! ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
! 
! Linear Algebra Data and Routines File
! 
! Generated by KPP-2.2.4_gc symbolic chemistry Kinetics PreProcessor
!       (http://www.cs.vt.edu/~asandu/Software/KPP)
! KPP is distributed under GPL, the general public licence
!       (http://www.gnu.org/copyleft/gpl.html)
! (C) 1995-1997, V. Damian & A. Sandu, CGRER, Univ. Iowa
! (C) 1997-2005, A. Sandu, Michigan Tech, Virginia Tech
!     With important contributions from:
!        M. Damian, Villanova University, USA
!        R. Sander, Max-Planck Institute for Chemistry, Mainz, Germany
! 
! File                 : gckpp_LinearAlgebra.f90
! Time                 : Thu Jul 19 13:05:43 2018
! Working directory    : /n/home05/msulprizio/GC/Code.Dev/KPP/Standard
! Equation file        : gckpp.kpp
! Output root filename : gckpp
! 
! ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~



MODULE gckpp_LinearAlgebra

  USE gckpp_Parameters
  USE gckpp_JacobianSP

  IMPLICIT NONE

CONTAINS


! ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
! 
! SPARSE_UTIL - SPARSE utility functions
!   Arguments :
! 
! ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~


! ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
SUBROUTINE KppDecomp( JVS, IER )
! ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
!        Sparse LU factorization
! ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~

  USE gckpp_Parameters
  USE gckpp_JacobianSP

      INTEGER  :: IER
      REAL(kind=dp) :: JVS(LU_NONZERO), W(NVAR), a
      INTEGER  :: k, kk, j, jj

      a = 0. ! mz_rs_20050606
      IER = 0
      DO k=1,NVAR
        ! mz_rs_20050606: don't check if real value == 0
        ! IF ( JVS( LU_DIAG(k) ) .EQ. 0. ) THEN
        IF ( ABS(JVS(LU_DIAG(k))) < TINY(a) ) THEN
            IER = k
            RETURN
        END IF
        DO kk = LU_CROW(k), LU_CROW(k+1)-1
              W( LU_ICOL(kk) ) = JVS(kk)
        END DO
        DO kk = LU_CROW(k), LU_DIAG(k)-1
            j = LU_ICOL(kk)
            a = -W(j) / JVS( LU_DIAG(j) )
            W(j) = -a
            DO jj = LU_DIAG(j)+1, LU_CROW(j+1)-1
               W( LU_ICOL(jj) ) = W( LU_ICOL(jj) ) + a*JVS(jj)
            END DO
         END DO
         DO kk = LU_CROW(k), LU_CROW(k+1)-1
            JVS(kk) = W( LU_ICOL(kk) )
         END DO
      END DO
      
END SUBROUTINE KppDecomp


! ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
SUBROUTINE KppDecompCmplx( JVS, IER )
! ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
!        Sparse LU factorization, complex
! ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~

  USE gckpp_Parameters
  USE gckpp_JacobianSP

      INTEGER        :: IER
      DOUBLE COMPLEX :: JVS(LU_NONZERO), W(NVAR), a
      REAL(kind=dp)  :: b = 0.0
      INTEGER        :: k, kk, j, jj

      IER = 0
      DO k=1,NVAR
        IF ( ABS(JVS(LU_DIAG(k))) < TINY(b) ) THEN
            IER = k
            RETURN
        END IF
        DO kk = LU_CROW(k), LU_CROW(k+1)-1
              W( LU_ICOL(kk) ) = JVS(kk)
        END DO
        DO kk = LU_CROW(k), LU_DIAG(k)-1
            j = LU_ICOL(kk)
            a = -W(j) / JVS( LU_DIAG(j) )
            W(j) = -a
            DO jj = LU_DIAG(j)+1, LU_CROW(j+1)-1
               W( LU_ICOL(jj) ) = W( LU_ICOL(jj) ) + a*JVS(jj)
            END DO
         END DO
         DO kk = LU_CROW(k), LU_CROW(k+1)-1
            JVS(kk) = W( LU_ICOL(kk) )
         END DO
      END DO
      
END SUBROUTINE KppDecompCmplx


! ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
SUBROUTINE KppDecompCmplxR( JVSR, JVSI, IER )
! ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
!    Sparse LU factorization, complex
!   (Real and Imaginary parts are used instead of complex data type)     
! ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~

  USE gckpp_Parameters
  USE gckpp_JacobianSP

      INTEGER       :: IER
      REAL(kind=dp) :: JVSR(LU_NONZERO), JVSI(LU_NONZERO) 
      REAL(kind=dp) :: WR(NVAR), WI(NVAR), ar, ai, den
      INTEGER       :: k, kk, j, jj

      IER = 0
      ar  = 0.0
      DO k=1,NVAR
        IF (  ( ABS(JVSR(LU_DIAG(k))) < TINY(ar) ) .AND. &
              ( ABS(JVSI(LU_DIAG(k))) < TINY(ar) ) )  THEN
            IER = k
            RETURN
        END IF
        DO kk = LU_CROW(k), LU_CROW(k+1)-1
              WR( LU_ICOL(kk) ) = JVSR(kk)
              WI( LU_ICOL(kk) ) = JVSI(kk)
        END DO
        DO kk = LU_CROW(k), LU_DIAG(k)-1
            j = LU_ICOL(kk)
            den = JVSR(LU_DIAG(j))**2 + JVSI(LU_DIAG(j))**2
            ar = -(WR(j)*JVSR(LU_DIAG(j)) + WI(j)*JVSI(LU_DIAG(j)))/den
            ai = -(WI(j)*JVSR(LU_DIAG(j)) - WR(j)*JVSI(LU_DIAG(j)))/den
            WR(j) = -ar
            WI(j) = -ai
            DO jj = LU_DIAG(j)+1, LU_CROW(j+1)-1
               WR( LU_ICOL(jj) ) = WR( LU_ICOL(jj) ) + ar*JVSR(jj) - ai*JVSI(jj)
               WI( LU_ICOL(jj) ) = WI( LU_ICOL(jj) ) + ar*JVSI(jj) + ai*JVSR(jj)
            END DO
         END DO
         DO kk = LU_CROW(k), LU_CROW(k+1)-1
            JVSR(kk) = WR( LU_ICOL(kk) )
            JVSI(kk) = WI( LU_ICOL(kk) )
         END DO
      END DO

END SUBROUTINE KppDecompCmplxR


! ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
SUBROUTINE KppSolveIndirect( JVS, X )
! ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
!        Sparse solve subroutine using indirect addressing
! ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~

  USE gckpp_Parameters
  USE gckpp_JacobianSP

      INTEGER  :: i, j
      REAL(kind=dp) :: JVS(LU_NONZERO), X(NVAR), sum

      DO i=1,NVAR
         DO j = LU_CROW(i), LU_DIAG(i)-1 
             X(i) = X(i) - JVS(j)*X(LU_ICOL(j));
         END DO  
      END DO

      DO i=NVAR,1,-1
        sum = X(i);
        DO j = LU_DIAG(i)+1, LU_CROW(i+1)-1
          sum = sum - JVS(j)*X(LU_ICOL(j));
        END DO
        X(i) = sum/JVS(LU_DIAG(i));
      END DO
      
END SUBROUTINE KppSolveIndirect


! ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
SUBROUTINE KppSolveTRIndirect( JVS, X )
! ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
!        Complex sparse solve transpose subroutine using indirect addressing
! ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~

  USE gckpp_Parameters
  USE gckpp_JacobianSP

      INTEGER       :: i, j
      REAL(kind=dp) :: JVS(LU_NONZERO), X(NVAR)

      DO i=1,NVAR
        X(i) = X(i)/JVS(LU_DIAG(i))
	! subtract all nonzero elements in row i of JVS from X
        DO j=LU_DIAG(i)+1,LU_CROW(i+1)-1
	  X(LU_ICOL(j)) = X(LU_ICOL(j))-JVS(j)*X(i)
	END DO
      END DO

      DO i=NVAR, 1, -1
	! subtract all nonzero elements in row i of JVS from X
        DO j=LU_CROW(i),LU_DIAG(i)-1
	  X(LU_ICOL(j)) = X(LU_ICOL(j))-JVS(j)*X(i)
	END DO
      END DO
      
END SUBROUTINE KppSolveTRIndirect


! ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
SUBROUTINE KppSolveCmplx( JVS, X )
! ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
!        Complex sparse solve subroutine using indirect addressing
! ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~

  USE gckpp_Parameters
  USE gckpp_JacobianSP

      INTEGER        :: i, j
      DOUBLE COMPLEX :: JVS(LU_NONZERO), X(NVAR), sum

      DO i=1,NVAR
         DO j = LU_CROW(i), LU_DIAG(i)-1 
             X(i) = X(i) - JVS(j)*X(LU_ICOL(j));
         END DO  
      END DO

      DO i=NVAR,1,-1
        sum = X(i);
        DO j = LU_DIAG(i)+1, LU_CROW(i+1)-1
          sum = sum - JVS(j)*X(LU_ICOL(j));
        END DO
        X(i) = sum/JVS(LU_DIAG(i));
      END DO
      
END SUBROUTINE KppSolveCmplx

! ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
SUBROUTINE KppSolveCmplxR( JVSR, JVSI, XR, XI )
! ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
!   Complex sparse solve subroutine using indirect addressing
!   (Real and Imaginary parts are used instead of complex data type)     
! ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~

  USE gckpp_Parameters
  USE gckpp_JacobianSP

      INTEGER       ::  i, j
      REAL(kind=dp) ::  JVSR(LU_NONZERO), JVSI(LU_NONZERO), XR(NVAR), XI(NVAR), sumr, sumi, den

      DO i=1,NVAR
         DO j = LU_CROW(i), LU_DIAG(i)-1 
             XR(i) = XR(i) - (JVSR(j)*XR(LU_ICOL(j)) - JVSI(j)*XI(LU_ICOL(j)))
             XI(i) = XI(i) - (JVSR(j)*XI(LU_ICOL(j)) + JVSI(j)*XR(LU_ICOL(j)))
         END DO  
      END DO

      DO i=NVAR,1,-1
        sumr = XR(i); sumi = XI(i)
        DO j = LU_DIAG(i)+1, LU_CROW(i+1)-1
            sumr = sumr - (JVSR(j)*XR(LU_ICOL(j)) - JVSI(j)*XI(LU_ICOL(j)))
            sumi = sumi - (JVSR(j)*XI(LU_ICOL(j)) + JVSI(j)*XR(LU_ICOL(j)))
        END DO
        den   = JVSR(LU_DIAG(i))**2 + JVSI(LU_DIAG(i))**2
        XR(i) = (sumr*JVSR(LU_DIAG(i)) + sumi*JVSI(LU_DIAG(i)))/den
        XI(i) = (sumi*JVSR(LU_DIAG(i)) - sumr*JVSI(LU_DIAG(i)))/den
      END DO
      
END SUBROUTINE KppSolveCmplxR


! ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
SUBROUTINE KppSolveTRCmplx( JVS, X )
! ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
!        Complex sparse solve transpose subroutine using indirect addressing
! ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~

  USE gckpp_Parameters
  USE gckpp_JacobianSP

      INTEGER        :: i, j
      DOUBLE COMPLEX :: JVS(LU_NONZERO), X(NVAR)

      DO i=1,NVAR
        X(i) = X(i)/JVS(LU_DIAG(i))
	! subtract all nonzero elements in row i of JVS from X
        DO j=LU_DIAG(i)+1,LU_CROW(i+1)-1
	  X(LU_ICOL(j)) = X(LU_ICOL(j))-JVS(j)*X(i)
	END DO
      END DO

      DO i=NVAR, 1, -1
	! subtract all nonzero elements in row i of JVS from X
        DO j=LU_CROW(i),LU_DIAG(i)-1
	  X(LU_ICOL(j)) = X(LU_ICOL(j))-JVS(j)*X(i)
	END DO
      END DO
      
END SUBROUTINE KppSolveTRCmplx


! ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
SUBROUTINE KppSolveTRCmplxR( JVSR, JVSI, XR, XI )
! ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
!   Complex sparse solve transpose subroutine using indirect addressing
!   (Real and Imaginary parts are used instead of complex data type)     
! ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~

  USE gckpp_Parameters
  USE gckpp_JacobianSP

      INTEGER       ::  i, j
      REAL(kind=dp) ::  JVSR(LU_NONZERO), JVSI(LU_NONZERO), XR(NVAR), XI(NVAR), den

      DO i=1,NVAR
        den   = JVSR(LU_DIAG(i))**2 + JVSI(LU_DIAG(i))**2
        XR(i) = (XR(i)*JVSR(LU_DIAG(i)) + XI(i)*JVSI(LU_DIAG(i)))/den
        XI(i) = (XI(i)*JVSR(LU_DIAG(i)) - XR(i)*JVSI(LU_DIAG(i)))/den
	! subtract all nonzero elements in row i of JVS from X
        DO j=LU_DIAG(i)+1,LU_CROW(i+1)-1
	  XR(LU_ICOL(j)) = XR(LU_ICOL(j))-(JVSR(j)*XR(i) - JVSI(j)*XI(i))
	  XI(LU_ICOL(j)) = XI(LU_ICOL(j))-(JVSI(j)*XR(i) + JVSR(j)*XI(i))
	END DO
      END DO

      DO i=NVAR, 1, -1
	! subtract all nonzero elements in row i of JVS from X
        DO j=LU_CROW(i),LU_DIAG(i)-1
	  XR(LU_ICOL(j)) = XR(LU_ICOL(j))-(JVSR(j)*XR(i) - JVSI(j)*XI(i))
	  XI(LU_ICOL(j)) = XI(LU_ICOL(j))-(JVSI(j)*XR(i) + JVSR(j)*XI(i))
	END DO
      END DO
      
END SUBROUTINE KppSolveTRCmplxR


!
! Next few commented subroutines perform sparse big linear algebra
!
!! ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
!SUBROUTINE KppDecompBig( JVS, IP, IER )
!! ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
!!        Sparse LU factorization
!!        for the Runge Kutta (3n)x(3n) linear system
!! ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
!
!  USE gckpp_Parameters
!  USE gckpp_JacobianSP
!
!      INTEGER  :: IP3(3), IER, IP(3,NVAR)
!      REAL(kind=dp) :: JVS(3,3,LU_NONZERO), W(3,3,NVAR), a(3,3), E(3,3)
!      INTEGER  :: k, kk, j, jj
!
!      a = 0.0d0
!      IER = 0
!      DO k=1,NVAR
!        DO kk = LU_CROW(k), LU_CROW(k+1)-1
!              W( 1:3,1:3,LU_ICOL(kk) ) = JVS(1:3,1:3,kk)
!        END DO
!        DO kk = LU_CROW(k), LU_DIAG(k)-1
!            j = LU_ICOL(kk)
!            E(1:3,1:3) = JVS( 1:3,1:3,LU_DIAG(j) )
!            ! CALL DGETRF(3,3,E,3,IP3,IER) 
!            CALL FAC3(E,IP3,IER)
!            IF ( IER /= 0 )  RETURN
!            ! a = W(j) / JVS( LU_DIAG(j) )
!            a(1:3,1:3) = W( 1:3,1:3,j )
!            ! CALL DGETRS ('N',3,3,E,3,IP3,a,3,IER) 
!            CALL SOL3('N',E,IP3,a(1,1))
!            CALL SOL3('N',E,IP3,a(1,2))
!            CALL SOL3('N',E,IP3,a(1,3))
!            W(1:3,1:3,j) = a(1:3,1:3)
!            DO jj = LU_DIAG(j)+1, LU_CROW(j+1)-1
!               W( 1:3,1:3,LU_ICOL(jj) ) = W( 1:3,1:3,LU_ICOL(jj) ) &
!                        - MATMUL( a(1:3,1:3) , JVS(1:3,1:3,jj) )
!            END DO
!         END DO
!         DO kk = LU_CROW(k), LU_CROW(k+1)-1
!            JVS(1:3,1:3,kk) = W( 1:3,1:3,LU_ICOL(kk) )
!         END DO
!      END DO
!
!      DO k=1,NVAR
!         ! CALL WGEFA(JVS(1,1,LU_DIAG(k)),3,3,IP(1,k),IER)
!         ! CALL DGETRF(3,3,JVS(1,1,LU_DIAG(k)),3,IP(1,k),IER)
!         CALL FAC3(JVS(1,1,LU_DIAG(k)),IP(1,k),IER)
!         IF ( IER /= 0 )  RETURN
!      END DO 
!      
!END SUBROUTINE KppDecompBig
!
!
!! ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
!SUBROUTINE KppSolveBig( JVS, IP, X )
!! ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
!!        Sparse solve subroutine using indirect addressing
!!        for the Runge Kutta (3n)x(3n) linear system
!! ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
!
!  USE gckpp_Parameters
!  USE gckpp_JacobianSP
!
!      INTEGER  :: i, j, k, m, IP3(3), IP(3,NVAR), IER
!      REAL(kind=dp) :: JVS(3,3,LU_NONZERO), X(3,NVAR), sum(3)
!
!      DO i=1,NVAR
!        DO j = LU_CROW(i), LU_DIAG(i)-1 
!          !X(1:3,i) = X(1:3,i) - MATMUL(JVS(1:3,1:3,j),X(1:3,LU_ICOL(j)));
!          DO k=1,3
!            DO m=1,3
!	       X(k,i) = X(k,i) - JVS(k,m,j)*X(m,LU_ICOL(j))
!            END DO
!          END DO
!        END DO  
!      END DO
!
!      DO i=NVAR,1,-1
!        sum(1:3) = X(1:3,i);
!        DO j = LU_DIAG(i)+1, LU_CROW(i+1)-1
!          !sum(1:3) = sum(1:3) - MATMUL(JVS(1:3,1:3,j),X(1:3,LU_ICOL(j)));
!          DO k=1,3
!            DO m=1,3
!	       sum(k) = sum(k) - JVS(k,m,j)*X(m,LU_ICOL(j))
!            END DO
!          END DO
!        END DO
!        ! X(i) = sum/JVS(LU_DIAG(i));
!        ! CALL DGETRS ('N',3,1,JVS(1:3,1:3,LU_DIAG(i)),3,IP(1,i),sum,3,0) 
!        ! CALL WGESL('N',JVS(1,1,LU_DIAG(i)),3,3,IP(1,i),sum)
!        CALL SOL3('N',JVS(1,1,LU_DIAG(i)),IP(1,i),sum)
!        X(1:3,i) = sum(1:3)
!      END DO
!      
!END SUBROUTINE KppSolveBig
!
!
!! ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
!SUBROUTINE KppSolveBigTR( JVS, IP, X )
!! ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
!!        Big sparse transpose solve using indirect addressing
!! ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
!
!  USE gckpp_Parameters
!  USE gckpp_JacobianSP
!
!      INTEGER       :: i, j, k, m, IP(3,NVAR)
!      REAL(kind=dp) :: JVS(3,3,LU_NONZERO), X(3,NVAR)
!
!      DO i=1,NVAR
!        ! X(i) = X(i)/JVS(LU_DIAG(i))
!        CALL SOL3('T',JVS(1,1,LU_DIAG(i)),IP(1,i),X(1,i))
!        DO j=LU_DIAG(i)+1,LU_CROW(i+1)-1
!	  !X(1:3,LU_ICOL(j)) = X(1:3,LU_ICOL(j)) &
!          !    - MATMUL( TRANSPOSE(JVS(1:3,1:3,j)), X(1:3,i) )
!          DO k=1,3
!            DO m=1,3
!	       X(k,LU_ICOL(j)) = X(k,LU_ICOL(j)) - JVS(m,k,j)*X(m,i)
!            END DO
!          END DO
!	END DO
!      END DO
!
!      DO i=NVAR, 1, -1
!        DO j=LU_CROW(i),LU_DIAG(i)-1
!	  !X(1:3,LU_ICOL(j)) = X(1:3,LU_ICOL(j)) &
!          !   - MATMUL( TRANSPOSE(JVS(1:3,1:3,j)), X(1:3,i) )
!          DO k=1,3
!            DO m=1,3
!	       X(k,LU_ICOL(j)) = X(k,LU_ICOL(j)) - JVS(m,k,j)*X(m,i)
!            END DO
!          END DO
!	END DO
!      END DO
!      
!END SUBROUTINE KppSolveBigTR
!
!
!
!! ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
!SUBROUTINE FAC3(A,IPVT,INFO)
!! ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
!!     FAC3 FACTORS THE MATRIX A (3,3) BY
!!           GAUSS ELIMINATION WITH PARTIAL PIVOTING
!!     LINPACK - LIKE 
!!
!!     Remove comments to perform pivoting
!! ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
!!
!      REAL(kind=dp) :: A(3,3)
!      INTEGER       :: IPVT(3),INFO
!!      INTEGER       :: L
!!      REAL(kind=dp) :: t, dmax, da, TMP(3)
!      REAL(kind=dp), PARAMETER :: ZERO = 0.0, ONE = 1.0
!
!      info = 0
!!      t = TINY(da)
!!      
!!      da = ABS(A(1,1)); L = 1
!!      IF ( ABS(A(2,1))>da ) THEN
!!        da = ABS(A(2,1)); L = 2
!!        IF ( ABS(A(3,1))>da ) THEN
!!          L = 3
!!        END IF  
!!      END IF  
!!      IPVT(1)  = L
!!      IF (L /=1 ) THEN
!!         TMP(1:3) = A(L,1:3)
!!         A(L,1:3) = A(1,1:3)
!!         A(1,1:3) = TMP(1:3)
!!      END IF
!!      IF (ABS(A(1,1)) < t) THEN
!!         info = 1
!!         return
!!      END IF   
!!
!      A(2,1) = A(2,1)/A(1,1)
!      A(2,2) = A(2,2) - A(2,1)*A(1,2)
!      A(2,3) = A(2,3) - A(2,1)*A(1,3)
!      A(3,1) = A(3,1)/A(1,1)
!      A(3,2) = A(3,2) - A(3,1)*A(1,2)
!      A(3,3) = A(3,3) - A(3,1)*A(1,3)
!      
!!      IPVT(2)  = 2
!!      IF (ABS(A(3,2))>ABS(A(2,2))) THEN
!!         IPVT(2)  = 3
!!         TMP(2:3) = A(3,2:3)
!!         A(3,2:3) = A(2,2:3)
!!         A(2,2:3) = TMP(2:3)
!!      END IF
!!      IF (ABS(A(2,2)) < t) THEN
!!         info = 1
!!         return
!!      END IF   
!!      
!      A(3,2)   = A(3,2)/A(2,2)
!      A(3,3)   = A(3,3) - A(3,2)*A(2,3)
!      IPVT(3)  = 3
!      
!END SUBROUTINE FAC3
!
!
!! ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
!SUBROUTINE SOL3(Trans,A,IPVT,b)
!! ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
!!     SOL3 solves the system 3x3
!!     A * x = b  or  trans(a) * x = b
!!     using the factors computed by WGEFA.
!!
!!     Trans      = 'N'   to solve  A*x = b ,
!!                = 'T'   to solve  transpose(A)*x = b
!!     LINPACK - LIKE 
!!
!!     Remove comments to use pivoting
!! ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
!
!      CHARACTER     :: Trans
!      REAL(kind=dp) :: a(3,3),b(3)
!      INTEGER       :: IPVT(3)
!!      INTEGER       :: L
!!      REAL(kind=dp) :: TMP
!      
!      SELECT CASE (Trans)
!
!      CASE ('n','N')  !  Solve  A * x = b
!
!!     Solve  L*y = b
!!         L = IPVT(1)
!!         IF (L /= 1) THEN
!!            TMP = B(1); B(1) = B(L); B(L) = TMP
!!         END IF
!         b(2) = b(2)-A(2,1)*b(1)
!         b(3) = b(3)-A(3,1)*b(1)
!         
!!         L = IPVT(2)
!!         IF (L /= 2) THEN
!!            TMP = B(2); B(2) = B(L); B(L) = TMP
!!         END IF
!         b(3) = b(3)-A(3,2)*b(2)
!
!!     Solve  U*x = y
!         b(3) = b(3)/A(3,3)
!         b(2) = (b(2)-A(2,3)*b(3))/A(2,2)
!         b(1) = (b(1)-A(1,3)*b(3)-A(1,2)*b(2))/A(1,1)
!      
!      
!      CASE ('t','T')  !  Solve transpose(A) * x = b
!
!!      Solve transpose(U)*y = b
!         b(1) = b(1)/A(1,1)
!         b(2) = (b(2)-A(1,2)*b(1))/A(2,2)
!         b(3) = (b(3)-A(1,3)*b(1)-A(2,3)*b(2))/A(3,3)
!
!!      Solve transpose(L)*x = y
!         b(2) = b(2)-A(3,2)*b(3)
!!         L = ipvt(2)
!!         IF (L /= 2) THEN
!!            TMP = B(2); B(2) = B(L); B(L) = TMP
!!         END IF
!         b(1) = b(1)-A(3,1)*b(3)-A(2,1)*b(2)
!!         L = ipvt(1)
!!         IF (L /= 1) THEN
!!            TMP = B(1); B(1) = B(L); B(L) = TMP
!!         END IF
!   
!      END SELECT
!
!END SUBROUTINE SOL3

! End of SPARSE_UTIL function
! ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~


! ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
! 
! KppSolve - sparse back substitution
!   Arguments :
!      JVS       - sparse Jacobian of variables
!      X         - Vector for variables
! 
! ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~

SUBROUTINE KppSolve ( JVS, X )

! JVS - sparse Jacobian of variables
  REAL(kind=dp) :: JVS(LU_NONZERO)
! X - Vector for variables
  REAL(kind=dp) :: X(NVAR)

  X(63) = X(63)-JVS(424)*X(50)
  X(64) = X(64)-JVS(429)*X(42)
  X(67) = X(67)-JVS(444)*X(38)
  X(88) = X(88)-JVS(526)*X(37)-JVS(527)*X(40)-JVS(528)*X(47)
  X(96) = X(96)-JVS(557)*X(79)
  X(97) = X(97)-JVS(564)*X(86)
  X(113) = X(113)-JVS(649)*X(107)
  X(120) = X(120)-JVS(690)*X(112)
  X(139) = X(139)-JVS(791)*X(118)
  X(141) = X(141)-JVS(804)*X(76)
  X(145) = X(145)-JVS(832)*X(48)
  X(147) = X(147)-JVS(857)*X(61)-JVS(858)*X(86)-JVS(859)*X(138)
  X(149) = X(149)-JVS(877)*X(96)
  X(157) = X(157)-JVS(936)*X(60)-JVS(937)*X(65)-JVS(938)*X(66)-JVS(939)*X(121)-JVS(940)*X(128)-JVS(941)*X(129)-JVS(942)&
             &*X(150)
  X(158) = X(158)-JVS(950)*X(39)-JVS(951)*X(42)-JVS(952)*X(50)-JVS(953)*X(91)-JVS(954)*X(107)-JVS(955)*X(110)-JVS(956)&
             &*X(113)-JVS(957)*X(140)-JVS(958)*X(152)-JVS(959)*X(154)-JVS(960)*X(157)
  X(159) = X(159)-JVS(974)*X(150)
  X(161) = X(161)-JVS(993)*X(102)
  X(164) = X(164)-JVS(1022)*X(89)-JVS(1023)*X(109)
  X(165) = X(165)-JVS(1034)*X(102)-JVS(1035)*X(150)-JVS(1036)*X(152)-JVS(1037)*X(154)-JVS(1038)*X(161)
  X(168) = X(168)-JVS(1068)*X(101)
  X(169) = X(169)-JVS(1078)*X(123)
  X(170) = X(170)-JVS(1085)*X(142)-JVS(1086)*X(145)-JVS(1087)*X(150)-JVS(1088)*X(157)-JVS(1089)*X(159)-JVS(1090)*X(169)
  X(171) = X(171)-JVS(1109)*X(90)-JVS(1110)*X(109)
  X(173) = X(173)-JVS(1129)*X(123)-JVS(1130)*X(169)
  X(175) = X(175)-JVS(1145)*X(126)-JVS(1146)*X(166)
  X(176) = X(176)-JVS(1156)*X(134)-JVS(1157)*X(135)-JVS(1158)*X(142)-JVS(1159)*X(153)-JVS(1160)*X(155)-JVS(1161)*X(156)&
             &-JVS(1162)*X(160)-JVS(1163)*X(163)-JVS(1164)*X(172)-JVS(1165)*X(174)
  X(177) = X(177)-JVS(1183)*X(115)
  X(178) = X(178)-JVS(1194)*X(1)-JVS(1195)*X(2)-JVS(1196)*X(3)-JVS(1197)*X(40)-JVS(1198)*X(44)-JVS(1199)*X(59)-JVS(1200)&
             &*X(61)-JVS(1201)*X(71)-JVS(1202)*X(74)-JVS(1203)*X(86)-JVS(1204)*X(88)-JVS(1205)*X(111)-JVS(1206)*X(138)&
             &-JVS(1207)*X(147)
  X(179) = X(179)-JVS(1218)*X(49)-JVS(1219)*X(100)-JVS(1220)*X(167)
  X(180) = X(180)-JVS(1233)*X(142)
  X(181) = X(181)-JVS(1242)*X(150)-JVS(1243)*X(169)
  X(182) = X(182)-JVS(1253)*X(134)-JVS(1254)*X(135)-JVS(1255)*X(142)
  X(183) = X(183)-JVS(1265)*X(134)-JVS(1266)*X(135)-JVS(1267)*X(142)-JVS(1268)*X(182)
  X(184) = X(184)-JVS(1277)*X(40)-JVS(1278)*X(47)-JVS(1279)*X(88)-JVS(1280)*X(111)-JVS(1281)*X(138)-JVS(1282)*X(147)&
             &-JVS(1283)*X(178)
  X(185) = X(185)-JVS(1293)*X(134)-JVS(1294)*X(135)-JVS(1295)*X(142)
  X(186) = X(186)-JVS(1305)*X(116)-JVS(1306)*X(122)-JVS(1307)*X(125)-JVS(1308)*X(144)
  X(187) = X(187)-JVS(1321)*X(123)-JVS(1322)*X(150)-JVS(1323)*X(169)
  X(188) = X(188)-JVS(1331)*X(134)-JVS(1332)*X(135)
  X(189) = X(189)-JVS(1341)*X(112)-JVS(1342)*X(128)-JVS(1343)*X(129)
  X(190) = X(190)-JVS(1352)*X(41)-JVS(1353)*X(67)-JVS(1354)*X(92)-JVS(1355)*X(104)-JVS(1356)*X(119)-JVS(1357)*X(122)&
             &-JVS(1358)*X(125)-JVS(1359)*X(132)-JVS(1360)*X(137)-JVS(1361)*X(138)-JVS(1362)*X(139)-JVS(1363)*X(140)&
             &-JVS(1364)*X(144)-JVS(1365)*X(147)-JVS(1366)*X(148)-JVS(1367)*X(150)-JVS(1368)*X(158)-JVS(1369)*X(159)&
             &-JVS(1370)*X(162)-JVS(1371)*X(169)-JVS(1372)*X(175)-JVS(1373)*X(178)-JVS(1374)*X(180)-JVS(1375)*X(181)&
             &-JVS(1376)*X(182)-JVS(1377)*X(183)-JVS(1378)*X(184)-JVS(1379)*X(186)-JVS(1380)*X(187)-JVS(1381)*X(188)&
             &-JVS(1382)*X(189)
  X(192) = X(192)-JVS(1423)*X(107)-JVS(1424)*X(112)-JVS(1425)*X(114)-JVS(1426)*X(140)-JVS(1427)*X(155)-JVS(1428)*X(157)&
             &-JVS(1429)*X(159)-JVS(1430)*X(169)-JVS(1431)*X(187)-JVS(1432)*X(189)-JVS(1433)*X(191)
  X(193) = X(193)-JVS(1450)*X(126)-JVS(1451)*X(136)-JVS(1452)*X(166)
  X(194) = X(194)-JVS(1463)*X(145)-JVS(1464)*X(156)-JVS(1465)*X(161)-JVS(1466)*X(164)-JVS(1467)*X(166)-JVS(1468)*X(168)&
             &-JVS(1469)*X(171)-JVS(1470)*X(173)-JVS(1471)*X(175)-JVS(1472)*X(177)-JVS(1473)*X(181)-JVS(1474)*X(185)&
             &-JVS(1475)*X(187)-JVS(1476)*X(189)-JVS(1477)*X(191)-JVS(1478)*X(193)
  X(195) = X(195)-JVS(1506)*X(114)-JVS(1507)*X(174)
  X(196) = X(196)-JVS(1518)*X(79)-JVS(1519)*X(83)-JVS(1520)*X(98)-JVS(1521)*X(132)-JVS(1522)*X(149)-JVS(1523)*X(184)
  X(197) = X(197)-JVS(1540)*X(174)
  X(199) = X(199)-JVS(1562)*X(122)-JVS(1563)*X(125)-JVS(1564)*X(186)
  X(200) = X(200)-JVS(1578)*X(39)-JVS(1579)*X(50)-JVS(1580)*X(91)-JVS(1581)*X(107)-JVS(1582)*X(110)-JVS(1583)*X(112)&
             &-JVS(1584)*X(113)-JVS(1585)*X(114)-JVS(1586)*X(115)-JVS(1587)*X(117)-JVS(1588)*X(140)-JVS(1589)*X(145)&
             &-JVS(1590)*X(157)-JVS(1591)*X(159)-JVS(1592)*X(160)-JVS(1593)*X(163)-JVS(1594)*X(165)-JVS(1595)*X(166)&
             &-JVS(1596)*X(167)-JVS(1597)*X(169)-JVS(1598)*X(177)-JVS(1599)*X(181)-JVS(1600)*X(185)-JVS(1601)*X(187)&
             &-JVS(1602)*X(189)-JVS(1603)*X(191)-JVS(1604)*X(195)-JVS(1605)*X(198)
  X(201) = X(201)-JVS(1630)*X(90)-JVS(1631)*X(171)-JVS(1632)*X(188)
  X(202) = X(202)-JVS(1645)*X(121)-JVS(1646)*X(128)-JVS(1647)*X(129)-JVS(1648)*X(150)-JVS(1649)*X(191)
  X(203) = X(203)-JVS(1660)*X(121)-JVS(1661)*X(128)-JVS(1662)*X(129)-JVS(1663)*X(174)
  X(204) = X(204)-JVS(1673)*X(81)-JVS(1674)*X(137)-JVS(1675)*X(142)-JVS(1676)*X(179)-JVS(1677)*X(198)
  X(205) = X(205)-JVS(1695)*X(133)-JVS(1696)*X(152)-JVS(1697)*X(154)-JVS(1698)*X(174)-JVS(1699)*X(198)
  X(206) = X(206)-JVS(1709)*X(104)-JVS(1710)*X(105)-JVS(1711)*X(106)-JVS(1712)*X(139)-JVS(1713)*X(140)-JVS(1714)*X(173)&
             &-JVS(1715)*X(180)-JVS(1716)*X(187)-JVS(1717)*X(188)-JVS(1718)*X(189)-JVS(1719)*X(191)-JVS(1720)*X(202)&
             &-JVS(1721)*X(203)-JVS(1722)*X(205)
  X(207) = X(207)-JVS(1733)*X(133)-JVS(1734)*X(152)-JVS(1735)*X(154)-JVS(1736)*X(166)-JVS(1737)*X(173)-JVS(1738)*X(185)&
             &-JVS(1739)*X(187)-JVS(1740)*X(191)-JVS(1741)*X(198)-JVS(1742)*X(203)-JVS(1743)*X(205)-JVS(1744)*X(206)
  X(208) = X(208)-JVS(1756)*X(101)-JVS(1757)*X(107)-JVS(1758)*X(112)-JVS(1759)*X(119)-JVS(1760)*X(120)-JVS(1761)*X(127)&
             &-JVS(1762)*X(136)-JVS(1763)*X(140)-JVS(1764)*X(141)-JVS(1765)*X(145)-JVS(1766)*X(148)-JVS(1767)*X(155)&
             &-JVS(1768)*X(157)-JVS(1769)*X(162)-JVS(1770)*X(167)-JVS(1771)*X(168)-JVS(1772)*X(169)-JVS(1773)*X(172)&
             &-JVS(1774)*X(174)-JVS(1775)*X(175)-JVS(1776)*X(177)-JVS(1777)*X(180)-JVS(1778)*X(181)-JVS(1779)*X(182)&
             &-JVS(1780)*X(183)-JVS(1781)*X(185)-JVS(1782)*X(187)-JVS(1783)*X(188)-JVS(1784)*X(189)-JVS(1785)*X(191)&
             &-JVS(1786)*X(193)-JVS(1787)*X(198)-JVS(1788)*X(201)-JVS(1789)*X(202)-JVS(1790)*X(203)-JVS(1791)*X(205)&
             &-JVS(1792)*X(206)-JVS(1793)*X(207)
  X(209) = X(209)-JVS(1812)*X(127)-JVS(1813)*X(172)-JVS(1814)*X(174)
  X(210) = X(210)-JVS(1829)*X(45)-JVS(1830)*X(46)-JVS(1831)*X(58)-JVS(1832)*X(73)-JVS(1833)*X(80)-JVS(1834)*X(94)&
             &-JVS(1835)*X(144)-JVS(1836)*X(178)-JVS(1837)*X(184)-JVS(1838)*X(186)-JVS(1839)*X(199)
  X(211) = X(211)-JVS(1855)*X(142)-JVS(1856)*X(174)-JVS(1857)*X(180)
  X(212) = X(212)-JVS(1869)*X(89)-JVS(1870)*X(102)-JVS(1871)*X(105)-JVS(1872)*X(106)-JVS(1873)*X(123)-JVS(1874)*X(133)&
             &-JVS(1875)*X(134)-JVS(1876)*X(135)-JVS(1877)*X(139)-JVS(1878)*X(140)-JVS(1879)*X(146)-JVS(1880)*X(152)&
             &-JVS(1881)*X(154)-JVS(1882)*X(161)-JVS(1883)*X(162)-JVS(1884)*X(164)-JVS(1885)*X(166)-JVS(1886)*X(168)&
             &-JVS(1887)*X(169)-JVS(1888)*X(171)-JVS(1889)*X(173)-JVS(1890)*X(175)-JVS(1891)*X(180)-JVS(1892)*X(182)&
             &-JVS(1893)*X(183)-JVS(1894)*X(185)-JVS(1895)*X(187)-JVS(1896)*X(188)-JVS(1897)*X(189)-JVS(1898)*X(191)&
             &-JVS(1899)*X(193)-JVS(1900)*X(195)-JVS(1901)*X(198)-JVS(1902)*X(202)-JVS(1903)*X(203)-JVS(1904)*X(205)&
             &-JVS(1905)*X(206)-JVS(1906)*X(207)-JVS(1907)*X(209)-JVS(1908)*X(211)
  X(213) = X(213)-JVS(1926)*X(105)-JVS(1927)*X(114)-JVS(1928)*X(118)-JVS(1929)*X(120)-JVS(1930)*X(133)-JVS(1931)*X(134)&
             &-JVS(1932)*X(135)-JVS(1933)*X(148)-JVS(1934)*X(152)-JVS(1935)*X(154)-JVS(1936)*X(175)-JVS(1937)*X(180)&
             &-JVS(1938)*X(182)-JVS(1939)*X(183)-JVS(1940)*X(185)-JVS(1941)*X(188)-JVS(1942)*X(189)-JVS(1943)*X(193)&
             &-JVS(1944)*X(195)-JVS(1945)*X(198)-JVS(1946)*X(202)-JVS(1947)*X(203)-JVS(1948)*X(205)-JVS(1949)*X(206)&
             &-JVS(1950)*X(207)-JVS(1951)*X(209)
  X(214) = X(214)-JVS(1967)*X(42)-JVS(1968)*X(50)-JVS(1969)*X(78)-JVS(1970)*X(91)-JVS(1971)*X(92)-JVS(1972)*X(101)&
             &-JVS(1973)*X(107)-JVS(1974)*X(114)-JVS(1975)*X(115)-JVS(1976)*X(117)-JVS(1977)*X(121)-JVS(1978)*X(124)&
             &-JVS(1979)*X(126)-JVS(1980)*X(127)-JVS(1981)*X(128)-JVS(1982)*X(129)-JVS(1983)*X(131)-JVS(1984)*X(136)&
             &-JVS(1985)*X(141)-JVS(1986)*X(142)-JVS(1987)*X(145)-JVS(1988)*X(150)-JVS(1989)*X(151)-JVS(1990)*X(152)&
             &-JVS(1991)*X(154)-JVS(1992)*X(157)-JVS(1993)*X(158)-JVS(1994)*X(159)-JVS(1995)*X(161)-JVS(1996)*X(164)&
             &-JVS(1997)*X(165)-JVS(1998)*X(166)-JVS(1999)*X(167)-JVS(2000)*X(168)-JVS(2001)*X(169)-JVS(2002)*X(171)&
             &-JVS(2003)*X(172)-JVS(2004)*X(173)-JVS(2005)*X(174)-JVS(2006)*X(175)-JVS(2007)*X(177)-JVS(2008)*X(179)&
             &-JVS(2009)*X(180)-JVS(2010)*X(181)-JVS(2011)*X(182)-JVS(2012)*X(183)-JVS(2013)*X(185)-JVS(2014)*X(187)&
             &-JVS(2015)*X(188)-JVS(2016)*X(189)-JVS(2017)*X(191)-JVS(2018)*X(192)-JVS(2019)*X(193)-JVS(2020)*X(195)&
             &-JVS(2021)*X(197)-JVS(2022)*X(198)-JVS(2023)*X(201)-JVS(2024)*X(202)-JVS(2025)*X(203)-JVS(2026)*X(204)&
             &-JVS(2027)*X(205)-JVS(2028)*X(206)-JVS(2029)*X(207)-JVS(2030)*X(208)-JVS(2031)*X(209)-JVS(2032)*X(211)&
             &-JVS(2033)*X(212)-JVS(2034)*X(213)
  X(215) = X(215)-JVS(2055)*X(121)-JVS(2056)*X(128)-JVS(2057)*X(129)-JVS(2058)*X(142)-JVS(2059)*X(172)-JVS(2060)*X(174)&
             &-JVS(2061)*X(180)-JVS(2062)*X(203)-JVS(2063)*X(205)
  X(216) = X(216)-JVS(2077)*X(81)-JVS(2078)*X(100)-JVS(2079)*X(101)-JVS(2080)*X(130)-JVS(2081)*X(156)-JVS(2082)*X(161)&
             &-JVS(2083)*X(167)-JVS(2084)*X(168)-JVS(2085)*X(173)-JVS(2086)*X(179)-JVS(2087)*X(185)-JVS(2088)*X(187)&
             &-JVS(2089)*X(191)-JVS(2090)*X(198)-JVS(2091)*X(203)-JVS(2092)*X(204)-JVS(2093)*X(205)-JVS(2094)*X(206)&
             &-JVS(2095)*X(207)-JVS(2096)*X(211)-JVS(2097)*X(212)-JVS(2098)*X(213)-JVS(2099)*X(215)
  X(217) = X(217)-JVS(2115)*X(121)-JVS(2116)*X(128)-JVS(2117)*X(129)-JVS(2118)*X(153)-JVS(2119)*X(174)-JVS(2120)*X(203)&
             &-JVS(2121)*X(205)
  X(218) = X(218)-JVS(2135)*X(72)-JVS(2136)*X(99)-JVS(2137)*X(107)-JVS(2138)*X(114)-JVS(2139)*X(115)-JVS(2140)*X(117)&
             &-JVS(2141)*X(126)-JVS(2142)*X(136)-JVS(2143)*X(141)-JVS(2144)*X(157)-JVS(2145)*X(159)-JVS(2146)*X(161)&
             &-JVS(2147)*X(163)-JVS(2148)*X(164)-JVS(2149)*X(166)-JVS(2150)*X(167)-JVS(2151)*X(168)-JVS(2152)*X(169)&
             &-JVS(2153)*X(171)-JVS(2154)*X(173)-JVS(2155)*X(174)-JVS(2156)*X(175)-JVS(2157)*X(177)-JVS(2158)*X(179)&
             &-JVS(2159)*X(180)-JVS(2160)*X(182)-JVS(2161)*X(183)-JVS(2162)*X(185)-JVS(2163)*X(187)-JVS(2164)*X(188)&
             &-JVS(2165)*X(189)-JVS(2166)*X(191)-JVS(2167)*X(193)-JVS(2168)*X(195)-JVS(2169)*X(198)-JVS(2170)*X(200)&
             &-JVS(2171)*X(201)-JVS(2172)*X(202)-JVS(2173)*X(203)-JVS(2174)*X(204)-JVS(2175)*X(205)-JVS(2176)*X(206)&
             &-JVS(2177)*X(207)-JVS(2178)*X(208)-JVS(2179)*X(209)-JVS(2180)*X(211)-JVS(2181)*X(212)-JVS(2182)*X(213)&
             &-JVS(2183)*X(215)-JVS(2184)*X(216)-JVS(2185)*X(217)
  X(219) = X(219)-JVS(2199)*X(69)-JVS(2200)*X(92)-JVS(2201)*X(103)-JVS(2202)*X(153)-JVS(2203)*X(155)-JVS(2204)*X(156)&
             &-JVS(2205)*X(160)-JVS(2206)*X(163)-JVS(2207)*X(172)-JVS(2208)*X(174)-JVS(2209)*X(197)-JVS(2210)*X(202)&
             &-JVS(2211)*X(203)-JVS(2212)*X(205)-JVS(2213)*X(211)-JVS(2214)*X(215)-JVS(2215)*X(217)-JVS(2216)*X(218)
  X(220) = X(220)-JVS(2230)*X(69)-JVS(2231)*X(75)-JVS(2232)*X(77)-JVS(2233)*X(93)-JVS(2234)*X(107)-JVS(2235)*X(110)&
             &-JVS(2236)*X(112)-JVS(2237)*X(117)-JVS(2238)*X(120)-JVS(2239)*X(127)-JVS(2240)*X(131)-JVS(2241)*X(134)&
             &-JVS(2242)*X(135)-JVS(2243)*X(136)-JVS(2244)*X(141)-JVS(2245)*X(142)-JVS(2246)*X(150)-JVS(2247)*X(153)&
             &-JVS(2248)*X(155)-JVS(2249)*X(156)-JVS(2250)*X(157)-JVS(2251)*X(158)-JVS(2252)*X(160)-JVS(2253)*X(163)&
             &-JVS(2254)*X(165)-JVS(2255)*X(166)-JVS(2256)*X(167)-JVS(2257)*X(169)-JVS(2258)*X(172)-JVS(2259)*X(174)&
             &-JVS(2260)*X(181)-JVS(2261)*X(187)-JVS(2262)*X(189)-JVS(2263)*X(191)-JVS(2264)*X(192)-JVS(2265)*X(193)&
             &-JVS(2266)*X(195)-JVS(2267)*X(197)-JVS(2268)*X(198)-JVS(2269)*X(200)-JVS(2270)*X(201)-JVS(2271)*X(202)&
             &-JVS(2272)*X(203)-JVS(2273)*X(205)-JVS(2274)*X(206)-JVS(2275)*X(207)-JVS(2276)*X(208)-JVS(2277)*X(209)&
             &-JVS(2278)*X(211)-JVS(2279)*X(212)-JVS(2280)*X(213)-JVS(2281)*X(214)-JVS(2282)*X(215)-JVS(2283)*X(216)&
             &-JVS(2284)*X(217)-JVS(2285)*X(218)-JVS(2286)*X(219)
  X(221) = X(221)-JVS(2301)*X(44)-JVS(2302)*X(72)-JVS(2303)*X(78)-JVS(2304)*X(92)-JVS(2305)*X(93)-JVS(2306)*X(94)&
             &-JVS(2307)*X(99)-JVS(2308)*X(124)-JVS(2309)*X(141)-JVS(2310)*X(151)-JVS(2311)*X(152)-JVS(2312)*X(154)&
             &-JVS(2313)*X(161)-JVS(2314)*X(163)-JVS(2315)*X(164)-JVS(2316)*X(165)-JVS(2317)*X(166)-JVS(2318)*X(167)&
             &-JVS(2319)*X(168)-JVS(2320)*X(169)-JVS(2321)*X(171)-JVS(2322)*X(173)-JVS(2323)*X(174)-JVS(2324)*X(175)&
             &-JVS(2325)*X(177)-JVS(2326)*X(179)-JVS(2327)*X(180)-JVS(2328)*X(182)-JVS(2329)*X(183)-JVS(2330)*X(185)&
             &-JVS(2331)*X(187)-JVS(2332)*X(188)-JVS(2333)*X(189)-JVS(2334)*X(191)-JVS(2335)*X(193)-JVS(2336)*X(194)&
             &-JVS(2337)*X(195)-JVS(2338)*X(198)-JVS(2339)*X(201)-JVS(2340)*X(202)-JVS(2341)*X(203)-JVS(2342)*X(204)&
             &-JVS(2343)*X(205)-JVS(2344)*X(206)-JVS(2345)*X(207)-JVS(2346)*X(208)-JVS(2347)*X(209)-JVS(2348)*X(211)&
             &-JVS(2349)*X(212)-JVS(2350)*X(213)-JVS(2351)*X(215)-JVS(2352)*X(216)-JVS(2353)*X(217)-JVS(2354)*X(218)&
             &-JVS(2355)*X(219)-JVS(2356)*X(220)
  X(222) = X(222)-JVS(2370)*X(3)-JVS(2371)*X(45)-JVS(2372)*X(46)-JVS(2373)*X(51)-JVS(2374)*X(58)-JVS(2375)*X(59)&
             &-JVS(2376)*X(73)-JVS(2377)*X(80)-JVS(2378)*X(86)-JVS(2379)*X(94)-JVS(2380)*X(108)-JVS(2381)*X(109)-JVS(2382)&
             &*X(111)-JVS(2383)*X(116)-JVS(2384)*X(122)-JVS(2385)*X(125)-JVS(2386)*X(137)-JVS(2387)*X(138)-JVS(2388)*X(144)&
             &-JVS(2389)*X(147)-JVS(2390)*X(178)-JVS(2391)*X(184)-JVS(2392)*X(186)-JVS(2393)*X(196)-JVS(2394)*X(199)&
             &-JVS(2395)*X(201)-JVS(2396)*X(206)-JVS(2397)*X(207)-JVS(2398)*X(210)-JVS(2399)*X(211)-JVS(2400)*X(213)&
             &-JVS(2401)*X(214)-JVS(2402)*X(215)-JVS(2403)*X(216)-JVS(2404)*X(217)-JVS(2405)*X(218)-JVS(2406)*X(219)&
             &-JVS(2407)*X(220)-JVS(2408)*X(221)
  X(223) = X(223)-JVS(2423)*X(61)-JVS(2424)*X(62)-JVS(2425)*X(63)-JVS(2426)*X(64)-JVS(2427)*X(68)-JVS(2428)*X(70)&
             &-JVS(2429)*X(88)-JVS(2430)*X(91)-JVS(2431)*X(97)-JVS(2432)*X(110)-JVS(2433)*X(113)-JVS(2434)*X(139)-JVS(2435)&
             &*X(140)-JVS(2436)*X(145)-JVS(2437)*X(152)-JVS(2438)*X(153)-JVS(2439)*X(154)-JVS(2440)*X(155)-JVS(2441)*X(156)&
             &-JVS(2442)*X(157)-JVS(2443)*X(160)-JVS(2444)*X(161)-JVS(2445)*X(163)-JVS(2446)*X(164)-JVS(2447)*X(166)&
             &-JVS(2448)*X(167)-JVS(2449)*X(168)-JVS(2450)*X(169)-JVS(2451)*X(171)-JVS(2452)*X(172)-JVS(2453)*X(173)&
             &-JVS(2454)*X(174)-JVS(2455)*X(175)-JVS(2456)*X(177)-JVS(2457)*X(178)-JVS(2458)*X(179)-JVS(2459)*X(180)&
             &-JVS(2460)*X(181)-JVS(2461)*X(182)-JVS(2462)*X(183)-JVS(2463)*X(184)-JVS(2464)*X(185)-JVS(2465)*X(187)&
             &-JVS(2466)*X(188)-JVS(2467)*X(189)-JVS(2468)*X(191)-JVS(2469)*X(193)-JVS(2470)*X(195)-JVS(2471)*X(197)&
             &-JVS(2472)*X(198)-JVS(2473)*X(201)-JVS(2474)*X(202)-JVS(2475)*X(203)-JVS(2476)*X(204)-JVS(2477)*X(205)&
             &-JVS(2478)*X(206)-JVS(2479)*X(207)-JVS(2480)*X(209)-JVS(2481)*X(210)-JVS(2482)*X(211)-JVS(2483)*X(212)&
             &-JVS(2484)*X(213)-JVS(2485)*X(215)-JVS(2486)*X(217)-JVS(2487)*X(218)-JVS(2488)*X(219)-JVS(2489)*X(220)&
             &-JVS(2490)*X(221)-JVS(2491)*X(222)
  X(224) = X(224)-JVS(2505)*X(109)-JVS(2506)*X(137)-JVS(2507)*X(186)-JVS(2508)*X(196)-JVS(2509)*X(199)-JVS(2510)*X(201)&
             &-JVS(2511)*X(206)-JVS(2512)*X(207)-JVS(2513)*X(210)-JVS(2514)*X(211)-JVS(2515)*X(213)-JVS(2516)*X(214)&
             &-JVS(2517)*X(215)-JVS(2518)*X(216)-JVS(2519)*X(217)-JVS(2520)*X(218)-JVS(2521)*X(219)-JVS(2522)*X(220)&
             &-JVS(2523)*X(221)-JVS(2524)*X(222)-JVS(2525)*X(223)
  X(225) = X(225)-JVS(2538)*X(75)-JVS(2539)*X(77)-JVS(2540)*X(93)-JVS(2541)*X(104)-JVS(2542)*X(109)-JVS(2543)*X(124)&
             &-JVS(2544)*X(130)-JVS(2545)*X(132)-JVS(2546)*X(137)-JVS(2547)*X(144)-JVS(2548)*X(151)-JVS(2549)*X(170)&
             &-JVS(2550)*X(174)-JVS(2551)*X(176)-JVS(2552)*X(181)-JVS(2553)*X(186)-JVS(2554)*X(187)-JVS(2555)*X(188)&
             &-JVS(2556)*X(191)-JVS(2557)*X(192)-JVS(2558)*X(194)-JVS(2559)*X(195)-JVS(2560)*X(196)-JVS(2561)*X(197)&
             &-JVS(2562)*X(198)-JVS(2563)*X(199)-JVS(2564)*X(201)-JVS(2565)*X(202)-JVS(2566)*X(203)-JVS(2567)*X(204)&
             &-JVS(2568)*X(205)-JVS(2569)*X(206)-JVS(2570)*X(207)-JVS(2571)*X(208)-JVS(2572)*X(209)-JVS(2573)*X(210)&
             &-JVS(2574)*X(211)-JVS(2575)*X(212)-JVS(2576)*X(213)-JVS(2577)*X(214)-JVS(2578)*X(215)-JVS(2579)*X(216)&
             &-JVS(2580)*X(217)-JVS(2581)*X(218)-JVS(2582)*X(219)-JVS(2583)*X(220)-JVS(2584)*X(221)-JVS(2585)*X(222)&
             &-JVS(2586)*X(223)-JVS(2587)*X(224)
  X(226) = X(226)-JVS(2599)*X(45)-JVS(2600)*X(46)-JVS(2601)*X(52)-JVS(2602)*X(53)-JVS(2603)*X(54)-JVS(2604)*X(55)&
             &-JVS(2605)*X(56)-JVS(2606)*X(57)-JVS(2607)*X(58)-JVS(2608)*X(62)-JVS(2609)*X(68)-JVS(2610)*X(73)-JVS(2611)&
             &*X(80)-JVS(2612)*X(82)-JVS(2613)*X(84)-JVS(2614)*X(85)-JVS(2615)*X(87)-JVS(2616)*X(94)-JVS(2617)*X(149)&
             &-JVS(2618)*X(151)-JVS(2619)*X(196)-JVS(2620)*X(199)-JVS(2621)*X(210)-JVS(2622)*X(211)-JVS(2623)*X(216)&
             &-JVS(2624)*X(217)-JVS(2625)*X(218)-JVS(2626)*X(219)-JVS(2627)*X(220)-JVS(2628)*X(221)-JVS(2629)*X(222)&
             &-JVS(2630)*X(223)-JVS(2631)*X(224)-JVS(2632)*X(225)
  X(227) = X(227)-JVS(2643)*X(2)-JVS(2644)*X(43)-JVS(2645)*X(52)-JVS(2646)*X(53)-JVS(2647)*X(54)-JVS(2648)*X(55)&
             &-JVS(2649)*X(56)-JVS(2650)*X(57)-JVS(2651)*X(58)-JVS(2652)*X(74)-JVS(2653)*X(75)-JVS(2654)*X(77)-JVS(2655)&
             &*X(79)-JVS(2656)*X(82)-JVS(2657)*X(83)-JVS(2658)*X(84)-JVS(2659)*X(85)-JVS(2660)*X(86)-JVS(2661)*X(87)&
             &-JVS(2662)*X(93)-JVS(2663)*X(96)-JVS(2664)*X(104)-JVS(2665)*X(108)-JVS(2666)*X(109)-JVS(2667)*X(111)-JVS(2668)&
             &*X(122)-JVS(2669)*X(124)-JVS(2670)*X(125)-JVS(2671)*X(130)-JVS(2672)*X(132)-JVS(2673)*X(137)-JVS(2674)*X(138)&
             &-JVS(2675)*X(144)-JVS(2676)*X(147)-JVS(2677)*X(149)-JVS(2678)*X(151)-JVS(2679)*X(170)-JVS(2680)*X(174)&
             &-JVS(2681)*X(176)-JVS(2682)*X(178)-JVS(2683)*X(181)-JVS(2684)*X(184)-JVS(2685)*X(186)-JVS(2686)*X(187)&
             &-JVS(2687)*X(188)-JVS(2688)*X(191)-JVS(2689)*X(192)-JVS(2690)*X(194)-JVS(2691)*X(195)-JVS(2692)*X(196)&
             &-JVS(2693)*X(197)-JVS(2694)*X(198)-JVS(2695)*X(199)-JVS(2696)*X(201)-JVS(2697)*X(202)-JVS(2698)*X(203)&
             &-JVS(2699)*X(204)-JVS(2700)*X(205)-JVS(2701)*X(206)-JVS(2702)*X(207)-JVS(2703)*X(208)-JVS(2704)*X(209)&
             &-JVS(2705)*X(210)-JVS(2706)*X(211)-JVS(2707)*X(212)-JVS(2708)*X(213)-JVS(2709)*X(214)-JVS(2710)*X(215)&
             &-JVS(2711)*X(216)-JVS(2712)*X(217)-JVS(2713)*X(218)-JVS(2714)*X(219)-JVS(2715)*X(220)-JVS(2716)*X(221)&
             &-JVS(2717)*X(222)-JVS(2718)*X(223)-JVS(2719)*X(224)-JVS(2720)*X(225)-JVS(2721)*X(226)
  X(228) = X(228)-JVS(2731)*X(45)-JVS(2732)*X(46)-JVS(2733)*X(52)-JVS(2734)*X(53)-JVS(2735)*X(54)-JVS(2736)*X(55)&
             &-JVS(2737)*X(56)-JVS(2738)*X(57)-JVS(2739)*X(58)-JVS(2740)*X(68)-JVS(2741)*X(69)-JVS(2742)*X(73)-JVS(2743)&
             &*X(80)-JVS(2744)*X(82)-JVS(2745)*X(84)-JVS(2746)*X(85)-JVS(2747)*X(87)-JVS(2748)*X(98)-JVS(2749)*X(143)&
             &-JVS(2750)*X(149)-JVS(2751)*X(151)-JVS(2752)*X(176)-JVS(2753)*X(184)-JVS(2754)*X(186)-JVS(2755)*X(196)&
             &-JVS(2756)*X(197)-JVS(2757)*X(199)-JVS(2758)*X(202)-JVS(2759)*X(203)-JVS(2760)*X(205)-JVS(2761)*X(210)&
             &-JVS(2762)*X(211)-JVS(2763)*X(214)-JVS(2764)*X(215)-JVS(2765)*X(216)-JVS(2766)*X(217)-JVS(2767)*X(218)&
             &-JVS(2768)*X(219)-JVS(2769)*X(220)-JVS(2770)*X(221)-JVS(2771)*X(222)-JVS(2772)*X(223)-JVS(2773)*X(224)&
             &-JVS(2774)*X(225)-JVS(2775)*X(226)-JVS(2776)*X(227)
  X(229) = X(229)-JVS(2785)*X(78)-JVS(2786)*X(91)-JVS(2787)*X(92)-JVS(2788)*X(95)-JVS(2789)*X(99)-JVS(2790)*X(104)&
             &-JVS(2791)*X(119)-JVS(2792)*X(132)-JVS(2793)*X(134)-JVS(2794)*X(135)-JVS(2795)*X(136)-JVS(2796)*X(137)&
             &-JVS(2797)*X(138)-JVS(2798)*X(141)-JVS(2799)*X(142)-JVS(2800)*X(144)-JVS(2801)*X(145)-JVS(2802)*X(147)&
             &-JVS(2803)*X(148)-JVS(2804)*X(153)-JVS(2805)*X(154)-JVS(2806)*X(155)-JVS(2807)*X(156)-JVS(2808)*X(158)&
             &-JVS(2809)*X(159)-JVS(2810)*X(160)-JVS(2811)*X(162)-JVS(2812)*X(163)-JVS(2813)*X(167)-JVS(2814)*X(169)&
             &-JVS(2815)*X(172)-JVS(2816)*X(174)-JVS(2817)*X(178)-JVS(2818)*X(180)-JVS(2819)*X(181)-JVS(2820)*X(182)&
             &-JVS(2821)*X(183)-JVS(2822)*X(184)-JVS(2823)*X(187)-JVS(2824)*X(188)-JVS(2825)*X(189)-JVS(2826)*X(190)&
             &-JVS(2827)*X(191)-JVS(2828)*X(192)-JVS(2829)*X(193)-JVS(2830)*X(195)-JVS(2831)*X(197)-JVS(2832)*X(198)&
             &-JVS(2833)*X(199)-JVS(2834)*X(200)-JVS(2835)*X(201)-JVS(2836)*X(202)-JVS(2837)*X(203)-JVS(2838)*X(205)&
             &-JVS(2839)*X(206)-JVS(2840)*X(207)-JVS(2841)*X(208)-JVS(2842)*X(209)-JVS(2843)*X(210)-JVS(2844)*X(211)&
             &-JVS(2845)*X(212)-JVS(2846)*X(213)-JVS(2847)*X(214)-JVS(2848)*X(215)-JVS(2849)*X(216)-JVS(2850)*X(217)&
             &-JVS(2851)*X(218)-JVS(2852)*X(219)-JVS(2853)*X(220)-JVS(2854)*X(221)-JVS(2855)*X(222)-JVS(2856)*X(223)&
             &-JVS(2857)*X(224)-JVS(2858)*X(225)-JVS(2859)*X(226)-JVS(2860)*X(227)-JVS(2861)*X(228)
  X(230) = X(230)-JVS(2869)*X(48)-JVS(2870)*X(49)-JVS(2871)*X(51)-JVS(2872)*X(68)-JVS(2873)*X(76)-JVS(2874)*X(78)&
             &-JVS(2875)*X(83)-JVS(2876)*X(86)-JVS(2877)*X(88)-JVS(2878)*X(95)-JVS(2879)*X(97)-JVS(2880)*X(99)-JVS(2881)&
             &*X(102)-JVS(2882)*X(110)-JVS(2883)*X(113)-JVS(2884)*X(119)-JVS(2885)*X(123)-JVS(2886)*X(131)-JVS(2887)*X(132)&
             &-JVS(2888)*X(133)-JVS(2889)*X(136)-JVS(2890)*X(138)-JVS(2891)*X(139)-JVS(2892)*X(140)-JVS(2893)*X(141)&
             &-JVS(2894)*X(144)-JVS(2895)*X(145)-JVS(2896)*X(147)-JVS(2897)*X(148)-JVS(2898)*X(150)-JVS(2899)*X(152)&
             &-JVS(2900)*X(153)-JVS(2901)*X(154)-JVS(2902)*X(155)-JVS(2903)*X(156)-JVS(2904)*X(157)-JVS(2905)*X(159)&
             &-JVS(2906)*X(160)-JVS(2907)*X(161)-JVS(2908)*X(162)-JVS(2909)*X(163)-JVS(2910)*X(164)-JVS(2911)*X(165)&
             &-JVS(2912)*X(166)-JVS(2913)*X(167)-JVS(2914)*X(168)-JVS(2915)*X(169)-JVS(2916)*X(171)-JVS(2917)*X(172)&
             &-JVS(2918)*X(173)-JVS(2919)*X(174)-JVS(2920)*X(175)-JVS(2921)*X(177)-JVS(2922)*X(178)-JVS(2923)*X(179)&
             &-JVS(2924)*X(180)-JVS(2925)*X(181)-JVS(2926)*X(182)-JVS(2927)*X(183)-JVS(2928)*X(184)-JVS(2929)*X(185)&
             &-JVS(2930)*X(187)-JVS(2931)*X(188)-JVS(2932)*X(189)-JVS(2933)*X(190)-JVS(2934)*X(191)-JVS(2935)*X(192)&
             &-JVS(2936)*X(193)-JVS(2937)*X(195)-JVS(2938)*X(197)-JVS(2939)*X(198)-JVS(2940)*X(199)-JVS(2941)*X(200)&
             &-JVS(2942)*X(201)-JVS(2943)*X(202)-JVS(2944)*X(203)-JVS(2945)*X(204)-JVS(2946)*X(205)-JVS(2947)*X(206)&
             &-JVS(2948)*X(207)-JVS(2949)*X(208)-JVS(2950)*X(209)-JVS(2951)*X(210)-JVS(2952)*X(211)-JVS(2953)*X(212)&
             &-JVS(2954)*X(213)-JVS(2955)*X(214)-JVS(2956)*X(215)-JVS(2957)*X(216)-JVS(2958)*X(217)-JVS(2959)*X(218)&
             &-JVS(2960)*X(219)-JVS(2961)*X(220)-JVS(2962)*X(221)-JVS(2963)*X(222)-JVS(2964)*X(223)-JVS(2965)*X(224)&
             &-JVS(2966)*X(225)-JVS(2967)*X(226)-JVS(2968)*X(227)-JVS(2969)*X(228)-JVS(2970)*X(229)
  X(231) = X(231)-JVS(2977)*X(118)-JVS(2978)*X(122)-JVS(2979)*X(125)-JVS(2980)*X(134)-JVS(2981)*X(135)-JVS(2982)*X(136)&
             &-JVS(2983)*X(142)-JVS(2984)*X(143)-JVS(2985)*X(150)-JVS(2986)*X(151)-JVS(2987)*X(162)-JVS(2988)*X(167)&
             &-JVS(2989)*X(174)-JVS(2990)*X(178)-JVS(2991)*X(179)-JVS(2992)*X(180)-JVS(2993)*X(182)-JVS(2994)*X(183)&
             &-JVS(2995)*X(184)-JVS(2996)*X(186)-JVS(2997)*X(188)-JVS(2998)*X(189)-JVS(2999)*X(191)-JVS(3000)*X(193)&
             &-JVS(3001)*X(198)-JVS(3002)*X(199)-JVS(3003)*X(202)-JVS(3004)*X(203)-JVS(3005)*X(205)-JVS(3006)*X(210)&
             &-JVS(3007)*X(211)-JVS(3008)*X(212)-JVS(3009)*X(213)-JVS(3010)*X(214)-JVS(3011)*X(215)-JVS(3012)*X(216)&
             &-JVS(3013)*X(217)-JVS(3014)*X(218)-JVS(3015)*X(219)-JVS(3016)*X(220)-JVS(3017)*X(221)-JVS(3018)*X(222)&
             &-JVS(3019)*X(223)-JVS(3020)*X(224)-JVS(3021)*X(225)-JVS(3022)*X(226)-JVS(3023)*X(227)-JVS(3024)*X(228)&
             &-JVS(3025)*X(229)-JVS(3026)*X(230)
  X(232) = X(232)-JVS(3032)*X(63)-JVS(3033)*X(64)-JVS(3034)*X(70)-JVS(3035)*X(75)-JVS(3036)*X(77)-JVS(3037)*X(78)&
             &-JVS(3038)*X(81)-JVS(3039)*X(89)-JVS(3040)*X(90)-JVS(3041)*X(91)-JVS(3042)*X(93)-JVS(3043)*X(94)-JVS(3044)&
             &*X(95)-JVS(3045)*X(100)-JVS(3046)*X(101)-JVS(3047)*X(102)-JVS(3048)*X(105)-JVS(3049)*X(106)-JVS(3050)*X(107)&
             &-JVS(3051)*X(110)-JVS(3052)*X(112)-JVS(3053)*X(113)-JVS(3054)*X(114)-JVS(3055)*X(117)-JVS(3056)*X(118)&
             &-JVS(3057)*X(120)-JVS(3058)*X(121)-JVS(3059)*X(123)-JVS(3060)*X(124)-JVS(3061)*X(127)-JVS(3062)*X(128)&
             &-JVS(3063)*X(129)-JVS(3064)*X(130)-JVS(3065)*X(131)-JVS(3066)*X(133)-JVS(3067)*X(134)-JVS(3068)*X(135)&
             &-JVS(3069)*X(139)-JVS(3070)*X(140)-JVS(3071)*X(141)-JVS(3072)*X(142)-JVS(3073)*X(143)-JVS(3074)*X(145)&
             &-JVS(3075)*X(146)-JVS(3076)*X(150)-JVS(3077)*X(151)-JVS(3078)*X(152)-JVS(3079)*X(154)-JVS(3080)*X(157)&
             &-JVS(3081)*X(158)-JVS(3082)*X(161)-JVS(3083)*X(164)-JVS(3084)*X(166)-JVS(3085)*X(167)-JVS(3086)*X(168)&
             &-JVS(3087)*X(169)-JVS(3088)*X(170)-JVS(3089)*X(171)-JVS(3090)*X(172)-JVS(3091)*X(173)-JVS(3092)*X(174)&
             &-JVS(3093)*X(175)-JVS(3094)*X(176)-JVS(3095)*X(177)-JVS(3096)*X(178)-JVS(3097)*X(179)-JVS(3098)*X(180)&
             &-JVS(3099)*X(181)-JVS(3100)*X(182)-JVS(3101)*X(183)-JVS(3102)*X(184)-JVS(3103)*X(185)-JVS(3104)*X(187)&
             &-JVS(3105)*X(188)-JVS(3106)*X(189)-JVS(3107)*X(191)-JVS(3108)*X(192)-JVS(3109)*X(193)-JVS(3110)*X(195)&
             &-JVS(3111)*X(197)-JVS(3112)*X(198)-JVS(3113)*X(200)-JVS(3114)*X(201)-JVS(3115)*X(202)-JVS(3116)*X(203)&
             &-JVS(3117)*X(204)-JVS(3118)*X(205)-JVS(3119)*X(206)-JVS(3120)*X(207)-JVS(3121)*X(208)-JVS(3122)*X(209)&
             &-JVS(3123)*X(210)-JVS(3124)*X(211)-JVS(3125)*X(212)-JVS(3126)*X(213)-JVS(3127)*X(214)-JVS(3128)*X(215)&
             &-JVS(3129)*X(216)-JVS(3130)*X(217)-JVS(3131)*X(218)-JVS(3132)*X(219)-JVS(3133)*X(220)-JVS(3134)*X(221)&
             &-JVS(3135)*X(222)-JVS(3136)*X(223)-JVS(3137)*X(224)-JVS(3138)*X(225)-JVS(3139)*X(226)-JVS(3140)*X(227)&
             &-JVS(3141)*X(228)-JVS(3142)*X(229)-JVS(3143)*X(230)-JVS(3144)*X(231)
  X(233) = X(233)-JVS(3149)*X(52)-JVS(3150)*X(53)-JVS(3151)*X(54)-JVS(3152)*X(55)-JVS(3153)*X(56)-JVS(3154)*X(57)&
             &-JVS(3155)*X(58)-JVS(3156)*X(79)-JVS(3157)*X(82)-JVS(3158)*X(84)-JVS(3159)*X(85)-JVS(3160)*X(87)-JVS(3161)&
             &*X(96)-JVS(3162)*X(98)-JVS(3163)*X(149)-JVS(3164)*X(184)-JVS(3165)*X(196)-JVS(3166)*X(199)-JVS(3167)*X(204)&
             &-JVS(3168)*X(205)-JVS(3169)*X(206)-JVS(3170)*X(207)-JVS(3171)*X(210)-JVS(3172)*X(212)-JVS(3173)*X(213)&
             &-JVS(3174)*X(215)-JVS(3175)*X(217)-JVS(3176)*X(218)-JVS(3177)*X(219)-JVS(3178)*X(220)-JVS(3179)*X(221)&
             &-JVS(3180)*X(222)-JVS(3181)*X(223)-JVS(3182)*X(224)-JVS(3183)*X(225)-JVS(3184)*X(226)-JVS(3185)*X(227)&
             &-JVS(3186)*X(228)-JVS(3187)*X(229)-JVS(3188)*X(230)-JVS(3189)*X(231)-JVS(3190)*X(232)
  X(234) = X(234)-JVS(3194)*X(39)-JVS(3195)*X(43)-JVS(3196)*X(44)-JVS(3197)*X(60)-JVS(3198)*X(65)-JVS(3199)*X(66)&
             &-JVS(3200)*X(69)-JVS(3201)*X(71)-JVS(3202)*X(72)-JVS(3203)*X(73)-JVS(3204)*X(75)-JVS(3205)*X(77)-JVS(3206)&
             &*X(79)-JVS(3207)*X(80)-JVS(3208)*X(81)-JVS(3209)*X(82)-JVS(3210)*X(83)-JVS(3211)*X(84)-JVS(3212)*X(85)&
             &-JVS(3213)*X(87)-JVS(3214)*X(89)-JVS(3215)*X(90)-JVS(3216)*X(92)-JVS(3217)*X(93)-JVS(3218)*X(94)-JVS(3219)&
             &*X(95)-JVS(3220)*X(97)-JVS(3221)*X(98)-JVS(3222)*X(100)-JVS(3223)*X(101)-JVS(3224)*X(102)-JVS(3225)*X(103)&
             &-JVS(3226)*X(104)-JVS(3227)*X(105)-JVS(3228)*X(106)-JVS(3229)*X(107)-JVS(3230)*X(109)-JVS(3231)*X(110)&
             &-JVS(3232)*X(111)-JVS(3233)*X(112)-JVS(3234)*X(113)-JVS(3235)*X(114)-JVS(3236)*X(115)-JVS(3237)*X(116)&
             &-JVS(3238)*X(117)-JVS(3239)*X(118)-JVS(3240)*X(119)-JVS(3241)*X(120)-JVS(3242)*X(121)-JVS(3243)*X(122)&
             &-JVS(3244)*X(123)-JVS(3245)*X(124)-JVS(3246)*X(125)-JVS(3247)*X(126)-JVS(3248)*X(127)-JVS(3249)*X(128)&
             &-JVS(3250)*X(129)-JVS(3251)*X(130)-JVS(3252)*X(131)-JVS(3253)*X(132)-JVS(3254)*X(133)-JVS(3255)*X(134)&
             &-JVS(3256)*X(135)-JVS(3257)*X(136)-JVS(3258)*X(137)-JVS(3259)*X(139)-JVS(3260)*X(140)-JVS(3261)*X(141)&
             &-JVS(3262)*X(142)-JVS(3263)*X(143)-JVS(3264)*X(144)-JVS(3265)*X(145)-JVS(3266)*X(146)-JVS(3267)*X(147)&
             &-JVS(3268)*X(148)-JVS(3269)*X(149)-JVS(3270)*X(150)-JVS(3271)*X(151)-JVS(3272)*X(152)-JVS(3273)*X(153)&
             &-JVS(3274)*X(154)-JVS(3275)*X(155)-JVS(3276)*X(156)-JVS(3277)*X(157)-JVS(3278)*X(158)-JVS(3279)*X(159)&
             &-JVS(3280)*X(160)-JVS(3281)*X(161)-JVS(3282)*X(162)-JVS(3283)*X(163)-JVS(3284)*X(164)-JVS(3285)*X(165)&
             &-JVS(3286)*X(166)-JVS(3287)*X(167)-JVS(3288)*X(168)-JVS(3289)*X(169)-JVS(3290)*X(170)-JVS(3291)*X(171)&
             &-JVS(3292)*X(172)-JVS(3293)*X(173)-JVS(3294)*X(174)-JVS(3295)*X(175)-JVS(3296)*X(176)-JVS(3297)*X(177)&
             &-JVS(3298)*X(178)-JVS(3299)*X(179)-JVS(3300)*X(180)-JVS(3301)*X(181)-JVS(3302)*X(182)-JVS(3303)*X(183)&
             &-JVS(3304)*X(184)-JVS(3305)*X(185)-JVS(3306)*X(186)-JVS(3307)*X(187)-JVS(3308)*X(188)-JVS(3309)*X(189)&
             &-JVS(3310)*X(190)-JVS(3311)*X(191)-JVS(3312)*X(192)-JVS(3313)*X(193)-JVS(3314)*X(194)-JVS(3315)*X(195)&
             &-JVS(3316)*X(196)-JVS(3317)*X(197)-JVS(3318)*X(198)-JVS(3319)*X(199)-JVS(3320)*X(200)-JVS(3321)*X(201)&
             &-JVS(3322)*X(202)-JVS(3323)*X(203)-JVS(3324)*X(204)-JVS(3325)*X(205)-JVS(3326)*X(206)-JVS(3327)*X(207)&
             &-JVS(3328)*X(208)-JVS(3329)*X(209)-JVS(3330)*X(210)-JVS(3331)*X(211)-JVS(3332)*X(212)-JVS(3333)*X(213)&
             &-JVS(3334)*X(214)-JVS(3335)*X(215)-JVS(3336)*X(216)-JVS(3337)*X(217)-JVS(3338)*X(218)-JVS(3339)*X(219)&
             &-JVS(3340)*X(220)-JVS(3341)*X(221)-JVS(3342)*X(222)-JVS(3343)*X(223)-JVS(3344)*X(224)-JVS(3345)*X(225)&
             &-JVS(3346)*X(226)-JVS(3347)*X(227)-JVS(3348)*X(228)-JVS(3349)*X(229)-JVS(3350)*X(230)-JVS(3351)*X(231)&
             &-JVS(3352)*X(232)-JVS(3353)*X(233)
  X(235) = X(235)-JVS(3356)*X(43)-JVS(3357)*X(44)-JVS(3358)*X(71)-JVS(3359)*X(82)-JVS(3360)*X(84)-JVS(3361)*X(85)&
             &-JVS(3362)*X(87)-JVS(3363)*X(93)-JVS(3364)*X(94)-JVS(3365)*X(95)-JVS(3366)*X(97)-JVS(3367)*X(111)-JVS(3368)&
             &*X(115)-JVS(3369)*X(121)-JVS(3370)*X(124)-JVS(3371)*X(128)-JVS(3372)*X(129)-JVS(3373)*X(132)-JVS(3374)*X(137)&
             &-JVS(3375)*X(143)-JVS(3376)*X(144)-JVS(3377)*X(147)-JVS(3378)*X(151)-JVS(3379)*X(153)-JVS(3380)*X(155)&
             &-JVS(3381)*X(156)-JVS(3382)*X(160)-JVS(3383)*X(163)-JVS(3384)*X(170)-JVS(3385)*X(172)-JVS(3386)*X(174)&
             &-JVS(3387)*X(176)-JVS(3388)*X(177)-JVS(3389)*X(178)-JVS(3390)*X(181)-JVS(3391)*X(184)-JVS(3392)*X(185)&
             &-JVS(3393)*X(186)-JVS(3394)*X(187)-JVS(3395)*X(188)-JVS(3396)*X(190)-JVS(3397)*X(191)-JVS(3398)*X(192)&
             &-JVS(3399)*X(193)-JVS(3400)*X(194)-JVS(3401)*X(195)-JVS(3402)*X(196)-JVS(3403)*X(197)-JVS(3404)*X(198)&
             &-JVS(3405)*X(199)-JVS(3406)*X(200)-JVS(3407)*X(201)-JVS(3408)*X(202)-JVS(3409)*X(203)-JVS(3410)*X(204)&
             &-JVS(3411)*X(205)-JVS(3412)*X(206)-JVS(3413)*X(207)-JVS(3414)*X(208)-JVS(3415)*X(209)-JVS(3416)*X(210)&
             &-JVS(3417)*X(211)-JVS(3418)*X(212)-JVS(3419)*X(213)-JVS(3420)*X(214)-JVS(3421)*X(215)-JVS(3422)*X(216)&
             &-JVS(3423)*X(217)-JVS(3424)*X(218)-JVS(3425)*X(219)-JVS(3426)*X(220)-JVS(3427)*X(221)-JVS(3428)*X(222)&
             &-JVS(3429)*X(223)-JVS(3430)*X(224)-JVS(3431)*X(225)-JVS(3432)*X(226)-JVS(3433)*X(227)-JVS(3434)*X(228)&
             &-JVS(3435)*X(229)-JVS(3436)*X(230)-JVS(3437)*X(231)-JVS(3438)*X(232)-JVS(3439)*X(233)-JVS(3440)*X(234)
  X(235) = X(235)/JVS(3441)
  X(234) = (X(234)-JVS(3355)*X(235))/(JVS(3354))
  X(233) = (X(233)-JVS(3192)*X(234)-JVS(3193)*X(235))/(JVS(3191))
  X(232) = (X(232)-JVS(3146)*X(233)-JVS(3147)*X(234)-JVS(3148)*X(235))/(JVS(3145))
  X(231) = (X(231)-JVS(3028)*X(232)-JVS(3029)*X(233)-JVS(3030)*X(234)-JVS(3031)*X(235))/(JVS(3027))
  X(230) = (X(230)-JVS(2972)*X(231)-JVS(2973)*X(232)-JVS(2974)*X(233)-JVS(2975)*X(234)-JVS(2976)*X(235))/(JVS(2971))
  X(229) = (X(229)-JVS(2863)*X(230)-JVS(2864)*X(231)-JVS(2865)*X(232)-JVS(2866)*X(233)-JVS(2867)*X(234)-JVS(2868)&
             &*X(235))/(JVS(2862))
  X(228) = (X(228)-JVS(2778)*X(229)-JVS(2779)*X(230)-JVS(2780)*X(231)-JVS(2781)*X(232)-JVS(2782)*X(233)-JVS(2783)*X(234)&
             &-JVS(2784)*X(235))/(JVS(2777))
  X(227) = (X(227)-JVS(2723)*X(228)-JVS(2724)*X(229)-JVS(2725)*X(230)-JVS(2726)*X(231)-JVS(2727)*X(232)-JVS(2728)*X(233)&
             &-JVS(2729)*X(234)-JVS(2730)*X(235))/(JVS(2722))
  X(226) = (X(226)-JVS(2634)*X(227)-JVS(2635)*X(228)-JVS(2636)*X(229)-JVS(2637)*X(230)-JVS(2638)*X(231)-JVS(2639)*X(232)&
             &-JVS(2640)*X(233)-JVS(2641)*X(234)-JVS(2642)*X(235))/(JVS(2633))
  X(225) = (X(225)-JVS(2589)*X(226)-JVS(2590)*X(227)-JVS(2591)*X(228)-JVS(2592)*X(229)-JVS(2593)*X(230)-JVS(2594)*X(231)&
             &-JVS(2595)*X(232)-JVS(2596)*X(233)-JVS(2597)*X(234)-JVS(2598)*X(235))/(JVS(2588))
  X(224) = (X(224)-JVS(2527)*X(225)-JVS(2528)*X(226)-JVS(2529)*X(227)-JVS(2530)*X(228)-JVS(2531)*X(229)-JVS(2532)*X(230)&
             &-JVS(2533)*X(231)-JVS(2534)*X(232)-JVS(2535)*X(233)-JVS(2536)*X(234)-JVS(2537)*X(235))/(JVS(2526))
  X(223) = (X(223)-JVS(2493)*X(224)-JVS(2494)*X(225)-JVS(2495)*X(226)-JVS(2496)*X(227)-JVS(2497)*X(228)-JVS(2498)*X(229)&
             &-JVS(2499)*X(230)-JVS(2500)*X(231)-JVS(2501)*X(232)-JVS(2502)*X(233)-JVS(2503)*X(234)-JVS(2504)*X(235))&
             &/(JVS(2492))
  X(222) = (X(222)-JVS(2410)*X(223)-JVS(2411)*X(224)-JVS(2412)*X(225)-JVS(2413)*X(226)-JVS(2414)*X(227)-JVS(2415)*X(228)&
             &-JVS(2416)*X(229)-JVS(2417)*X(230)-JVS(2418)*X(231)-JVS(2419)*X(232)-JVS(2420)*X(233)-JVS(2421)*X(234)&
             &-JVS(2422)*X(235))/(JVS(2409))
  X(221) = (X(221)-JVS(2358)*X(222)-JVS(2359)*X(223)-JVS(2360)*X(226)-JVS(2361)*X(227)-JVS(2362)*X(228)-JVS(2363)*X(229)&
             &-JVS(2364)*X(230)-JVS(2365)*X(231)-JVS(2366)*X(232)-JVS(2367)*X(233)-JVS(2368)*X(234)-JVS(2369)*X(235))&
             &/(JVS(2357))
  X(220) = (X(220)-JVS(2288)*X(221)-JVS(2289)*X(222)-JVS(2290)*X(223)-JVS(2291)*X(226)-JVS(2292)*X(227)-JVS(2293)*X(228)&
             &-JVS(2294)*X(229)-JVS(2295)*X(230)-JVS(2296)*X(231)-JVS(2297)*X(232)-JVS(2298)*X(233)-JVS(2299)*X(234)&
             &-JVS(2300)*X(235))/(JVS(2287))
  X(219) = (X(219)-JVS(2218)*X(220)-JVS(2219)*X(221)-JVS(2220)*X(222)-JVS(2221)*X(223)-JVS(2222)*X(227)-JVS(2223)*X(228)&
             &-JVS(2224)*X(229)-JVS(2225)*X(230)-JVS(2226)*X(231)-JVS(2227)*X(232)-JVS(2228)*X(234)-JVS(2229)*X(235))&
             &/(JVS(2217))
  X(218) = (X(218)-JVS(2187)*X(219)-JVS(2188)*X(220)-JVS(2189)*X(221)-JVS(2190)*X(222)-JVS(2191)*X(223)-JVS(2192)*X(227)&
             &-JVS(2193)*X(229)-JVS(2194)*X(230)-JVS(2195)*X(231)-JVS(2196)*X(232)-JVS(2197)*X(234)-JVS(2198)*X(235))&
             &/(JVS(2186))
  X(217) = (X(217)-JVS(2123)*X(218)-JVS(2124)*X(219)-JVS(2125)*X(220)-JVS(2126)*X(221)-JVS(2127)*X(223)-JVS(2128)*X(227)&
             &-JVS(2129)*X(229)-JVS(2130)*X(230)-JVS(2131)*X(231)-JVS(2132)*X(232)-JVS(2133)*X(234)-JVS(2134)*X(235))&
             &/(JVS(2122))
  X(216) = (X(216)-JVS(2101)*X(217)-JVS(2102)*X(218)-JVS(2103)*X(219)-JVS(2104)*X(220)-JVS(2105)*X(221)-JVS(2106)*X(222)&
             &-JVS(2107)*X(223)-JVS(2108)*X(227)-JVS(2109)*X(229)-JVS(2110)*X(230)-JVS(2111)*X(231)-JVS(2112)*X(232)&
             &-JVS(2113)*X(234)-JVS(2114)*X(235))/(JVS(2100))
  X(215) = (X(215)-JVS(2065)*X(218)-JVS(2066)*X(219)-JVS(2067)*X(220)-JVS(2068)*X(221)-JVS(2069)*X(223)-JVS(2070)*X(227)&
             &-JVS(2071)*X(229)-JVS(2072)*X(230)-JVS(2073)*X(231)-JVS(2074)*X(232)-JVS(2075)*X(234)-JVS(2076)*X(235))&
             &/(JVS(2064))
  X(214) = (X(214)-JVS(2036)*X(215)-JVS(2037)*X(216)-JVS(2038)*X(217)-JVS(2039)*X(218)-JVS(2040)*X(219)-JVS(2041)*X(220)&
             &-JVS(2042)*X(221)-JVS(2043)*X(222)-JVS(2044)*X(223)-JVS(2045)*X(226)-JVS(2046)*X(227)-JVS(2047)*X(228)&
             &-JVS(2048)*X(229)-JVS(2049)*X(230)-JVS(2050)*X(231)-JVS(2051)*X(232)-JVS(2052)*X(233)-JVS(2053)*X(234)&
             &-JVS(2054)*X(235))/(JVS(2035))
  X(213) = (X(213)-JVS(1953)*X(215)-JVS(1954)*X(217)-JVS(1955)*X(218)-JVS(1956)*X(219)-JVS(1957)*X(220)-JVS(1958)*X(221)&
             &-JVS(1959)*X(223)-JVS(1960)*X(227)-JVS(1961)*X(229)-JVS(1962)*X(230)-JVS(1963)*X(231)-JVS(1964)*X(232)&
             &-JVS(1965)*X(234)-JVS(1966)*X(235))/(JVS(1952))
  X(212) = (X(212)-JVS(1910)*X(213)-JVS(1911)*X(215)-JVS(1912)*X(217)-JVS(1913)*X(218)-JVS(1914)*X(219)-JVS(1915)*X(220)&
             &-JVS(1916)*X(221)-JVS(1917)*X(222)-JVS(1918)*X(223)-JVS(1919)*X(227)-JVS(1920)*X(229)-JVS(1921)*X(230)&
             &-JVS(1922)*X(231)-JVS(1923)*X(232)-JVS(1924)*X(234)-JVS(1925)*X(235))/(JVS(1909))
  X(211) = (X(211)-JVS(1859)*X(217)-JVS(1860)*X(218)-JVS(1861)*X(221)-JVS(1862)*X(222)-JVS(1863)*X(223)-JVS(1864)*X(227)&
             &-JVS(1865)*X(229)-JVS(1866)*X(231)-JVS(1867)*X(232)-JVS(1868)*X(234))/(JVS(1858))
  X(210) = (X(210)-JVS(1841)*X(222)-JVS(1842)*X(223)-JVS(1843)*X(224)-JVS(1844)*X(225)-JVS(1845)*X(226)-JVS(1846)*X(227)&
             &-JVS(1847)*X(228)-JVS(1848)*X(229)-JVS(1849)*X(230)-JVS(1850)*X(231)-JVS(1851)*X(232)-JVS(1852)*X(233)&
             &-JVS(1853)*X(234)-JVS(1854)*X(235))/(JVS(1840))
  X(209) = (X(209)-JVS(1816)*X(215)-JVS(1817)*X(218)-JVS(1818)*X(219)-JVS(1819)*X(220)-JVS(1820)*X(221)-JVS(1821)*X(223)&
             &-JVS(1822)*X(227)-JVS(1823)*X(229)-JVS(1824)*X(230)-JVS(1825)*X(231)-JVS(1826)*X(232)-JVS(1827)*X(234)&
             &-JVS(1828)*X(235))/(JVS(1815))
  X(208) = (X(208)-JVS(1795)*X(209)-JVS(1796)*X(211)-JVS(1797)*X(213)-JVS(1798)*X(215)-JVS(1799)*X(218)-JVS(1800)*X(219)&
             &-JVS(1801)*X(220)-JVS(1802)*X(221)-JVS(1803)*X(222)-JVS(1804)*X(223)-JVS(1805)*X(227)-JVS(1806)*X(229)&
             &-JVS(1807)*X(230)-JVS(1808)*X(231)-JVS(1809)*X(232)-JVS(1810)*X(234)-JVS(1811)*X(235))/(JVS(1794))
  X(207) = (X(207)-JVS(1746)*X(213)-JVS(1747)*X(215)-JVS(1748)*X(218)-JVS(1749)*X(221)-JVS(1750)*X(223)-JVS(1751)*X(227)&
             &-JVS(1752)*X(229)-JVS(1753)*X(231)-JVS(1754)*X(232)-JVS(1755)*X(234))/(JVS(1745))
  X(206) = (X(206)-JVS(1724)*X(207)-JVS(1725)*X(218)-JVS(1726)*X(221)-JVS(1727)*X(223)-JVS(1728)*X(227)-JVS(1729)*X(229)&
             &-JVS(1730)*X(231)-JVS(1731)*X(232)-JVS(1732)*X(234))/(JVS(1723))
  X(205) = (X(205)-JVS(1701)*X(218)-JVS(1702)*X(221)-JVS(1703)*X(223)-JVS(1704)*X(227)-JVS(1705)*X(229)-JVS(1706)*X(231)&
             &-JVS(1707)*X(232)-JVS(1708)*X(234))/(JVS(1700))
  X(204) = (X(204)-JVS(1679)*X(205)-JVS(1680)*X(206)-JVS(1681)*X(207)-JVS(1682)*X(212)-JVS(1683)*X(213)-JVS(1684)*X(217)&
             &-JVS(1685)*X(218)-JVS(1686)*X(221)-JVS(1687)*X(222)-JVS(1688)*X(223)-JVS(1689)*X(227)-JVS(1690)*X(229)&
             &-JVS(1691)*X(230)-JVS(1692)*X(231)-JVS(1693)*X(232)-JVS(1694)*X(234))/(JVS(1678))
  X(203) = (X(203)-JVS(1665)*X(218)-JVS(1666)*X(221)-JVS(1667)*X(223)-JVS(1668)*X(227)-JVS(1669)*X(229)-JVS(1670)*X(231)&
             &-JVS(1671)*X(232)-JVS(1672)*X(234))/(JVS(1664))
  X(202) = (X(202)-JVS(1651)*X(203)-JVS(1652)*X(205)-JVS(1653)*X(218)-JVS(1654)*X(221)-JVS(1655)*X(223)-JVS(1656)*X(229)&
             &-JVS(1657)*X(231)-JVS(1658)*X(232)-JVS(1659)*X(234))/(JVS(1650))
  X(201) = (X(201)-JVS(1634)*X(206)-JVS(1635)*X(207)-JVS(1636)*X(218)-JVS(1637)*X(221)-JVS(1638)*X(222)-JVS(1639)*X(223)&
             &-JVS(1640)*X(227)-JVS(1641)*X(229)-JVS(1642)*X(231)-JVS(1643)*X(232)-JVS(1644)*X(234))/(JVS(1633))
  X(200) = (X(200)-JVS(1607)*X(201)-JVS(1608)*X(202)-JVS(1609)*X(203)-JVS(1610)*X(205)-JVS(1611)*X(208)-JVS(1612)*X(209)&
             &-JVS(1613)*X(211)-JVS(1614)*X(213)-JVS(1615)*X(215)-JVS(1616)*X(217)-JVS(1617)*X(218)-JVS(1618)*X(219)&
             &-JVS(1619)*X(220)-JVS(1620)*X(221)-JVS(1621)*X(222)-JVS(1622)*X(223)-JVS(1623)*X(227)-JVS(1624)*X(229)&
             &-JVS(1625)*X(230)-JVS(1626)*X(231)-JVS(1627)*X(232)-JVS(1628)*X(234)-JVS(1629)*X(235))/(JVS(1606))
  X(199) = (X(199)-JVS(1566)*X(210)-JVS(1567)*X(222)-JVS(1568)*X(224)-JVS(1569)*X(225)-JVS(1570)*X(227)-JVS(1571)*X(228)&
             &-JVS(1572)*X(230)-JVS(1573)*X(231)-JVS(1574)*X(232)-JVS(1575)*X(233)-JVS(1576)*X(234)-JVS(1577)*X(235))&
             &/(JVS(1565))
  X(198) = (X(198)-JVS(1555)*X(205)-JVS(1556)*X(218)-JVS(1557)*X(221)-JVS(1558)*X(223)-JVS(1559)*X(229)-JVS(1560)*X(231)&
             &-JVS(1561)*X(234))/(JVS(1554))
  X(197) = (X(197)-JVS(1542)*X(211)-JVS(1543)*X(215)-JVS(1544)*X(217)-JVS(1545)*X(219)-JVS(1546)*X(220)-JVS(1547)*X(223)&
             &-JVS(1548)*X(227)-JVS(1549)*X(229)-JVS(1550)*X(230)-JVS(1551)*X(231)-JVS(1552)*X(234)-JVS(1553)*X(235))&
             &/(JVS(1541))
  X(196) = (X(196)-JVS(1525)*X(199)-JVS(1526)*X(210)-JVS(1527)*X(221)-JVS(1528)*X(223)-JVS(1529)*X(224)-JVS(1530)*X(225)&
             &-JVS(1531)*X(226)-JVS(1532)*X(227)-JVS(1533)*X(229)-JVS(1534)*X(230)-JVS(1535)*X(231)-JVS(1536)*X(232)&
             &-JVS(1537)*X(233)-JVS(1538)*X(234)-JVS(1539)*X(235))/(JVS(1524))
  X(195) = (X(195)-JVS(1509)*X(217)-JVS(1510)*X(218)-JVS(1511)*X(221)-JVS(1512)*X(223)-JVS(1513)*X(227)-JVS(1514)*X(229)&
             &-JVS(1515)*X(231)-JVS(1516)*X(232)-JVS(1517)*X(234))/(JVS(1508))
  X(194) = (X(194)-JVS(1480)*X(195)-JVS(1481)*X(201)-JVS(1482)*X(202)-JVS(1483)*X(203)-JVS(1484)*X(204)-JVS(1485)*X(205)&
             &-JVS(1486)*X(206)-JVS(1487)*X(207)-JVS(1488)*X(208)-JVS(1489)*X(209)-JVS(1490)*X(211)-JVS(1491)*X(213)&
             &-JVS(1492)*X(215)-JVS(1493)*X(218)-JVS(1494)*X(219)-JVS(1495)*X(220)-JVS(1496)*X(221)-JVS(1497)*X(222)&
             &-JVS(1498)*X(223)-JVS(1499)*X(227)-JVS(1500)*X(229)-JVS(1501)*X(230)-JVS(1502)*X(231)-JVS(1503)*X(232)&
             &-JVS(1504)*X(234)-JVS(1505)*X(235))/(JVS(1479))
  X(193) = (X(193)-JVS(1454)*X(215)-JVS(1455)*X(218)-JVS(1456)*X(221)-JVS(1457)*X(223)-JVS(1458)*X(229)-JVS(1459)*X(230)&
             &-JVS(1460)*X(231)-JVS(1461)*X(232)-JVS(1462)*X(234))/(JVS(1453))
  X(192) = (X(192)-JVS(1435)*X(195)-JVS(1436)*X(198)-JVS(1437)*X(202)-JVS(1438)*X(203)-JVS(1439)*X(205)-JVS(1440)*X(218)&
             &-JVS(1441)*X(219)-JVS(1442)*X(220)-JVS(1443)*X(221)-JVS(1444)*X(223)-JVS(1445)*X(230)-JVS(1446)*X(231)&
             &-JVS(1447)*X(232)-JVS(1448)*X(234)-JVS(1449)*X(235))/(JVS(1434))
  X(191) = (X(191)-JVS(1417)*X(203)-JVS(1418)*X(205)-JVS(1419)*X(221)-JVS(1420)*X(223)-JVS(1421)*X(231)-JVS(1422)&
             &*X(234))/(JVS(1416))
  X(190) = (X(190)-JVS(1384)*X(191)-JVS(1385)*X(192)-JVS(1386)*X(193)-JVS(1387)*X(195)-JVS(1388)*X(198)-JVS(1389)*X(199)&
             &-JVS(1390)*X(200)-JVS(1391)*X(202)-JVS(1392)*X(203)-JVS(1393)*X(207)-JVS(1394)*X(209)-JVS(1395)*X(210)&
             &-JVS(1396)*X(212)-JVS(1397)*X(213)-JVS(1398)*X(214)-JVS(1399)*X(215)-JVS(1400)*X(216)-JVS(1401)*X(218)&
             &-JVS(1402)*X(221)-JVS(1403)*X(222)-JVS(1404)*X(223)-JVS(1405)*X(224)-JVS(1406)*X(225)-JVS(1407)*X(227)&
             &-JVS(1408)*X(228)-JVS(1409)*X(229)-JVS(1410)*X(230)-JVS(1411)*X(231)-JVS(1412)*X(232)-JVS(1413)*X(233)&
             &-JVS(1414)*X(234)-JVS(1415)*X(235))/(JVS(1383))
  X(189) = (X(189)-JVS(1345)*X(202)-JVS(1346)*X(203)-JVS(1347)*X(218)-JVS(1348)*X(221)-JVS(1349)*X(223)-JVS(1350)*X(232)&
             &-JVS(1351)*X(234))/(JVS(1344))
  X(188) = (X(188)-JVS(1334)*X(218)-JVS(1335)*X(221)-JVS(1336)*X(223)-JVS(1337)*X(229)-JVS(1338)*X(231)-JVS(1339)*X(232)&
             &-JVS(1340)*X(234))/(JVS(1333))
  X(187) = (X(187)-JVS(1325)*X(191)-JVS(1326)*X(203)-JVS(1327)*X(223)-JVS(1328)*X(231)-JVS(1329)*X(232)-JVS(1330)&
             &*X(234))/(JVS(1324))
  X(186) = (X(186)-JVS(1310)*X(199)-JVS(1311)*X(210)-JVS(1312)*X(222)-JVS(1313)*X(224)-JVS(1314)*X(225)-JVS(1315)*X(228)&
             &-JVS(1316)*X(230)-JVS(1317)*X(231)-JVS(1318)*X(232)-JVS(1319)*X(234)-JVS(1320)*X(235))/(JVS(1309))
  X(185) = (X(185)-JVS(1297)*X(213)-JVS(1298)*X(218)-JVS(1299)*X(221)-JVS(1300)*X(223)-JVS(1301)*X(229)-JVS(1302)*X(231)&
             &-JVS(1303)*X(232)-JVS(1304)*X(234))/(JVS(1296))
  X(184) = (X(184)-JVS(1285)*X(210)-JVS(1286)*X(223)-JVS(1287)*X(229)-JVS(1288)*X(230)-JVS(1289)*X(231)-JVS(1290)*X(232)&
             &-JVS(1291)*X(233)-JVS(1292)*X(234))/(JVS(1284))
  X(183) = (X(183)-JVS(1270)*X(218)-JVS(1271)*X(221)-JVS(1272)*X(223)-JVS(1273)*X(229)-JVS(1274)*X(231)-JVS(1275)*X(232)&
             &-JVS(1276)*X(234))/(JVS(1269))
  X(182) = (X(182)-JVS(1257)*X(183)-JVS(1258)*X(218)-JVS(1259)*X(221)-JVS(1260)*X(223)-JVS(1261)*X(229)-JVS(1262)*X(231)&
             &-JVS(1263)*X(232)-JVS(1264)*X(234))/(JVS(1256))
  X(181) = (X(181)-JVS(1245)*X(187)-JVS(1246)*X(191)-JVS(1247)*X(203)-JVS(1248)*X(209)-JVS(1249)*X(223)-JVS(1250)*X(231)&
             &-JVS(1251)*X(232)-JVS(1252)*X(234))/(JVS(1244))
  X(180) = (X(180)-JVS(1235)*X(218)-JVS(1236)*X(221)-JVS(1237)*X(223)-JVS(1238)*X(229)-JVS(1239)*X(231)-JVS(1240)*X(232)&
             &-JVS(1241)*X(234))/(JVS(1234))
  X(179) = (X(179)-JVS(1222)*X(198)-JVS(1223)*X(212)-JVS(1224)*X(213)-JVS(1225)*X(217)-JVS(1226)*X(218)-JVS(1227)*X(221)&
             &-JVS(1228)*X(223)-JVS(1229)*X(229)-JVS(1230)*X(230)-JVS(1231)*X(232)-JVS(1232)*X(234))/(JVS(1221))
  X(178) = (X(178)-JVS(1209)*X(184)-JVS(1210)*X(210)-JVS(1211)*X(223)-JVS(1212)*X(229)-JVS(1213)*X(230)-JVS(1214)*X(231)&
             &-JVS(1215)*X(232)-JVS(1216)*X(233)-JVS(1217)*X(234))/(JVS(1208))
  X(177) = (X(177)-JVS(1185)*X(185)-JVS(1186)*X(201)-JVS(1187)*X(218)-JVS(1188)*X(221)-JVS(1189)*X(222)-JVS(1190)*X(223)&
             &-JVS(1191)*X(227)-JVS(1192)*X(232)-JVS(1193)*X(234))/(JVS(1184))
  X(176) = (X(176)-JVS(1167)*X(197)-JVS(1168)*X(202)-JVS(1169)*X(211)-JVS(1170)*X(215)-JVS(1171)*X(217)-JVS(1172)*X(219)&
             &-JVS(1173)*X(220)-JVS(1174)*X(223)-JVS(1175)*X(227)-JVS(1176)*X(228)-JVS(1177)*X(229)-JVS(1178)*X(230)&
             &-JVS(1179)*X(231)-JVS(1180)*X(232)-JVS(1181)*X(234)-JVS(1182)*X(235))/(JVS(1166))
  X(175) = (X(175)-JVS(1148)*X(193)-JVS(1149)*X(215)-JVS(1150)*X(218)-JVS(1151)*X(221)-JVS(1152)*X(223)-JVS(1153)*X(229)&
             &-JVS(1154)*X(232)-JVS(1155)*X(234))/(JVS(1147))
  X(174) = (X(174)-JVS(1141)*X(227)-JVS(1142)*X(229)-JVS(1143)*X(231)-JVS(1144)*X(234))/(JVS(1140))
  X(173) = (X(173)-JVS(1132)*X(187)-JVS(1133)*X(191)-JVS(1134)*X(207)-JVS(1135)*X(218)-JVS(1136)*X(221)-JVS(1137)*X(223)&
             &-JVS(1138)*X(232)-JVS(1139)*X(234))/(JVS(1131))
  X(172) = (X(172)-JVS(1122)*X(174)-JVS(1123)*X(219)-JVS(1124)*X(220)-JVS(1125)*X(223)-JVS(1126)*X(230)-JVS(1127)*X(231)&
             &-JVS(1128)*X(235))/(JVS(1121))
  X(171) = (X(171)-JVS(1112)*X(206)-JVS(1113)*X(207)-JVS(1114)*X(218)-JVS(1115)*X(221)-JVS(1116)*X(222)-JVS(1117)*X(223)&
             &-JVS(1118)*X(227)-JVS(1119)*X(232)-JVS(1120)*X(234))/(JVS(1111))
  X(170) = (X(170)-JVS(1092)*X(181)-JVS(1093)*X(187)-JVS(1094)*X(188)-JVS(1095)*X(191)-JVS(1096)*X(192)-JVS(1097)*X(195)&
             &-JVS(1098)*X(197)-JVS(1099)*X(203)-JVS(1100)*X(208)-JVS(1101)*X(223)-JVS(1102)*X(227)-JVS(1103)*X(229)&
             &-JVS(1104)*X(230)-JVS(1105)*X(231)-JVS(1106)*X(232)-JVS(1107)*X(234)-JVS(1108)*X(235))/(JVS(1091))
  X(169) = (X(169)-JVS(1080)*X(187)-JVS(1081)*X(191)-JVS(1082)*X(223)-JVS(1083)*X(232)-JVS(1084)*X(234))/(JVS(1079))
  X(168) = (X(168)-JVS(1070)*X(211)-JVS(1071)*X(218)-JVS(1072)*X(221)-JVS(1073)*X(222)-JVS(1074)*X(223)-JVS(1075)*X(227)&
             &-JVS(1076)*X(232)-JVS(1077)*X(234))/(JVS(1069))
  X(167) = (X(167)-JVS(1062)*X(198)-JVS(1063)*X(223)-JVS(1064)*X(229)-JVS(1065)*X(230)-JVS(1066)*X(232)-JVS(1067)&
             &*X(234))/(JVS(1061))
  X(166) = (X(166)-JVS(1055)*X(215)-JVS(1056)*X(218)-JVS(1057)*X(221)-JVS(1058)*X(223)-JVS(1059)*X(229)-JVS(1060)&
             &*X(232))/(JVS(1054))
  X(165) = (X(165)-JVS(1040)*X(166)-JVS(1041)*X(167)-JVS(1042)*X(169)-JVS(1043)*X(191)-JVS(1044)*X(198)-JVS(1045)*X(203)&
             &-JVS(1046)*X(211)-JVS(1047)*X(218)-JVS(1048)*X(221)-JVS(1049)*X(223)-JVS(1050)*X(229)-JVS(1051)*X(231)&
             &-JVS(1052)*X(232)-JVS(1053)*X(234))/(JVS(1039))
  X(164) = (X(164)-JVS(1025)*X(206)-JVS(1026)*X(207)-JVS(1027)*X(218)-JVS(1028)*X(221)-JVS(1029)*X(222)-JVS(1030)*X(223)&
             &-JVS(1031)*X(227)-JVS(1032)*X(232)-JVS(1033)*X(234))/(JVS(1024))
  X(163) = (X(163)-JVS(1015)*X(217)-JVS(1016)*X(219)-JVS(1017)*X(220)-JVS(1018)*X(223)-JVS(1019)*X(230)-JVS(1020)*X(231)&
             &-JVS(1021)*X(235))/(JVS(1014))
  X(162) = (X(162)-JVS(1003)*X(180)-JVS(1004)*X(182)-JVS(1005)*X(183)-JVS(1006)*X(188)-JVS(1007)*X(218)-JVS(1008)*X(221)&
             &-JVS(1009)*X(223)-JVS(1010)*X(229)-JVS(1011)*X(231)-JVS(1012)*X(232)-JVS(1013)*X(234))/(JVS(1002))
  X(161) = (X(161)-JVS(995)*X(211)-JVS(996)*X(218)-JVS(997)*X(221)-JVS(998)*X(223)-JVS(999)*X(229)-JVS(1000)*X(232)&
             &-JVS(1001)*X(234))/(JVS(994))
  X(160) = (X(160)-JVS(985)*X(202)-JVS(986)*X(215)-JVS(987)*X(219)-JVS(988)*X(220)-JVS(989)*X(223)-JVS(990)*X(230)&
             &-JVS(991)*X(231)-JVS(992)*X(235))/(JVS(984))
  X(159) = (X(159)-JVS(976)*X(169)-JVS(977)*X(187)-JVS(978)*X(195)-JVS(979)*X(203)-JVS(980)*X(223)-JVS(981)*X(231)&
             &-JVS(982)*X(232)-JVS(983)*X(234))/(JVS(975))
  X(158) = (X(158)-JVS(962)*X(189)-JVS(963)*X(191)-JVS(964)*X(192)-JVS(965)*X(198)-JVS(966)*X(203)-JVS(967)*X(218)&
             &-JVS(968)*X(221)-JVS(969)*X(223)-JVS(970)*X(229)-JVS(971)*X(231)-JVS(972)*X(232)-JVS(973)*X(234))/(JVS(961))
  X(157) = (X(157)-JVS(944)*X(191)-JVS(945)*X(203)-JVS(946)*X(223)-JVS(947)*X(231)-JVS(948)*X(232)-JVS(949)*X(234))&
             &/(JVS(943))
  X(156) = (X(156)-JVS(929)*X(211)-JVS(930)*X(219)-JVS(931)*X(220)-JVS(932)*X(223)-JVS(933)*X(230)-JVS(934)*X(231)&
             &-JVS(935)*X(235))/(JVS(928))
  X(155) = (X(155)-JVS(921)*X(202)-JVS(922)*X(219)-JVS(923)*X(220)-JVS(924)*X(223)-JVS(925)*X(230)-JVS(926)*X(231)&
             &-JVS(927)*X(235))/(JVS(920))
  X(154) = (X(154)-JVS(915)*X(198)-JVS(916)*X(221)-JVS(917)*X(223)-JVS(918)*X(229)-JVS(919)*X(232))/(JVS(914))
  X(153) = (X(153)-JVS(907)*X(174)-JVS(908)*X(219)-JVS(909)*X(220)-JVS(910)*X(223)-JVS(911)*X(230)-JVS(912)*X(231)&
             &-JVS(913)*X(235))/(JVS(906))
  X(152) = (X(152)-JVS(901)*X(198)-JVS(902)*X(221)-JVS(903)*X(223)-JVS(904)*X(232)-JVS(905)*X(234))/(JVS(900))
  X(151) = (X(151)-JVS(894)*X(211)-JVS(895)*X(216)-JVS(896)*X(226)-JVS(897)*X(227)-JVS(898)*X(231)-JVS(899)*X(234))&
             &/(JVS(893))
  X(150) = (X(150)-JVS(889)*X(203)-JVS(890)*X(223)-JVS(891)*X(231)-JVS(892)*X(234))/(JVS(888))
  X(149) = (X(149)-JVS(879)*X(196)-JVS(880)*X(199)-JVS(881)*X(210)-JVS(882)*X(221)-JVS(883)*X(225)-JVS(884)*X(226)&
             &-JVS(885)*X(227)-JVS(886)*X(233)-JVS(887)*X(234))/(JVS(878))
  X(148) = (X(148)-JVS(868)*X(182)-JVS(869)*X(183)-JVS(870)*X(188)-JVS(871)*X(218)-JVS(872)*X(221)-JVS(873)*X(223)&
             &-JVS(874)*X(229)-JVS(875)*X(232)-JVS(876)*X(234))/(JVS(867))
  X(147) = (X(147)-JVS(861)*X(178)-JVS(862)*X(184)-JVS(863)*X(223)-JVS(864)*X(229)-JVS(865)*X(230)-JVS(866)*X(234))&
             &/(JVS(860))
  X(146) = (X(146)-JVS(840)*X(161)-JVS(841)*X(164)-JVS(842)*X(168)-JVS(843)*X(171)-JVS(844)*X(173)-JVS(845)*X(175)&
             &-JVS(846)*X(180)-JVS(847)*X(182)-JVS(848)*X(185)-JVS(849)*X(188)-JVS(850)*X(189)-JVS(851)*X(195)-JVS(852)&
             &*X(203)-JVS(853)*X(206)-JVS(854)*X(209)-JVS(855)*X(221)-JVS(856)*X(234))/(JVS(839))
  X(145) = (X(145)-JVS(834)*X(181)-JVS(835)*X(223)-JVS(836)*X(230)-JVS(837)*X(232)-JVS(838)*X(234))/(JVS(833))
  X(144) = (X(144)-JVS(827)*X(210)-JVS(828)*X(222)-JVS(829)*X(225)-JVS(830)*X(230)-JVS(831)*X(235))/(JVS(826))
  X(143) = (X(143)-JVS(816)*X(151)-JVS(817)*X(214)-JVS(818)*X(224)-JVS(819)*X(225)-JVS(820)*X(226)-JVS(821)*X(227)&
             &-JVS(822)*X(228)-JVS(823)*X(231)-JVS(824)*X(232)-JVS(825)*X(234))/(JVS(815))
  X(142) = (X(142)-JVS(812)*X(229)-JVS(813)*X(231)-JVS(814)*X(234))/(JVS(811))
  X(141) = (X(141)-JVS(806)*X(167)-JVS(807)*X(215)-JVS(808)*X(229)-JVS(809)*X(230)-JVS(810)*X(234))/(JVS(805))
  X(140) = (X(140)-JVS(800)*X(203)-JVS(801)*X(218)-JVS(802)*X(223)-JVS(803)*X(232))/(JVS(799))
  X(139) = (X(139)-JVS(793)*X(189)-JVS(794)*X(218)-JVS(795)*X(223)-JVS(796)*X(231)-JVS(797)*X(232)-JVS(798)*X(234))&
             &/(JVS(792))
  X(138) = (X(138)-JVS(786)*X(147)-JVS(787)*X(178)-JVS(788)*X(184)-JVS(789)*X(229)-JVS(790)*X(230))/(JVS(785))
  X(137) = (X(137)-JVS(781)*X(222)-JVS(782)*X(227)-JVS(783)*X(229)-JVS(784)*X(234))/(JVS(780))
  X(136) = (X(136)-JVS(776)*X(193)-JVS(777)*X(230)-JVS(778)*X(231)-JVS(779)*X(234))/(JVS(775))
  X(135) = (X(135)-JVS(772)*X(229)-JVS(773)*X(231)-JVS(774)*X(234))/(JVS(771))
  X(134) = (X(134)-JVS(768)*X(229)-JVS(769)*X(231)-JVS(770)*X(234))/(JVS(767))
  X(133) = (X(133)-JVS(762)*X(152)-JVS(763)*X(154)-JVS(764)*X(205)-JVS(765)*X(232)-JVS(766)*X(234))/(JVS(761))
  X(132) = (X(132)-JVS(757)*X(225)-JVS(758)*X(229)-JVS(759)*X(230)-JVS(760)*X(235))/(JVS(756))
  X(131) = (X(131)-JVS(750)*X(169)-JVS(751)*X(191)-JVS(752)*X(223)-JVS(753)*X(231)-JVS(754)*X(232)-JVS(755)*X(234))&
             &/(JVS(749))
  X(130) = (X(130)-JVS(743)*X(191)-JVS(744)*X(204)-JVS(745)*X(221)-JVS(746)*X(227)-JVS(747)*X(231)-JVS(748)*X(234))&
             &/(JVS(742))
  X(129) = (X(129)-JVS(739)*X(203)-JVS(740)*X(232)-JVS(741)*X(234))/(JVS(738))
  X(128) = (X(128)-JVS(735)*X(203)-JVS(736)*X(232)-JVS(737)*X(234))/(JVS(734))
  X(127) = (X(127)-JVS(729)*X(172)-JVS(730)*X(209)-JVS(731)*X(232)-JVS(732)*X(234)-JVS(733)*X(235))/(JVS(728))
  X(126) = (X(126)-JVS(722)*X(166)-JVS(723)*X(193)-JVS(724)*X(215)-JVS(725)*X(229)-JVS(726)*X(232)-JVS(727)*X(234))&
             &/(JVS(721))
  X(125) = (X(125)-JVS(717)*X(186)-JVS(718)*X(199)-JVS(719)*X(224)-JVS(720)*X(231))/(JVS(716))
  X(124) = (X(124)-JVS(712)*X(221)-JVS(713)*X(227)-JVS(714)*X(232)-JVS(715)*X(234))/(JVS(711))
  X(123) = (X(123)-JVS(707)*X(169)-JVS(708)*X(187)-JVS(709)*X(232)-JVS(710)*X(234))/(JVS(706))
  X(122) = (X(122)-JVS(702)*X(186)-JVS(703)*X(199)-JVS(704)*X(224)-JVS(705)*X(231))/(JVS(701))
  X(121) = (X(121)-JVS(698)*X(203)-JVS(699)*X(232)-JVS(700)*X(234))/(JVS(697))
  X(120) = (X(120)-JVS(692)*X(189)-JVS(693)*X(218)-JVS(694)*X(223)-JVS(695)*X(232)-JVS(696)*X(234))/(JVS(691))
  X(119) = (X(119)-JVS(685)*X(148)-JVS(686)*X(162)-JVS(687)*X(229)-JVS(688)*X(231)-JVS(689)*X(234))/(JVS(684))
  X(118) = (X(118)-JVS(679)*X(189)-JVS(680)*X(218)-JVS(681)*X(223)-JVS(682)*X(231)-JVS(683)*X(234))/(JVS(678))
  X(117) = (X(117)-JVS(674)*X(157)-JVS(675)*X(223)-JVS(676)*X(232)-JVS(677)*X(234))/(JVS(673))
  X(116) = (X(116)-JVS(665)*X(122)-JVS(666)*X(125)-JVS(667)*X(144)-JVS(668)*X(186)-JVS(669)*X(210)-JVS(670)*X(222)&
             &-JVS(671)*X(224)-JVS(672)*X(234))/(JVS(664))
  X(115) = (X(115)-JVS(660)*X(177)-JVS(661)*X(185)-JVS(662)*X(232)-JVS(663)*X(234))/(JVS(659))
  X(114) = (X(114)-JVS(656)*X(195)-JVS(657)*X(232)-JVS(658)*X(234))/(JVS(655))
  X(113) = (X(113)-JVS(651)*X(203)-JVS(652)*X(223)-JVS(653)*X(232)-JVS(654)*X(234))/(JVS(650))
  X(112) = (X(112)-JVS(646)*X(189)-JVS(647)*X(232)-JVS(648)*X(234))/(JVS(645))
  X(111) = (X(111)-JVS(641)*X(147)-JVS(642)*X(184)-JVS(643)*X(232)-JVS(644)*X(234))/(JVS(640))
  X(110) = (X(110)-JVS(637)*X(203)-JVS(638)*X(223)-JVS(639)*X(232))/(JVS(636))
  X(109) = (X(109)-JVS(633)*X(222)-JVS(634)*X(227)-JVS(635)*X(234))/(JVS(632))
  X(108) = (X(108)-JVS(622)*X(122)-JVS(623)*X(125)-JVS(624)*X(144)-JVS(625)*X(186)-JVS(626)*X(196)-JVS(627)*X(199)&
             &-JVS(628)*X(210)-JVS(629)*X(224)-JVS(630)*X(225)-JVS(631)*X(233))/(JVS(621))
  X(107) = (X(107)-JVS(619)*X(203)-JVS(620)*X(234))/(JVS(618))
  X(106) = (X(106)-JVS(613)*X(139)-JVS(614)*X(140)-JVS(615)*X(206)-JVS(616)*X(232)-JVS(617)*X(234))/(JVS(612))
  X(105) = (X(105)-JVS(608)*X(180)-JVS(609)*X(188)-JVS(610)*X(232)-JVS(611)*X(234))/(JVS(607))
  X(104) = (X(104)-JVS(604)*X(227)-JVS(605)*X(229)-JVS(606)*X(234))/(JVS(603))
  X(103) = (X(103)-JVS(594)*X(153)-JVS(595)*X(155)-JVS(596)*X(156)-JVS(597)*X(160)-JVS(598)*X(163)-JVS(599)*X(172)&
             &-JVS(600)*X(197)-JVS(601)*X(219)-JVS(602)*X(234))/(JVS(593))
  X(102) = (X(102)-JVS(590)*X(161)-JVS(591)*X(232)-JVS(592)*X(234))/(JVS(589))
  X(101) = (X(101)-JVS(586)*X(168)-JVS(587)*X(232)-JVS(588)*X(234))/(JVS(585))
  X(100) = (X(100)-JVS(581)*X(167)-JVS(582)*X(179)-JVS(583)*X(232)-JVS(584)*X(234))/(JVS(580))
  X(99) = (X(99)-JVS(576)*X(141)-JVS(577)*X(218)-JVS(578)*X(230)-JVS(579)*X(234))/(JVS(575))
  X(98) = (X(98)-JVS(571)*X(184)-JVS(572)*X(210)-JVS(573)*X(233)-JVS(574)*X(234))/(JVS(570))
  X(97) = (X(97)-JVS(566)*X(178)-JVS(567)*X(223)-JVS(568)*X(230)-JVS(569)*X(234))/(JVS(565))
  X(96) = (X(96)-JVS(559)*X(210)-JVS(560)*X(221)-JVS(561)*X(227)-JVS(562)*X(233)-JVS(563)*X(234))/(JVS(558))
  X(95) = (X(95)-JVS(554)*X(230)-JVS(555)*X(232)-JVS(556)*X(234))/(JVS(553))
  X(94) = (X(94)-JVS(551)*X(226)-JVS(552)*X(234))/(JVS(550))
  X(93) = (X(93)-JVS(548)*X(227)-JVS(549)*X(234))/(JVS(547))
  X(92) = (X(92)-JVS(545)*X(229)-JVS(546)*X(234))/(JVS(544))
  X(91) = (X(91)-JVS(542)*X(229)-JVS(543)*X(234))/(JVS(541))
  X(90) = (X(90)-JVS(538)*X(171)-JVS(539)*X(232)-JVS(540)*X(234))/(JVS(537))
  X(89) = (X(89)-JVS(534)*X(164)-JVS(535)*X(232)-JVS(536)*X(234))/(JVS(533))
  X(88) = (X(88)-JVS(530)*X(184)-JVS(531)*X(210)-JVS(532)*X(223))/(JVS(529))
  X(87) = (X(87)-JVS(524)*X(226)-JVS(525)*X(234))/(JVS(523))
  X(86) = (X(86)-JVS(521)*X(178)-JVS(522)*X(230))/(JVS(520))
  X(85) = (X(85)-JVS(518)*X(226)-JVS(519)*X(234))/(JVS(517))
  X(84) = (X(84)-JVS(515)*X(226)-JVS(516)*X(234))/(JVS(514))
  X(83) = (X(83)-JVS(511)*X(132)-JVS(512)*X(225)-JVS(513)*X(234))/(JVS(510))
  X(82) = (X(82)-JVS(508)*X(226)-JVS(509)*X(234))/(JVS(507))
  X(81) = (X(81)-JVS(504)*X(204)-JVS(505)*X(232)-JVS(506)*X(234))/(JVS(503))
  X(80) = (X(80)-JVS(501)*X(226)-JVS(502)*X(234))/(JVS(500))
  X(79) = (X(79)-JVS(498)*X(233)-JVS(499)*X(234))/(JVS(497))
  X(78) = (X(78)-JVS(495)*X(221)-JVS(496)*X(230))/(JVS(494))
  X(77) = (X(77)-JVS(492)*X(227)-JVS(493)*X(234))/(JVS(491))
  X(76) = (X(76)-JVS(486)*X(141)-JVS(487)*X(215)-JVS(488)*X(229)-JVS(489)*X(230)-JVS(490)*X(234))/(JVS(485))
  X(75) = (X(75)-JVS(483)*X(227)-JVS(484)*X(234))/(JVS(482))
  X(74) = (X(74)-JVS(477)*X(86)-JVS(478)*X(111)-JVS(479)*X(138)-JVS(480)*X(184)-JVS(481)*X(233))/(JVS(476))
  X(73) = (X(73)-JVS(474)*X(226)-JVS(475)*X(234))/(JVS(473))
  X(72) = (X(72)-JVS(470)*X(218)-JVS(471)*X(232)-JVS(472)*X(234))/(JVS(469))
  X(71) = (X(71)-JVS(466)*X(178)-JVS(467)*X(232)-JVS(468)*X(234))/(JVS(465))
  X(70) = (X(70)-JVS(461)*X(91)-JVS(462)*X(223)-JVS(463)*X(232)-JVS(464)*X(234))/(JVS(460))
  X(69) = (X(69)-JVS(458)*X(228)-JVS(459)*X(234))/(JVS(457))
  X(68) = (X(68)-JVS(455)*X(223)-JVS(456)*X(230))/(JVS(454))
  X(67) = (X(67)-JVS(446)*X(150)-JVS(447)*X(159)-JVS(448)*X(169)-JVS(449)*X(181)-JVS(450)*X(187)-JVS(451)*X(191)&
            &-JVS(452)*X(207)-JVS(453)*X(223))/(JVS(445))
  X(66) = (X(66)-JVS(440)*X(121)-JVS(441)*X(128)-JVS(442)*X(150)-JVS(443)*X(234))/(JVS(439))
  X(65) = (X(65)-JVS(435)*X(121)-JVS(436)*X(128)-JVS(437)*X(150)-JVS(438)*X(234))/(JVS(434))
  X(64) = (X(64)-JVS(431)*X(223)-JVS(432)*X(232)-JVS(433)*X(234))/(JVS(430))
  X(63) = (X(63)-JVS(426)*X(223)-JVS(427)*X(232)-JVS(428)*X(234))/(JVS(425))
  X(62) = (X(62)-JVS(421)*X(68)-JVS(422)*X(226)-JVS(423)*X(230))/(JVS(420))
  X(61) = (X(61)-JVS(418)*X(178)-JVS(419)*X(223))/(JVS(417))
  X(60) = (X(60)-JVS(414)*X(129)-JVS(415)*X(191)-JVS(416)*X(234))/(JVS(413))
  X(59) = (X(59)-JVS(410)*X(86)-JVS(411)*X(111)-JVS(412)*X(138))/(JVS(409))
  X(58) = (X(58)-JVS(408)*X(226))/(JVS(407))
  X(57) = (X(57)-JVS(406)*X(226))/(JVS(405))
  X(56) = (X(56)-JVS(404)*X(226))/(JVS(403))
  X(55) = (X(55)-JVS(402)*X(226))/(JVS(401))
  X(54) = (X(54)-JVS(400)*X(226))/(JVS(399))
  X(53) = (X(53)-JVS(398)*X(226))/(JVS(397))
  X(52) = (X(52)-JVS(396)*X(226))/(JVS(395))
  X(51) = (X(51)-JVS(393)*X(222)-JVS(394)*X(230))/(JVS(392))
  X(50) = (X(50)-JVS(391)*X(234))/(JVS(390))
  X(49) = (X(49)-JVS(388)*X(179)-JVS(389)*X(230))/(JVS(387))
  X(48) = (X(48)-JVS(385)*X(145)-JVS(386)*X(230))/(JVS(384))
  X(47) = (X(47)-JVS(382)*X(88)-JVS(383)*X(184))/(JVS(381))
  X(46) = (X(46)-JVS(380)*X(226))/(JVS(379))
  X(45) = (X(45)-JVS(378)*X(226))/(JVS(377))
  X(44) = (X(44)-JVS(376)*X(234))/(JVS(375))
  X(43) = (X(43)-JVS(374)*X(234))/(JVS(373))
  X(42) = (X(42)-JVS(372)*X(234))/(JVS(371))
  X(41) = (X(41)-JVS(368)*X(119)-JVS(369)*X(148)-JVS(370)*X(162))/(JVS(367))
  X(40) = (X(40)-JVS(366)*X(184))/(JVS(365))
  X(39) = (X(39)-JVS(364)*X(110))/(JVS(363))
  X(38) = (X(38)-JVS(360)*X(169)-JVS(361)*X(187)-JVS(362)*X(223))/(JVS(359))
  X(37) = (X(37)-JVS(358)*X(88))/(JVS(357))
  X(36) = (X(36)-JVS(343)*X(134)-JVS(344)*X(135)-JVS(345)*X(142)-JVS(346)*X(153)-JVS(347)*X(155)-JVS(348)*X(156)&
            &-JVS(349)*X(160)-JVS(350)*X(163)-JVS(351)*X(172)-JVS(352)*X(197)-JVS(353)*X(231)-JVS(354)*X(232)-JVS(355)&
            &*X(234)-JVS(356)*X(235))/(JVS(342))
  X(35) = (X(35)-JVS(338)*X(151)-JVS(339)*X(226)-JVS(340)*X(227)-JVS(341)*X(234))/(JVS(337))
  X(34) = (X(34)-JVS(328)*X(153)-JVS(329)*X(155)-JVS(330)*X(156)-JVS(331)*X(160)-JVS(332)*X(163)-JVS(333)*X(172)&
            &-JVS(334)*X(197)-JVS(335)*X(219)-JVS(336)*X(234))/(JVS(327))
  X(33) = (X(33)-JVS(318)*X(153)-JVS(319)*X(155)-JVS(320)*X(156)-JVS(321)*X(160)-JVS(322)*X(163)-JVS(323)*X(172)&
            &-JVS(324)*X(197)-JVS(325)*X(220)-JVS(326)*X(234))/(JVS(317))
  X(32) = (X(32)-JVS(268)*X(69)-JVS(269)*X(75)-JVS(270)*X(77)-JVS(271)*X(93)-JVS(272)*X(107)-JVS(273)*X(110)-JVS(274)&
            &*X(112)-JVS(275)*X(117)-JVS(276)*X(120)-JVS(277)*X(127)-JVS(278)*X(131)-JVS(279)*X(134)-JVS(280)*X(135)&
            &-JVS(281)*X(136)-JVS(282)*X(141)-JVS(283)*X(142)-JVS(284)*X(150)-JVS(285)*X(157)-JVS(286)*X(158)-JVS(287)&
            &*X(165)-JVS(288)*X(166)-JVS(289)*X(167)-JVS(290)*X(174)-JVS(291)*X(181)-JVS(292)*X(189)-JVS(293)*X(192)&
            &-JVS(294)*X(193)-JVS(295)*X(200)-JVS(296)*X(201)-JVS(297)*X(202)-JVS(298)*X(203)-JVS(299)*X(208)-JVS(300)&
            &*X(209)-JVS(301)*X(211)-JVS(302)*X(212)-JVS(303)*X(214)-JVS(304)*X(215)-JVS(305)*X(216)-JVS(306)*X(217)&
            &-JVS(307)*X(218)-JVS(308)*X(221)-JVS(309)*X(222)-JVS(310)*X(223)-JVS(311)*X(227)-JVS(312)*X(228)-JVS(313)&
            &*X(229)-JVS(314)*X(231)-JVS(315)*X(232)-JVS(316)*X(234))/(JVS(267))
  X(31) = (X(31)-JVS(193)*X(37)-JVS(194)*X(40)-JVS(195)*X(47)-JVS(196)*X(62)-JVS(197)*X(69)-JVS(198)*X(79)-JVS(199)&
            &*X(86)-JVS(200)*X(87)-JVS(201)*X(88)-JVS(202)*X(91)-JVS(203)*X(92)-JVS(204)*X(94)-JVS(205)*X(98)-JVS(206)&
            &*X(104)-JVS(207)*X(111)-JVS(208)*X(118)-JVS(209)*X(122)-JVS(210)*X(123)-JVS(211)*X(125)-JVS(212)*X(132)&
            &-JVS(213)*X(134)-JVS(214)*X(135)-JVS(215)*X(137)-JVS(216)*X(138)-JVS(217)*X(142)-JVS(218)*X(143)-JVS(219)&
            &*X(144)-JVS(220)*X(145)-JVS(221)*X(148)-JVS(222)*X(150)-JVS(223)*X(151)-JVS(224)*X(152)-JVS(225)*X(154)&
            &-JVS(226)*X(158)-JVS(227)*X(159)-JVS(228)*X(162)-JVS(229)*X(167)-JVS(230)*X(174)-JVS(231)*X(176)-JVS(232)&
            &*X(180)-JVS(233)*X(181)-JVS(234)*X(183)-JVS(235)*X(184)-JVS(236)*X(186)-JVS(237)*X(188)-JVS(238)*X(191)&
            &-JVS(239)*X(196)-JVS(240)*X(198)-JVS(241)*X(199)-JVS(242)*X(200)-JVS(243)*X(202)-JVS(244)*X(205)-JVS(245)&
            &*X(207)-JVS(246)*X(210)-JVS(247)*X(211)-JVS(248)*X(212)-JVS(249)*X(213)-JVS(250)*X(214)-JVS(251)*X(215)&
            &-JVS(252)*X(216)-JVS(253)*X(217)-JVS(254)*X(221)-JVS(255)*X(223)-JVS(256)*X(224)-JVS(257)*X(225)-JVS(258)&
            &*X(226)-JVS(259)*X(228)-JVS(260)*X(229)-JVS(261)*X(230)-JVS(262)*X(231)-JVS(263)*X(232)-JVS(264)*X(233)&
            &-JVS(265)*X(234)-JVS(266)*X(235))/(JVS(192))
  X(30) = (X(30)-JVS(124)*X(41)-JVS(125)*X(48)-JVS(126)*X(62)-JVS(127)*X(67)-JVS(128)*X(68)-JVS(129)*X(78)-JVS(130)&
            &*X(83)-JVS(131)*X(95)-JVS(132)*X(96)-JVS(133)*X(97)-JVS(134)*X(99)-JVS(135)*X(110)-JVS(136)*X(113)-JVS(137)&
            &*X(116)-JVS(138)*X(119)-JVS(139)*X(139)-JVS(140)*X(140)-JVS(141)*X(141)-JVS(142)*X(143)-JVS(143)*X(145)&
            &-JVS(144)*X(147)-JVS(145)*X(148)-JVS(146)*X(149)-JVS(147)*X(153)-JVS(148)*X(154)-JVS(149)*X(155)-JVS(150)&
            &*X(156)-JVS(151)*X(157)-JVS(152)*X(159)-JVS(153)*X(160)-JVS(154)*X(161)-JVS(155)*X(162)-JVS(156)*X(163)&
            &-JVS(157)*X(164)-JVS(158)*X(166)-JVS(159)*X(167)-JVS(160)*X(168)-JVS(161)*X(169)-JVS(162)*X(171)-JVS(163)&
            &*X(172)-JVS(164)*X(173)-JVS(165)*X(175)-JVS(166)*X(177)-JVS(167)*X(179)-JVS(168)*X(180)-JVS(169)*X(182)&
            &-JVS(170)*X(183)-JVS(171)*X(185)-JVS(172)*X(187)-JVS(173)*X(188)-JVS(174)*X(189)-JVS(175)*X(190)-JVS(176)&
            &*X(193)-JVS(177)*X(195)-JVS(178)*X(197)-JVS(179)*X(199)-JVS(180)*X(203)-JVS(181)*X(204)-JVS(182)*X(205)&
            &-JVS(183)*X(206)-JVS(184)*X(209)-JVS(185)*X(218)-JVS(186)*X(221)-JVS(187)*X(223)-JVS(188)*X(227)-JVS(189)&
            &*X(230)-JVS(190)*X(232)-JVS(191)*X(234))/(JVS(123))
  X(29) = (X(29)-JVS(122)*X(200))/(JVS(121))
  X(28) = (X(28)-JVS(119)*X(141)-JVS(120)*X(234))/(JVS(118))
  X(27) = (X(27)-JVS(117)*X(28))/(JVS(116))
  X(26) = (X(26)-JVS(113)*X(60)-JVS(114)*X(65)-JVS(115)*X(66))/(JVS(112))
  X(25) = (X(25)-JVS(111)*X(158))/(JVS(110))
  X(24) = (X(24)-JVS(109)*X(186))/(JVS(108))
  X(23) = (X(23)-JVS(107)*X(186))/(JVS(106))
  X(22) = (X(22)-JVS(104)*X(159)-JVS(105)*X(234))/(JVS(103))
  X(21) = (X(21)-JVS(101)*X(92)-JVS(102)*X(234))/(JVS(100))
  X(20) = (X(20)-JVS(98)*X(70)-JVS(99)*X(223))/(JVS(97))
  X(19) = (X(19)-JVS(95)*X(70)-JVS(96)*X(232))/(JVS(94))
  X(18) = (X(18)-JVS(90)*X(121)-JVS(91)*X(128)-JVS(92)*X(129)-JVS(93)*X(234))/(JVS(89))
  X(17) = (X(17)-JVS(88)*X(18))/(JVS(87))
  X(16) = (X(16)-JVS(85)*X(63)-JVS(86)*X(223))/(JVS(84))
  X(15) = (X(15)-JVS(82)*X(63)-JVS(83)*X(232))/(JVS(81))
  X(14) = (X(14)-JVS(79)*X(174)-JVS(80)*X(229))/(JVS(78))
  X(13) = (X(13)-JVS(76)*X(174)-JVS(77)*X(234))/(JVS(75))
  X(12) = (X(12)-JVS(73)*X(64)-JVS(74)*X(223))/(JVS(72))
  X(11) = (X(11)-JVS(70)*X(64)-JVS(71)*X(232))/(JVS(69))
  X(10) = (X(10)-JVS(61)*X(152)-JVS(62)*X(154)-JVS(63)*X(167)-JVS(64)*X(221)-JVS(65)*X(223)-JVS(66)*X(229)-JVS(67)&
            &*X(230)-JVS(68)*X(232))/(JVS(60))
  X(9) = (X(9)-JVS(59)*X(10))/(JVS(58))
  X(8) = (X(8)-JVS(51)*X(37)-JVS(52)*X(40)-JVS(53)*X(47)-JVS(54)*X(71)-JVS(55)*X(86)-JVS(56)*X(111)-JVS(57)*X(138))&
           &/(JVS(50))
  X(7) = (X(7)-JVS(43)*X(37)-JVS(44)*X(40)-JVS(45)*X(47)-JVS(46)*X(71)-JVS(47)*X(86)-JVS(48)*X(111)-JVS(49)*X(138))&
           &/(JVS(42))
  X(6) = (X(6)-JVS(40)*X(41)-JVS(41)*X(67))/(JVS(39))
  X(5) = (X(5)-JVS(10)*X(69)-JVS(11)*X(91)-JVS(12)*X(107)-JVS(13)*X(118)-JVS(14)*X(127)-JVS(15)*X(131)-JVS(16)*X(139)&
           &-JVS(17)*X(141)-JVS(18)*X(145)-JVS(19)*X(150)-JVS(20)*X(157)-JVS(21)*X(166)-JVS(22)*X(170)-JVS(23)*X(175)&
           &-JVS(24)*X(191)-JVS(25)*X(192)-JVS(26)*X(193)-JVS(27)*X(194)-JVS(28)*X(203)-JVS(29)*X(208)-JVS(30)*X(218)&
           &-JVS(31)*X(220)-JVS(32)*X(221)-JVS(33)*X(223)-JVS(34)*X(227)-JVS(35)*X(229)-JVS(36)*X(231)-JVS(37)*X(232)&
           &-JVS(38)*X(234))/(JVS(9))
  X(4) = (X(4)-JVS(5)*X(37)-JVS(6)*X(40)-JVS(7)*X(47)-JVS(8)*X(71))/(JVS(4))
  X(3) = X(3)/JVS(3)
  X(2) = X(2)/JVS(2)
  X(1) = X(1)/JVS(1)
      
END SUBROUTINE KppSolve

! End of KppSolve function
! ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~


! ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
! 
! KppSolveTR - sparse, transposed back substitution
!   Arguments :
!      JVS       - sparse Jacobian of variables
!      X         - Vector for variables
!      XX        - Vector for output variables
! 
! ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~

SUBROUTINE KppSolveTR ( JVS, X, XX )

! JVS - sparse Jacobian of variables
  REAL(kind=dp) :: JVS(LU_NONZERO)
! X - Vector for variables
  REAL(kind=dp) :: X(NVAR)
! XX - Vector for output variables
  REAL(kind=dp) :: XX(NVAR)

  XX(1) = X(1)/JVS(1)
  XX(2) = X(2)/JVS(2)
  XX(3) = X(3)/JVS(3)
  XX(4) = X(4)/JVS(4)
  XX(5) = X(5)/JVS(9)
  XX(6) = X(6)/JVS(39)
  XX(7) = X(7)/JVS(42)
  XX(8) = X(8)/JVS(50)
  XX(9) = X(9)/JVS(58)
  XX(10) = (X(10)-JVS(59)*XX(9))/(JVS(60))
  XX(11) = X(11)/JVS(69)
  XX(12) = X(12)/JVS(72)
  XX(13) = X(13)/JVS(75)
  XX(14) = X(14)/JVS(78)
  XX(15) = X(15)/JVS(81)
  XX(16) = X(16)/JVS(84)
  XX(17) = X(17)/JVS(87)
  XX(18) = (X(18)-JVS(88)*XX(17))/(JVS(89))
  XX(19) = X(19)/JVS(94)
  XX(20) = X(20)/JVS(97)
  XX(21) = X(21)/JVS(100)
  XX(22) = X(22)/JVS(103)
  XX(23) = X(23)/JVS(106)
  XX(24) = X(24)/JVS(108)
  XX(25) = X(25)/JVS(110)
  XX(26) = X(26)/JVS(112)
  XX(27) = X(27)/JVS(116)
  XX(28) = (X(28)-JVS(117)*XX(27))/(JVS(118))
  XX(29) = X(29)/JVS(121)
  XX(30) = X(30)/JVS(123)
  XX(31) = X(31)/JVS(192)
  XX(32) = X(32)/JVS(267)
  XX(33) = X(33)/JVS(317)
  XX(34) = X(34)/JVS(327)
  XX(35) = X(35)/JVS(337)
  XX(36) = X(36)/JVS(342)
  XX(37) = (X(37)-JVS(5)*XX(4)-JVS(43)*XX(7)-JVS(51)*XX(8)-JVS(193)*XX(31))/(JVS(357))
  XX(38) = X(38)/JVS(359)
  XX(39) = X(39)/JVS(363)
  XX(40) = (X(40)-JVS(6)*XX(4)-JVS(44)*XX(7)-JVS(52)*XX(8)-JVS(194)*XX(31))/(JVS(365))
  XX(41) = (X(41)-JVS(40)*XX(6)-JVS(124)*XX(30))/(JVS(367))
  XX(42) = X(42)/JVS(371)
  XX(43) = X(43)/JVS(373)
  XX(44) = X(44)/JVS(375)
  XX(45) = X(45)/JVS(377)
  XX(46) = X(46)/JVS(379)
  XX(47) = (X(47)-JVS(7)*XX(4)-JVS(45)*XX(7)-JVS(53)*XX(8)-JVS(195)*XX(31))/(JVS(381))
  XX(48) = (X(48)-JVS(125)*XX(30))/(JVS(384))
  XX(49) = X(49)/JVS(387)
  XX(50) = X(50)/JVS(390)
  XX(51) = X(51)/JVS(392)
  XX(52) = X(52)/JVS(395)
  XX(53) = X(53)/JVS(397)
  XX(54) = X(54)/JVS(399)
  XX(55) = X(55)/JVS(401)
  XX(56) = X(56)/JVS(403)
  XX(57) = X(57)/JVS(405)
  XX(58) = X(58)/JVS(407)
  XX(59) = X(59)/JVS(409)
  XX(60) = (X(60)-JVS(113)*XX(26))/(JVS(413))
  XX(61) = X(61)/JVS(417)
  XX(62) = (X(62)-JVS(126)*XX(30)-JVS(196)*XX(31))/(JVS(420))
  XX(63) = (X(63)-JVS(82)*XX(15)-JVS(85)*XX(16))/(JVS(425))
  XX(64) = (X(64)-JVS(70)*XX(11)-JVS(73)*XX(12))/(JVS(430))
  XX(65) = (X(65)-JVS(114)*XX(26))/(JVS(434))
  XX(66) = (X(66)-JVS(115)*XX(26))/(JVS(439))
  XX(67) = (X(67)-JVS(41)*XX(6)-JVS(127)*XX(30))/(JVS(445))
  XX(68) = (X(68)-JVS(128)*XX(30)-JVS(421)*XX(62))/(JVS(454))
  XX(69) = (X(69)-JVS(10)*XX(5)-JVS(197)*XX(31)-JVS(268)*XX(32))/(JVS(457))
  XX(70) = (X(70)-JVS(95)*XX(19)-JVS(98)*XX(20))/(JVS(460))
  XX(71) = (X(71)-JVS(8)*XX(4)-JVS(46)*XX(7)-JVS(54)*XX(8))/(JVS(465))
  XX(72) = X(72)/JVS(469)
  XX(73) = X(73)/JVS(473)
  XX(74) = X(74)/JVS(476)
  XX(75) = (X(75)-JVS(269)*XX(32))/(JVS(482))
  XX(76) = X(76)/JVS(485)
  XX(77) = (X(77)-JVS(270)*XX(32))/(JVS(491))
  XX(78) = (X(78)-JVS(129)*XX(30))/(JVS(494))
  XX(79) = (X(79)-JVS(198)*XX(31))/(JVS(497))
  XX(80) = X(80)/JVS(500)
  XX(81) = X(81)/JVS(503)
  XX(82) = X(82)/JVS(507)
  XX(83) = (X(83)-JVS(130)*XX(30))/(JVS(510))
  XX(84) = X(84)/JVS(514)
  XX(85) = X(85)/JVS(517)
  XX(86) = (X(86)-JVS(47)*XX(7)-JVS(55)*XX(8)-JVS(199)*XX(31)-JVS(410)*XX(59)-JVS(477)*XX(74))/(JVS(520))
  XX(87) = (X(87)-JVS(200)*XX(31))/(JVS(523))
  XX(88) = (X(88)-JVS(201)*XX(31)-JVS(358)*XX(37)-JVS(382)*XX(47))/(JVS(529))
  XX(89) = X(89)/JVS(533)
  XX(90) = X(90)/JVS(537)
  XX(91) = (X(91)-JVS(11)*XX(5)-JVS(202)*XX(31)-JVS(461)*XX(70))/(JVS(541))
  XX(92) = (X(92)-JVS(101)*XX(21)-JVS(203)*XX(31))/(JVS(544))
  XX(93) = (X(93)-JVS(271)*XX(32))/(JVS(547))
  XX(94) = (X(94)-JVS(204)*XX(31))/(JVS(550))
  XX(95) = (X(95)-JVS(131)*XX(30))/(JVS(553))
  XX(96) = (X(96)-JVS(132)*XX(30))/(JVS(558))
  XX(97) = (X(97)-JVS(133)*XX(30))/(JVS(565))
  XX(98) = (X(98)-JVS(205)*XX(31))/(JVS(570))
  XX(99) = (X(99)-JVS(134)*XX(30))/(JVS(575))
  XX(100) = X(100)/JVS(580)
  XX(101) = X(101)/JVS(585)
  XX(102) = X(102)/JVS(589)
  XX(103) = X(103)/JVS(593)
  XX(104) = (X(104)-JVS(206)*XX(31))/(JVS(603))
  XX(105) = X(105)/JVS(607)
  XX(106) = X(106)/JVS(612)
  XX(107) = (X(107)-JVS(12)*XX(5)-JVS(272)*XX(32))/(JVS(618))
  XX(108) = X(108)/JVS(621)
  XX(109) = X(109)/JVS(632)
  XX(110) = (X(110)-JVS(135)*XX(30)-JVS(273)*XX(32)-JVS(364)*XX(39))/(JVS(636))
  XX(111) = (X(111)-JVS(48)*XX(7)-JVS(56)*XX(8)-JVS(207)*XX(31)-JVS(411)*XX(59)-JVS(478)*XX(74))/(JVS(640))
  XX(112) = (X(112)-JVS(274)*XX(32))/(JVS(645))
  XX(113) = (X(113)-JVS(136)*XX(30))/(JVS(650))
  XX(114) = X(114)/JVS(655)
  XX(115) = X(115)/JVS(659)
  XX(116) = (X(116)-JVS(137)*XX(30))/(JVS(664))
  XX(117) = (X(117)-JVS(275)*XX(32))/(JVS(673))
  XX(118) = (X(118)-JVS(13)*XX(5)-JVS(208)*XX(31))/(JVS(678))
  XX(119) = (X(119)-JVS(138)*XX(30)-JVS(368)*XX(41))/(JVS(684))
  XX(120) = (X(120)-JVS(276)*XX(32))/(JVS(691))
  XX(121) = (X(121)-JVS(90)*XX(18)-JVS(435)*XX(65)-JVS(440)*XX(66))/(JVS(697))
  XX(122) = (X(122)-JVS(209)*XX(31)-JVS(622)*XX(108)-JVS(665)*XX(116))/(JVS(701))
  XX(123) = (X(123)-JVS(210)*XX(31))/(JVS(706))
  XX(124) = X(124)/JVS(711)
  XX(125) = (X(125)-JVS(211)*XX(31)-JVS(623)*XX(108)-JVS(666)*XX(116))/(JVS(716))
  XX(126) = X(126)/JVS(721)
  XX(127) = (X(127)-JVS(14)*XX(5)-JVS(277)*XX(32))/(JVS(728))
  XX(128) = (X(128)-JVS(91)*XX(18)-JVS(436)*XX(65)-JVS(441)*XX(66))/(JVS(734))
  XX(129) = (X(129)-JVS(92)*XX(18)-JVS(414)*XX(60))/(JVS(738))
  XX(130) = X(130)/JVS(742)
  XX(131) = (X(131)-JVS(15)*XX(5)-JVS(278)*XX(32))/(JVS(749))
  XX(132) = (X(132)-JVS(212)*XX(31)-JVS(511)*XX(83))/(JVS(756))
  XX(133) = X(133)/JVS(761)
  XX(134) = (X(134)-JVS(213)*XX(31)-JVS(279)*XX(32)-JVS(343)*XX(36))/(JVS(767))
  XX(135) = (X(135)-JVS(214)*XX(31)-JVS(280)*XX(32)-JVS(344)*XX(36))/(JVS(771))
  XX(136) = (X(136)-JVS(281)*XX(32))/(JVS(775))
  XX(137) = (X(137)-JVS(215)*XX(31))/(JVS(780))
  XX(138) = (X(138)-JVS(49)*XX(7)-JVS(57)*XX(8)-JVS(216)*XX(31)-JVS(412)*XX(59)-JVS(479)*XX(74))/(JVS(785))
  XX(139) = (X(139)-JVS(16)*XX(5)-JVS(139)*XX(30)-JVS(613)*XX(106))/(JVS(792))
  XX(140) = (X(140)-JVS(140)*XX(30)-JVS(614)*XX(106))/(JVS(799))
  XX(141) = (X(141)-JVS(17)*XX(5)-JVS(119)*XX(28)-JVS(141)*XX(30)-JVS(282)*XX(32)-JVS(486)*XX(76)-JVS(576)*XX(99))&
              &/(JVS(805))
  XX(142) = (X(142)-JVS(217)*XX(31)-JVS(283)*XX(32)-JVS(345)*XX(36))/(JVS(811))
  XX(143) = (X(143)-JVS(142)*XX(30)-JVS(218)*XX(31))/(JVS(815))
  XX(144) = (X(144)-JVS(219)*XX(31)-JVS(624)*XX(108)-JVS(667)*XX(116))/(JVS(826))
  XX(145) = (X(145)-JVS(18)*XX(5)-JVS(143)*XX(30)-JVS(220)*XX(31)-JVS(385)*XX(48))/(JVS(833))
  XX(146) = X(146)/JVS(839)
  XX(147) = (X(147)-JVS(144)*XX(30)-JVS(641)*XX(111)-JVS(786)*XX(138))/(JVS(860))
  XX(148) = (X(148)-JVS(145)*XX(30)-JVS(221)*XX(31)-JVS(369)*XX(41)-JVS(685)*XX(119))/(JVS(867))
  XX(149) = (X(149)-JVS(146)*XX(30))/(JVS(878))
  XX(150) = (X(150)-JVS(19)*XX(5)-JVS(222)*XX(31)-JVS(284)*XX(32)-JVS(437)*XX(65)-JVS(442)*XX(66)-JVS(446)*XX(67))&
              &/(JVS(888))
  XX(151) = (X(151)-JVS(223)*XX(31)-JVS(338)*XX(35)-JVS(816)*XX(143))/(JVS(893))
  XX(152) = (X(152)-JVS(61)*XX(10)-JVS(224)*XX(31)-JVS(762)*XX(133))/(JVS(900))
  XX(153) = (X(153)-JVS(147)*XX(30)-JVS(318)*XX(33)-JVS(328)*XX(34)-JVS(346)*XX(36)-JVS(594)*XX(103))/(JVS(906))
  XX(154) = (X(154)-JVS(62)*XX(10)-JVS(148)*XX(30)-JVS(225)*XX(31)-JVS(763)*XX(133))/(JVS(914))
  XX(155) = (X(155)-JVS(149)*XX(30)-JVS(319)*XX(33)-JVS(329)*XX(34)-JVS(347)*XX(36)-JVS(595)*XX(103))/(JVS(920))
  XX(156) = (X(156)-JVS(150)*XX(30)-JVS(320)*XX(33)-JVS(330)*XX(34)-JVS(348)*XX(36)-JVS(596)*XX(103))/(JVS(928))
  XX(157) = (X(157)-JVS(20)*XX(5)-JVS(151)*XX(30)-JVS(285)*XX(32)-JVS(674)*XX(117))/(JVS(943))
  XX(158) = (X(158)-JVS(111)*XX(25)-JVS(226)*XX(31)-JVS(286)*XX(32))/(JVS(961))
  XX(159) = (X(159)-JVS(104)*XX(22)-JVS(152)*XX(30)-JVS(227)*XX(31)-JVS(447)*XX(67))/(JVS(975))
  XX(160) = (X(160)-JVS(153)*XX(30)-JVS(321)*XX(33)-JVS(331)*XX(34)-JVS(349)*XX(36)-JVS(597)*XX(103))/(JVS(984))
  XX(161) = (X(161)-JVS(154)*XX(30)-JVS(590)*XX(102)-JVS(840)*XX(146))/(JVS(994))
  XX(162) = (X(162)-JVS(155)*XX(30)-JVS(228)*XX(31)-JVS(370)*XX(41)-JVS(686)*XX(119))/(JVS(1002))
  XX(163) = (X(163)-JVS(156)*XX(30)-JVS(322)*XX(33)-JVS(332)*XX(34)-JVS(350)*XX(36)-JVS(598)*XX(103))/(JVS(1014))
  XX(164) = (X(164)-JVS(157)*XX(30)-JVS(534)*XX(89)-JVS(841)*XX(146))/(JVS(1024))
  XX(165) = (X(165)-JVS(287)*XX(32))/(JVS(1039))
  XX(166) = (X(166)-JVS(21)*XX(5)-JVS(158)*XX(30)-JVS(288)*XX(32)-JVS(722)*XX(126)-JVS(1040)*XX(165))/(JVS(1054))
  XX(167) = (X(167)-JVS(63)*XX(10)-JVS(159)*XX(30)-JVS(229)*XX(31)-JVS(289)*XX(32)-JVS(581)*XX(100)-JVS(806)*XX(141)&
              &-JVS(1041)*XX(165))/(JVS(1061))
  XX(168) = (X(168)-JVS(160)*XX(30)-JVS(586)*XX(101)-JVS(842)*XX(146))/(JVS(1069))
  XX(169) = (X(169)-JVS(161)*XX(30)-JVS(360)*XX(38)-JVS(448)*XX(67)-JVS(707)*XX(123)-JVS(750)*XX(131)-JVS(976)*XX(159)&
              &-JVS(1042)*XX(165))/(JVS(1079))
  XX(170) = (X(170)-JVS(22)*XX(5))/(JVS(1091))
  XX(171) = (X(171)-JVS(162)*XX(30)-JVS(538)*XX(90)-JVS(843)*XX(146))/(JVS(1111))
  XX(172) = (X(172)-JVS(163)*XX(30)-JVS(323)*XX(33)-JVS(333)*XX(34)-JVS(351)*XX(36)-JVS(599)*XX(103)-JVS(729)*XX(127))&
              &/(JVS(1121))
  XX(173) = (X(173)-JVS(164)*XX(30)-JVS(844)*XX(146))/(JVS(1131))
  XX(174) = (X(174)-JVS(76)*XX(13)-JVS(79)*XX(14)-JVS(230)*XX(31)-JVS(290)*XX(32)-JVS(907)*XX(153)-JVS(1122)*XX(172))&
              &/(JVS(1140))
  XX(175) = (X(175)-JVS(23)*XX(5)-JVS(165)*XX(30)-JVS(845)*XX(146))/(JVS(1147))
  XX(176) = (X(176)-JVS(231)*XX(31))/(JVS(1166))
  XX(177) = (X(177)-JVS(166)*XX(30)-JVS(660)*XX(115))/(JVS(1184))
  XX(178) = (X(178)-JVS(418)*XX(61)-JVS(466)*XX(71)-JVS(521)*XX(86)-JVS(566)*XX(97)-JVS(787)*XX(138)-JVS(861)*XX(147))&
              &/(JVS(1208))
  XX(179) = (X(179)-JVS(167)*XX(30)-JVS(388)*XX(49)-JVS(582)*XX(100))/(JVS(1221))
  XX(180) = (X(180)-JVS(168)*XX(30)-JVS(232)*XX(31)-JVS(608)*XX(105)-JVS(846)*XX(146)-JVS(1003)*XX(162))/(JVS(1234))
  XX(181) = (X(181)-JVS(233)*XX(31)-JVS(291)*XX(32)-JVS(449)*XX(67)-JVS(834)*XX(145)-JVS(1092)*XX(170))/(JVS(1244))
  XX(182) = (X(182)-JVS(169)*XX(30)-JVS(847)*XX(146)-JVS(868)*XX(148)-JVS(1004)*XX(162))/(JVS(1256))
  XX(183) = (X(183)-JVS(170)*XX(30)-JVS(234)*XX(31)-JVS(869)*XX(148)-JVS(1005)*XX(162)-JVS(1257)*XX(182))/(JVS(1269))
  XX(184) = (X(184)-JVS(235)*XX(31)-JVS(366)*XX(40)-JVS(383)*XX(47)-JVS(480)*XX(74)-JVS(530)*XX(88)-JVS(571)*XX(98)&
              &-JVS(642)*XX(111)-JVS(788)*XX(138)-JVS(862)*XX(147)-JVS(1209)*XX(178))/(JVS(1284))
  XX(185) = (X(185)-JVS(171)*XX(30)-JVS(661)*XX(115)-JVS(848)*XX(146)-JVS(1185)*XX(177))/(JVS(1296))
  XX(186) = (X(186)-JVS(107)*XX(23)-JVS(109)*XX(24)-JVS(236)*XX(31)-JVS(625)*XX(108)-JVS(668)*XX(116)-JVS(702)*XX(122)&
              &-JVS(717)*XX(125))/(JVS(1309))
  XX(187) = (X(187)-JVS(172)*XX(30)-JVS(361)*XX(38)-JVS(450)*XX(67)-JVS(708)*XX(123)-JVS(977)*XX(159)-JVS(1080)*XX(169)&
              &-JVS(1093)*XX(170)-JVS(1132)*XX(173)-JVS(1245)*XX(181))/(JVS(1324))
  XX(188) = (X(188)-JVS(173)*XX(30)-JVS(237)*XX(31)-JVS(609)*XX(105)-JVS(849)*XX(146)-JVS(870)*XX(148)-JVS(1006)*XX(162)&
              &-JVS(1094)*XX(170))/(JVS(1333))
  XX(189) = (X(189)-JVS(174)*XX(30)-JVS(292)*XX(32)-JVS(646)*XX(112)-JVS(679)*XX(118)-JVS(692)*XX(120)-JVS(793)*XX(139)&
              &-JVS(850)*XX(146)-JVS(962)*XX(158))/(JVS(1344))
  XX(190) = (X(190)-JVS(175)*XX(30))/(JVS(1383))
  XX(191) = (X(191)-JVS(24)*XX(5)-JVS(238)*XX(31)-JVS(415)*XX(60)-JVS(451)*XX(67)-JVS(743)*XX(130)-JVS(751)*XX(131)&
              &-JVS(944)*XX(157)-JVS(963)*XX(158)-JVS(1043)*XX(165)-JVS(1081)*XX(169)-JVS(1095)*XX(170)-JVS(1133)*XX(173)&
              &-JVS(1246)*XX(181)-JVS(1325)*XX(187)-JVS(1384)*XX(190))/(JVS(1416))
  XX(192) = (X(192)-JVS(25)*XX(5)-JVS(293)*XX(32)-JVS(964)*XX(158)-JVS(1096)*XX(170)-JVS(1385)*XX(190))/(JVS(1434))
  XX(193) = (X(193)-JVS(26)*XX(5)-JVS(176)*XX(30)-JVS(294)*XX(32)-JVS(723)*XX(126)-JVS(776)*XX(136)-JVS(1148)*XX(175)&
              &-JVS(1386)*XX(190))/(JVS(1453))
  XX(194) = (X(194)-JVS(27)*XX(5))/(JVS(1479))
  XX(195) = (X(195)-JVS(177)*XX(30)-JVS(656)*XX(114)-JVS(851)*XX(146)-JVS(978)*XX(159)-JVS(1097)*XX(170)-JVS(1387)&
              &*XX(190)-JVS(1435)*XX(192)-JVS(1480)*XX(194))/(JVS(1508))
  XX(196) = (X(196)-JVS(239)*XX(31)-JVS(626)*XX(108)-JVS(879)*XX(149))/(JVS(1524))
  XX(197) = (X(197)-JVS(178)*XX(30)-JVS(324)*XX(33)-JVS(334)*XX(34)-JVS(352)*XX(36)-JVS(600)*XX(103)-JVS(1098)*XX(170)&
              &-JVS(1167)*XX(176))/(JVS(1541))
  XX(198) = (X(198)-JVS(240)*XX(31)-JVS(901)*XX(152)-JVS(915)*XX(154)-JVS(965)*XX(158)-JVS(1044)*XX(165)-JVS(1062)&
              &*XX(167)-JVS(1222)*XX(179)-JVS(1388)*XX(190)-JVS(1436)*XX(192))/(JVS(1554))
  XX(199) = (X(199)-JVS(179)*XX(30)-JVS(241)*XX(31)-JVS(627)*XX(108)-JVS(703)*XX(122)-JVS(718)*XX(125)-JVS(880)*XX(149)&
              &-JVS(1310)*XX(186)-JVS(1389)*XX(190)-JVS(1525)*XX(196))/(JVS(1565))
  XX(200) = (X(200)-JVS(122)*XX(29)-JVS(242)*XX(31)-JVS(295)*XX(32)-JVS(1390)*XX(190))/(JVS(1606))
  XX(201) = (X(201)-JVS(296)*XX(32)-JVS(1186)*XX(177)-JVS(1481)*XX(194)-JVS(1607)*XX(200))/(JVS(1633))
  XX(202) = (X(202)-JVS(243)*XX(31)-JVS(297)*XX(32)-JVS(921)*XX(155)-JVS(985)*XX(160)-JVS(1168)*XX(176)-JVS(1345)&
              &*XX(189)-JVS(1391)*XX(190)-JVS(1437)*XX(192)-JVS(1482)*XX(194)-JVS(1608)*XX(200))/(JVS(1650))
  XX(203) = (X(203)-JVS(28)*XX(5)-JVS(180)*XX(30)-JVS(298)*XX(32)-JVS(619)*XX(107)-JVS(637)*XX(110)-JVS(651)*XX(113)&
              &-JVS(698)*XX(121)-JVS(735)*XX(128)-JVS(739)*XX(129)-JVS(800)*XX(140)-JVS(852)*XX(146)-JVS(889)*XX(150)&
              &-JVS(945)*XX(157)-JVS(966)*XX(158)-JVS(979)*XX(159)-JVS(1045)*XX(165)-JVS(1099)*XX(170)-JVS(1247)*XX(181)&
              &-JVS(1326)*XX(187)-JVS(1346)*XX(189)-JVS(1392)*XX(190)-JVS(1417)*XX(191)-JVS(1438)*XX(192)-JVS(1483)*XX(194)&
              &-JVS(1609)*XX(200)-JVS(1651)*XX(202))/(JVS(1664))
  XX(204) = (X(204)-JVS(181)*XX(30)-JVS(504)*XX(81)-JVS(744)*XX(130)-JVS(1484)*XX(194))/(JVS(1678))
  XX(205) = (X(205)-JVS(182)*XX(30)-JVS(244)*XX(31)-JVS(764)*XX(133)-JVS(1418)*XX(191)-JVS(1439)*XX(192)-JVS(1485)&
              &*XX(194)-JVS(1555)*XX(198)-JVS(1610)*XX(200)-JVS(1652)*XX(202)-JVS(1679)*XX(204))/(JVS(1700))
  XX(206) = (X(206)-JVS(183)*XX(30)-JVS(615)*XX(106)-JVS(853)*XX(146)-JVS(1025)*XX(164)-JVS(1112)*XX(171)-JVS(1486)&
              &*XX(194)-JVS(1634)*XX(201)-JVS(1680)*XX(204))/(JVS(1723))
  XX(207) = (X(207)-JVS(245)*XX(31)-JVS(452)*XX(67)-JVS(1026)*XX(164)-JVS(1113)*XX(171)-JVS(1134)*XX(173)-JVS(1393)&
              &*XX(190)-JVS(1487)*XX(194)-JVS(1635)*XX(201)-JVS(1681)*XX(204)-JVS(1724)*XX(206))/(JVS(1745))
  XX(208) = (X(208)-JVS(29)*XX(5)-JVS(299)*XX(32)-JVS(1100)*XX(170)-JVS(1488)*XX(194)-JVS(1611)*XX(200))/(JVS(1794))
  XX(209) = (X(209)-JVS(184)*XX(30)-JVS(300)*XX(32)-JVS(730)*XX(127)-JVS(854)*XX(146)-JVS(1248)*XX(181)-JVS(1394)&
              &*XX(190)-JVS(1489)*XX(194)-JVS(1612)*XX(200)-JVS(1795)*XX(208))/(JVS(1815))
  XX(210) = (X(210)-JVS(246)*XX(31)-JVS(531)*XX(88)-JVS(559)*XX(96)-JVS(572)*XX(98)-JVS(628)*XX(108)-JVS(669)*XX(116)&
              &-JVS(827)*XX(144)-JVS(881)*XX(149)-JVS(1210)*XX(178)-JVS(1285)*XX(184)-JVS(1311)*XX(186)-JVS(1395)*XX(190)&
              &-JVS(1526)*XX(196)-JVS(1566)*XX(199))/(JVS(1840))
  XX(211) = (X(211)-JVS(247)*XX(31)-JVS(301)*XX(32)-JVS(894)*XX(151)-JVS(929)*XX(156)-JVS(995)*XX(161)-JVS(1046)*XX(165)&
              &-JVS(1070)*XX(168)-JVS(1169)*XX(176)-JVS(1490)*XX(194)-JVS(1542)*XX(197)-JVS(1613)*XX(200)-JVS(1796)*XX(208))&
              &/(JVS(1858))
  XX(212) = (X(212)-JVS(248)*XX(31)-JVS(302)*XX(32)-JVS(1223)*XX(179)-JVS(1396)*XX(190)-JVS(1682)*XX(204))/(JVS(1909))
  XX(213) = (X(213)-JVS(249)*XX(31)-JVS(1224)*XX(179)-JVS(1297)*XX(185)-JVS(1397)*XX(190)-JVS(1491)*XX(194)-JVS(1614)&
              &*XX(200)-JVS(1683)*XX(204)-JVS(1746)*XX(207)-JVS(1797)*XX(208)-JVS(1910)*XX(212))/(JVS(1952))
  XX(214) = (X(214)-JVS(250)*XX(31)-JVS(303)*XX(32)-JVS(817)*XX(143)-JVS(1398)*XX(190))/(JVS(2035))
  XX(215) = (X(215)-JVS(251)*XX(31)-JVS(304)*XX(32)-JVS(487)*XX(76)-JVS(724)*XX(126)-JVS(807)*XX(141)-JVS(986)*XX(160)&
              &-JVS(1055)*XX(166)-JVS(1149)*XX(175)-JVS(1170)*XX(176)-JVS(1399)*XX(190)-JVS(1454)*XX(193)-JVS(1492)*XX(194)&
              &-JVS(1543)*XX(197)-JVS(1615)*XX(200)-JVS(1747)*XX(207)-JVS(1798)*XX(208)-JVS(1816)*XX(209)-JVS(1911)*XX(212)&
              &-JVS(1953)*XX(213)-JVS(2036)*XX(214))/(JVS(2064))
  XX(216) = (X(216)-JVS(252)*XX(31)-JVS(305)*XX(32)-JVS(895)*XX(151)-JVS(1400)*XX(190)-JVS(2037)*XX(214))/(JVS(2100))
  XX(217) = (X(217)-JVS(253)*XX(31)-JVS(306)*XX(32)-JVS(1015)*XX(163)-JVS(1171)*XX(176)-JVS(1225)*XX(179)-JVS(1509)&
              &*XX(195)-JVS(1544)*XX(197)-JVS(1616)*XX(200)-JVS(1684)*XX(204)-JVS(1859)*XX(211)-JVS(1912)*XX(212)-JVS(1954)&
              &*XX(213)-JVS(2038)*XX(214)-JVS(2101)*XX(216))/(JVS(2122))
  XX(218) = (X(218)-JVS(30)*XX(5)-JVS(185)*XX(30)-JVS(307)*XX(32)-JVS(470)*XX(72)-JVS(577)*XX(99)-JVS(680)*XX(118)&
              &-JVS(693)*XX(120)-JVS(794)*XX(139)-JVS(801)*XX(140)-JVS(871)*XX(148)-JVS(967)*XX(158)-JVS(996)*XX(161)&
              &-JVS(1007)*XX(162)-JVS(1027)*XX(164)-JVS(1047)*XX(165)-JVS(1056)*XX(166)-JVS(1071)*XX(168)-JVS(1114)*XX(171)&
              &-JVS(1135)*XX(173)-JVS(1150)*XX(175)-JVS(1187)*XX(177)-JVS(1226)*XX(179)-JVS(1235)*XX(180)-JVS(1258)*XX(182)&
              &-JVS(1270)*XX(183)-JVS(1298)*XX(185)-JVS(1334)*XX(188)-JVS(1347)*XX(189)-JVS(1401)*XX(190)-JVS(1440)*XX(192)&
              &-JVS(1455)*XX(193)-JVS(1493)*XX(194)-JVS(1510)*XX(195)-JVS(1556)*XX(198)-JVS(1617)*XX(200)-JVS(1636)*XX(201)&
              &-JVS(1653)*XX(202)-JVS(1665)*XX(203)-JVS(1685)*XX(204)-JVS(1701)*XX(205)-JVS(1725)*XX(206)-JVS(1748)*XX(207)&
              &-JVS(1799)*XX(208)-JVS(1817)*XX(209)-JVS(1860)*XX(211)-JVS(1913)*XX(212)-JVS(1955)*XX(213)-JVS(2039)*XX(214)&
              &-JVS(2065)*XX(215)-JVS(2102)*XX(216)-JVS(2123)*XX(217))/(JVS(2186))
  XX(219) = (X(219)-JVS(335)*XX(34)-JVS(601)*XX(103)-JVS(908)*XX(153)-JVS(922)*XX(155)-JVS(930)*XX(156)-JVS(987)*XX(160)&
              &-JVS(1016)*XX(163)-JVS(1123)*XX(172)-JVS(1172)*XX(176)-JVS(1441)*XX(192)-JVS(1494)*XX(194)-JVS(1545)*XX(197)&
              &-JVS(1618)*XX(200)-JVS(1800)*XX(208)-JVS(1818)*XX(209)-JVS(1914)*XX(212)-JVS(1956)*XX(213)-JVS(2040)*XX(214)&
              &-JVS(2066)*XX(215)-JVS(2103)*XX(216)-JVS(2124)*XX(217)-JVS(2187)*XX(218))/(JVS(2217))
  XX(220) = (X(220)-JVS(31)*XX(5)-JVS(325)*XX(33)-JVS(909)*XX(153)-JVS(923)*XX(155)-JVS(931)*XX(156)-JVS(988)*XX(160)&
              &-JVS(1017)*XX(163)-JVS(1124)*XX(172)-JVS(1173)*XX(176)-JVS(1442)*XX(192)-JVS(1495)*XX(194)-JVS(1546)*XX(197)&
              &-JVS(1619)*XX(200)-JVS(1801)*XX(208)-JVS(1819)*XX(209)-JVS(1915)*XX(212)-JVS(1957)*XX(213)-JVS(2041)*XX(214)&
              &-JVS(2067)*XX(215)-JVS(2104)*XX(216)-JVS(2125)*XX(217)-JVS(2188)*XX(218)-JVS(2218)*XX(219))/(JVS(2287))
  XX(221) = (X(221)-JVS(32)*XX(5)-JVS(64)*XX(10)-JVS(186)*XX(30)-JVS(254)*XX(31)-JVS(308)*XX(32)-JVS(495)*XX(78)&
              &-JVS(560)*XX(96)-JVS(712)*XX(124)-JVS(745)*XX(130)-JVS(855)*XX(146)-JVS(872)*XX(148)-JVS(882)*XX(149)&
              &-JVS(902)*XX(152)-JVS(916)*XX(154)-JVS(968)*XX(158)-JVS(997)*XX(161)-JVS(1008)*XX(162)-JVS(1028)*XX(164)&
              &-JVS(1048)*XX(165)-JVS(1057)*XX(166)-JVS(1072)*XX(168)-JVS(1115)*XX(171)-JVS(1136)*XX(173)-JVS(1151)*XX(175)&
              &-JVS(1188)*XX(177)-JVS(1227)*XX(179)-JVS(1236)*XX(180)-JVS(1259)*XX(182)-JVS(1271)*XX(183)-JVS(1299)*XX(185)&
              &-JVS(1335)*XX(188)-JVS(1348)*XX(189)-JVS(1402)*XX(190)-JVS(1419)*XX(191)-JVS(1443)*XX(192)-JVS(1456)*XX(193)&
              &-JVS(1496)*XX(194)-JVS(1511)*XX(195)-JVS(1527)*XX(196)-JVS(1557)*XX(198)-JVS(1620)*XX(200)-JVS(1637)*XX(201)&
              &-JVS(1654)*XX(202)-JVS(1666)*XX(203)-JVS(1686)*XX(204)-JVS(1702)*XX(205)-JVS(1726)*XX(206)-JVS(1749)*XX(207)&
              &-JVS(1802)*XX(208)-JVS(1820)*XX(209)-JVS(1861)*XX(211)-JVS(1916)*XX(212)-JVS(1958)*XX(213)-JVS(2042)*XX(214)&
              &-JVS(2068)*XX(215)-JVS(2105)*XX(216)-JVS(2126)*XX(217)-JVS(2189)*XX(218)-JVS(2219)*XX(219)-JVS(2288)*XX(220))&
              &/(JVS(2357))
  XX(222) = (X(222)-JVS(309)*XX(32)-JVS(393)*XX(51)-JVS(633)*XX(109)-JVS(670)*XX(116)-JVS(781)*XX(137)-JVS(828)*XX(144)&
              &-JVS(1029)*XX(164)-JVS(1073)*XX(168)-JVS(1116)*XX(171)-JVS(1189)*XX(177)-JVS(1312)*XX(186)-JVS(1403)*XX(190)&
              &-JVS(1497)*XX(194)-JVS(1567)*XX(199)-JVS(1621)*XX(200)-JVS(1638)*XX(201)-JVS(1687)*XX(204)-JVS(1803)*XX(208)&
              &-JVS(1841)*XX(210)-JVS(1862)*XX(211)-JVS(1917)*XX(212)-JVS(2043)*XX(214)-JVS(2106)*XX(216)-JVS(2190)*XX(218)&
              &-JVS(2220)*XX(219)-JVS(2289)*XX(220)-JVS(2358)*XX(221))/(JVS(2409))
  XX(223) = (X(223)-JVS(33)*XX(5)-JVS(65)*XX(10)-JVS(74)*XX(12)-JVS(86)*XX(16)-JVS(99)*XX(20)-JVS(187)*XX(30)-JVS(255)&
              &*XX(31)-JVS(310)*XX(32)-JVS(362)*XX(38)-JVS(419)*XX(61)-JVS(426)*XX(63)-JVS(431)*XX(64)-JVS(453)*XX(67)&
              &-JVS(455)*XX(68)-JVS(462)*XX(70)-JVS(532)*XX(88)-JVS(567)*XX(97)-JVS(638)*XX(110)-JVS(652)*XX(113)-JVS(675)&
              &*XX(117)-JVS(681)*XX(118)-JVS(694)*XX(120)-JVS(752)*XX(131)-JVS(795)*XX(139)-JVS(802)*XX(140)-JVS(835)&
              &*XX(145)-JVS(863)*XX(147)-JVS(873)*XX(148)-JVS(890)*XX(150)-JVS(903)*XX(152)-JVS(910)*XX(153)-JVS(917)&
              &*XX(154)-JVS(924)*XX(155)-JVS(932)*XX(156)-JVS(946)*XX(157)-JVS(969)*XX(158)-JVS(980)*XX(159)-JVS(989)&
              &*XX(160)-JVS(998)*XX(161)-JVS(1009)*XX(162)-JVS(1018)*XX(163)-JVS(1030)*XX(164)-JVS(1049)*XX(165)-JVS(1058)&
              &*XX(166)-JVS(1063)*XX(167)-JVS(1074)*XX(168)-JVS(1082)*XX(169)-JVS(1101)*XX(170)-JVS(1117)*XX(171)-JVS(1125)&
              &*XX(172)-JVS(1137)*XX(173)-JVS(1152)*XX(175)-JVS(1174)*XX(176)-JVS(1190)*XX(177)-JVS(1211)*XX(178)-JVS(1228)&
              &*XX(179)-JVS(1237)*XX(180)-JVS(1249)*XX(181)-JVS(1260)*XX(182)-JVS(1272)*XX(183)-JVS(1286)*XX(184)-JVS(1300)&
              &*XX(185)-JVS(1327)*XX(187)-JVS(1336)*XX(188)-JVS(1349)*XX(189)-JVS(1404)*XX(190)-JVS(1420)*XX(191)-JVS(1444)&
              &*XX(192)-JVS(1457)*XX(193)-JVS(1498)*XX(194)-JVS(1512)*XX(195)-JVS(1528)*XX(196)-JVS(1547)*XX(197)-JVS(1558)&
              &*XX(198)-JVS(1622)*XX(200)-JVS(1639)*XX(201)-JVS(1655)*XX(202)-JVS(1667)*XX(203)-JVS(1688)*XX(204)-JVS(1703)&
              &*XX(205)-JVS(1727)*XX(206)-JVS(1750)*XX(207)-JVS(1804)*XX(208)-JVS(1821)*XX(209)-JVS(1842)*XX(210)-JVS(1863)&
              &*XX(211)-JVS(1918)*XX(212)-JVS(1959)*XX(213)-JVS(2044)*XX(214)-JVS(2069)*XX(215)-JVS(2107)*XX(216)-JVS(2127)&
              &*XX(217)-JVS(2191)*XX(218)-JVS(2221)*XX(219)-JVS(2290)*XX(220)-JVS(2359)*XX(221)-JVS(2410)*XX(222))&
              &/(JVS(2492))
  XX(224) = (X(224)-JVS(256)*XX(31)-JVS(629)*XX(108)-JVS(671)*XX(116)-JVS(704)*XX(122)-JVS(719)*XX(125)-JVS(818)*XX(143)&
              &-JVS(1313)*XX(186)-JVS(1405)*XX(190)-JVS(1529)*XX(196)-JVS(1568)*XX(199)-JVS(1843)*XX(210)-JVS(2411)*XX(222)&
              &-JVS(2493)*XX(223))/(JVS(2526))
  XX(225) = (X(225)-JVS(257)*XX(31)-JVS(512)*XX(83)-JVS(630)*XX(108)-JVS(757)*XX(132)-JVS(819)*XX(143)-JVS(829)*XX(144)&
              &-JVS(883)*XX(149)-JVS(1314)*XX(186)-JVS(1406)*XX(190)-JVS(1530)*XX(196)-JVS(1569)*XX(199)-JVS(1844)*XX(210)&
              &-JVS(2412)*XX(222)-JVS(2494)*XX(223)-JVS(2527)*XX(224))/(JVS(2588))
  XX(226) = (X(226)-JVS(258)*XX(31)-JVS(339)*XX(35)-JVS(378)*XX(45)-JVS(380)*XX(46)-JVS(396)*XX(52)-JVS(398)*XX(53)&
              &-JVS(400)*XX(54)-JVS(402)*XX(55)-JVS(404)*XX(56)-JVS(406)*XX(57)-JVS(408)*XX(58)-JVS(422)*XX(62)-JVS(474)&
              &*XX(73)-JVS(501)*XX(80)-JVS(508)*XX(82)-JVS(515)*XX(84)-JVS(518)*XX(85)-JVS(524)*XX(87)-JVS(551)*XX(94)&
              &-JVS(820)*XX(143)-JVS(884)*XX(149)-JVS(896)*XX(151)-JVS(1531)*XX(196)-JVS(1845)*XX(210)-JVS(2045)*XX(214)&
              &-JVS(2291)*XX(220)-JVS(2360)*XX(221)-JVS(2413)*XX(222)-JVS(2495)*XX(223)-JVS(2528)*XX(224)-JVS(2589)*XX(225))&
              &/(JVS(2633))
  XX(227) = (X(227)-JVS(34)*XX(5)-JVS(188)*XX(30)-JVS(311)*XX(32)-JVS(340)*XX(35)-JVS(483)*XX(75)-JVS(492)*XX(77)&
              &-JVS(548)*XX(93)-JVS(561)*XX(96)-JVS(604)*XX(104)-JVS(634)*XX(109)-JVS(713)*XX(124)-JVS(746)*XX(130)-JVS(782)&
              &*XX(137)-JVS(821)*XX(143)-JVS(885)*XX(149)-JVS(897)*XX(151)-JVS(1031)*XX(164)-JVS(1075)*XX(168)-JVS(1102)&
              &*XX(170)-JVS(1118)*XX(171)-JVS(1141)*XX(174)-JVS(1175)*XX(176)-JVS(1191)*XX(177)-JVS(1407)*XX(190)-JVS(1499)&
              &*XX(194)-JVS(1513)*XX(195)-JVS(1532)*XX(196)-JVS(1548)*XX(197)-JVS(1570)*XX(199)-JVS(1623)*XX(200)-JVS(1640)&
              &*XX(201)-JVS(1668)*XX(203)-JVS(1689)*XX(204)-JVS(1704)*XX(205)-JVS(1728)*XX(206)-JVS(1751)*XX(207)-JVS(1805)&
              &*XX(208)-JVS(1822)*XX(209)-JVS(1846)*XX(210)-JVS(1864)*XX(211)-JVS(1919)*XX(212)-JVS(1960)*XX(213)-JVS(2046)&
              &*XX(214)-JVS(2070)*XX(215)-JVS(2108)*XX(216)-JVS(2128)*XX(217)-JVS(2192)*XX(218)-JVS(2222)*XX(219)-JVS(2292)&
              &*XX(220)-JVS(2361)*XX(221)-JVS(2414)*XX(222)-JVS(2496)*XX(223)-JVS(2529)*XX(224)-JVS(2590)*XX(225)-JVS(2634)&
              &*XX(226))/(JVS(2722))
  XX(228) = (X(228)-JVS(259)*XX(31)-JVS(312)*XX(32)-JVS(458)*XX(69)-JVS(822)*XX(143)-JVS(1176)*XX(176)-JVS(1315)*XX(186)&
              &-JVS(1408)*XX(190)-JVS(1571)*XX(199)-JVS(1847)*XX(210)-JVS(2047)*XX(214)-JVS(2223)*XX(219)-JVS(2293)*XX(220)&
              &-JVS(2362)*XX(221)-JVS(2415)*XX(222)-JVS(2497)*XX(223)-JVS(2530)*XX(224)-JVS(2591)*XX(225)-JVS(2635)*XX(226)&
              &-JVS(2723)*XX(227))/(JVS(2777))
  XX(229) = (X(229)-JVS(35)*XX(5)-JVS(66)*XX(10)-JVS(80)*XX(14)-JVS(260)*XX(31)-JVS(313)*XX(32)-JVS(488)*XX(76)-JVS(542)&
              &*XX(91)-JVS(545)*XX(92)-JVS(605)*XX(104)-JVS(687)*XX(119)-JVS(725)*XX(126)-JVS(758)*XX(132)-JVS(768)*XX(134)&
              &-JVS(772)*XX(135)-JVS(783)*XX(137)-JVS(789)*XX(138)-JVS(808)*XX(141)-JVS(812)*XX(142)-JVS(864)*XX(147)&
              &-JVS(874)*XX(148)-JVS(918)*XX(154)-JVS(970)*XX(158)-JVS(999)*XX(161)-JVS(1010)*XX(162)-JVS(1050)*XX(165)&
              &-JVS(1059)*XX(166)-JVS(1064)*XX(167)-JVS(1103)*XX(170)-JVS(1142)*XX(174)-JVS(1153)*XX(175)-JVS(1177)*XX(176)&
              &-JVS(1212)*XX(178)-JVS(1229)*XX(179)-JVS(1238)*XX(180)-JVS(1261)*XX(182)-JVS(1273)*XX(183)-JVS(1287)*XX(184)&
              &-JVS(1301)*XX(185)-JVS(1337)*XX(188)-JVS(1409)*XX(190)-JVS(1458)*XX(193)-JVS(1500)*XX(194)-JVS(1514)*XX(195)&
              &-JVS(1533)*XX(196)-JVS(1549)*XX(197)-JVS(1559)*XX(198)-JVS(1624)*XX(200)-JVS(1641)*XX(201)-JVS(1656)*XX(202)&
              &-JVS(1669)*XX(203)-JVS(1690)*XX(204)-JVS(1705)*XX(205)-JVS(1729)*XX(206)-JVS(1752)*XX(207)-JVS(1806)*XX(208)&
              &-JVS(1823)*XX(209)-JVS(1848)*XX(210)-JVS(1865)*XX(211)-JVS(1920)*XX(212)-JVS(1961)*XX(213)-JVS(2048)*XX(214)&
              &-JVS(2071)*XX(215)-JVS(2109)*XX(216)-JVS(2129)*XX(217)-JVS(2193)*XX(218)-JVS(2224)*XX(219)-JVS(2294)*XX(220)&
              &-JVS(2363)*XX(221)-JVS(2416)*XX(222)-JVS(2498)*XX(223)-JVS(2531)*XX(224)-JVS(2592)*XX(225)-JVS(2636)*XX(226)&
              &-JVS(2724)*XX(227)-JVS(2778)*XX(228))/(JVS(2862))
  XX(230) = (X(230)-JVS(67)*XX(10)-JVS(189)*XX(30)-JVS(261)*XX(31)-JVS(386)*XX(48)-JVS(389)*XX(49)-JVS(394)*XX(51)&
              &-JVS(423)*XX(62)-JVS(456)*XX(68)-JVS(489)*XX(76)-JVS(496)*XX(78)-JVS(522)*XX(86)-JVS(554)*XX(95)-JVS(568)&
              &*XX(97)-JVS(578)*XX(99)-JVS(759)*XX(132)-JVS(777)*XX(136)-JVS(790)*XX(138)-JVS(809)*XX(141)-JVS(830)*XX(144)&
              &-JVS(836)*XX(145)-JVS(865)*XX(147)-JVS(911)*XX(153)-JVS(925)*XX(155)-JVS(933)*XX(156)-JVS(990)*XX(160)&
              &-JVS(1019)*XX(163)-JVS(1065)*XX(167)-JVS(1104)*XX(170)-JVS(1126)*XX(172)-JVS(1178)*XX(176)-JVS(1213)*XX(178)&
              &-JVS(1230)*XX(179)-JVS(1288)*XX(184)-JVS(1316)*XX(186)-JVS(1410)*XX(190)-JVS(1445)*XX(192)-JVS(1459)*XX(193)&
              &-JVS(1501)*XX(194)-JVS(1534)*XX(196)-JVS(1550)*XX(197)-JVS(1572)*XX(199)-JVS(1625)*XX(200)-JVS(1691)*XX(204)&
              &-JVS(1807)*XX(208)-JVS(1824)*XX(209)-JVS(1849)*XX(210)-JVS(1921)*XX(212)-JVS(1962)*XX(213)-JVS(2049)*XX(214)&
              &-JVS(2072)*XX(215)-JVS(2110)*XX(216)-JVS(2130)*XX(217)-JVS(2194)*XX(218)-JVS(2225)*XX(219)-JVS(2295)*XX(220)&
              &-JVS(2364)*XX(221)-JVS(2417)*XX(222)-JVS(2499)*XX(223)-JVS(2532)*XX(224)-JVS(2593)*XX(225)-JVS(2637)*XX(226)&
              &-JVS(2725)*XX(227)-JVS(2779)*XX(228)-JVS(2863)*XX(229))/(JVS(2971))
  XX(231) = (X(231)-JVS(36)*XX(5)-JVS(262)*XX(31)-JVS(314)*XX(32)-JVS(353)*XX(36)-JVS(682)*XX(118)-JVS(688)*XX(119)&
              &-JVS(705)*XX(122)-JVS(720)*XX(125)-JVS(747)*XX(130)-JVS(753)*XX(131)-JVS(769)*XX(134)-JVS(773)*XX(135)&
              &-JVS(778)*XX(136)-JVS(796)*XX(139)-JVS(813)*XX(142)-JVS(823)*XX(143)-JVS(891)*XX(150)-JVS(898)*XX(151)&
              &-JVS(912)*XX(153)-JVS(926)*XX(155)-JVS(934)*XX(156)-JVS(947)*XX(157)-JVS(971)*XX(158)-JVS(981)*XX(159)&
              &-JVS(991)*XX(160)-JVS(1011)*XX(162)-JVS(1020)*XX(163)-JVS(1051)*XX(165)-JVS(1105)*XX(170)-JVS(1127)*XX(172)&
              &-JVS(1143)*XX(174)-JVS(1179)*XX(176)-JVS(1214)*XX(178)-JVS(1239)*XX(180)-JVS(1250)*XX(181)-JVS(1262)*XX(182)&
              &-JVS(1274)*XX(183)-JVS(1289)*XX(184)-JVS(1302)*XX(185)-JVS(1317)*XX(186)-JVS(1328)*XX(187)-JVS(1338)*XX(188)&
              &-JVS(1411)*XX(190)-JVS(1421)*XX(191)-JVS(1446)*XX(192)-JVS(1460)*XX(193)-JVS(1502)*XX(194)-JVS(1515)*XX(195)&
              &-JVS(1535)*XX(196)-JVS(1551)*XX(197)-JVS(1560)*XX(198)-JVS(1573)*XX(199)-JVS(1626)*XX(200)-JVS(1642)*XX(201)&
              &-JVS(1657)*XX(202)-JVS(1670)*XX(203)-JVS(1692)*XX(204)-JVS(1706)*XX(205)-JVS(1730)*XX(206)-JVS(1753)*XX(207)&
              &-JVS(1808)*XX(208)-JVS(1825)*XX(209)-JVS(1850)*XX(210)-JVS(1866)*XX(211)-JVS(1922)*XX(212)-JVS(1963)*XX(213)&
              &-JVS(2050)*XX(214)-JVS(2073)*XX(215)-JVS(2111)*XX(216)-JVS(2131)*XX(217)-JVS(2195)*XX(218)-JVS(2226)*XX(219)&
              &-JVS(2296)*XX(220)-JVS(2365)*XX(221)-JVS(2418)*XX(222)-JVS(2500)*XX(223)-JVS(2533)*XX(224)-JVS(2594)*XX(225)&
              &-JVS(2638)*XX(226)-JVS(2726)*XX(227)-JVS(2780)*XX(228)-JVS(2864)*XX(229)-JVS(2972)*XX(230))/(JVS(3027))
  XX(232) = (X(232)-JVS(37)*XX(5)-JVS(68)*XX(10)-JVS(71)*XX(11)-JVS(83)*XX(15)-JVS(96)*XX(19)-JVS(190)*XX(30)-JVS(263)&
              &*XX(31)-JVS(315)*XX(32)-JVS(354)*XX(36)-JVS(427)*XX(63)-JVS(432)*XX(64)-JVS(463)*XX(70)-JVS(467)*XX(71)&
              &-JVS(471)*XX(72)-JVS(505)*XX(81)-JVS(535)*XX(89)-JVS(539)*XX(90)-JVS(555)*XX(95)-JVS(583)*XX(100)-JVS(587)&
              &*XX(101)-JVS(591)*XX(102)-JVS(610)*XX(105)-JVS(616)*XX(106)-JVS(639)*XX(110)-JVS(643)*XX(111)-JVS(647)&
              &*XX(112)-JVS(653)*XX(113)-JVS(657)*XX(114)-JVS(662)*XX(115)-JVS(676)*XX(117)-JVS(695)*XX(120)-JVS(699)&
              &*XX(121)-JVS(709)*XX(123)-JVS(714)*XX(124)-JVS(726)*XX(126)-JVS(731)*XX(127)-JVS(736)*XX(128)-JVS(740)&
              &*XX(129)-JVS(754)*XX(131)-JVS(765)*XX(133)-JVS(797)*XX(139)-JVS(803)*XX(140)-JVS(824)*XX(143)-JVS(837)&
              &*XX(145)-JVS(875)*XX(148)-JVS(904)*XX(152)-JVS(919)*XX(154)-JVS(948)*XX(157)-JVS(972)*XX(158)-JVS(982)&
              &*XX(159)-JVS(1000)*XX(161)-JVS(1012)*XX(162)-JVS(1032)*XX(164)-JVS(1052)*XX(165)-JVS(1060)*XX(166)-JVS(1066)&
              &*XX(167)-JVS(1076)*XX(168)-JVS(1083)*XX(169)-JVS(1106)*XX(170)-JVS(1119)*XX(171)-JVS(1138)*XX(173)-JVS(1154)&
              &*XX(175)-JVS(1180)*XX(176)-JVS(1192)*XX(177)-JVS(1215)*XX(178)-JVS(1231)*XX(179)-JVS(1240)*XX(180)-JVS(1251)&
              &*XX(181)-JVS(1263)*XX(182)-JVS(1275)*XX(183)-JVS(1290)*XX(184)-JVS(1303)*XX(185)-JVS(1318)*XX(186)-JVS(1329)&
              &*XX(187)-JVS(1339)*XX(188)-JVS(1350)*XX(189)-JVS(1412)*XX(190)-JVS(1447)*XX(192)-JVS(1461)*XX(193)-JVS(1503)&
              &*XX(194)-JVS(1516)*XX(195)-JVS(1536)*XX(196)-JVS(1574)*XX(199)-JVS(1627)*XX(200)-JVS(1643)*XX(201)-JVS(1658)&
              &*XX(202)-JVS(1671)*XX(203)-JVS(1693)*XX(204)-JVS(1707)*XX(205)-JVS(1731)*XX(206)-JVS(1754)*XX(207)-JVS(1809)&
              &*XX(208)-JVS(1826)*XX(209)-JVS(1851)*XX(210)-JVS(1867)*XX(211)-JVS(1923)*XX(212)-JVS(1964)*XX(213)-JVS(2051)&
              &*XX(214)-JVS(2074)*XX(215)-JVS(2112)*XX(216)-JVS(2132)*XX(217)-JVS(2196)*XX(218)-JVS(2227)*XX(219)-JVS(2297)&
              &*XX(220)-JVS(2366)*XX(221)-JVS(2419)*XX(222)-JVS(2501)*XX(223)-JVS(2534)*XX(224)-JVS(2595)*XX(225)-JVS(2639)&
              &*XX(226)-JVS(2727)*XX(227)-JVS(2781)*XX(228)-JVS(2865)*XX(229)-JVS(2973)*XX(230)-JVS(3028)*XX(231))&
              &/(JVS(3145))
  XX(233) = (X(233)-JVS(264)*XX(31)-JVS(481)*XX(74)-JVS(498)*XX(79)-JVS(562)*XX(96)-JVS(573)*XX(98)-JVS(631)*XX(108)&
              &-JVS(886)*XX(149)-JVS(1216)*XX(178)-JVS(1291)*XX(184)-JVS(1413)*XX(190)-JVS(1537)*XX(196)-JVS(1575)*XX(199)&
              &-JVS(1852)*XX(210)-JVS(2052)*XX(214)-JVS(2298)*XX(220)-JVS(2367)*XX(221)-JVS(2420)*XX(222)-JVS(2502)*XX(223)&
              &-JVS(2535)*XX(224)-JVS(2596)*XX(225)-JVS(2640)*XX(226)-JVS(2728)*XX(227)-JVS(2782)*XX(228)-JVS(2866)*XX(229)&
              &-JVS(2974)*XX(230)-JVS(3029)*XX(231)-JVS(3146)*XX(232))/(JVS(3191))
  XX(234) = (X(234)-JVS(38)*XX(5)-JVS(77)*XX(13)-JVS(93)*XX(18)-JVS(102)*XX(21)-JVS(105)*XX(22)-JVS(120)*XX(28)-JVS(191)&
              &*XX(30)-JVS(265)*XX(31)-JVS(316)*XX(32)-JVS(326)*XX(33)-JVS(336)*XX(34)-JVS(341)*XX(35)-JVS(355)*XX(36)&
              &-JVS(372)*XX(42)-JVS(374)*XX(43)-JVS(376)*XX(44)-JVS(391)*XX(50)-JVS(416)*XX(60)-JVS(428)*XX(63)-JVS(433)&
              &*XX(64)-JVS(438)*XX(65)-JVS(443)*XX(66)-JVS(459)*XX(69)-JVS(464)*XX(70)-JVS(468)*XX(71)-JVS(472)*XX(72)&
              &-JVS(475)*XX(73)-JVS(484)*XX(75)-JVS(490)*XX(76)-JVS(493)*XX(77)-JVS(499)*XX(79)-JVS(502)*XX(80)-JVS(506)&
              &*XX(81)-JVS(509)*XX(82)-JVS(513)*XX(83)-JVS(516)*XX(84)-JVS(519)*XX(85)-JVS(525)*XX(87)-JVS(536)*XX(89)&
              &-JVS(540)*XX(90)-JVS(543)*XX(91)-JVS(546)*XX(92)-JVS(549)*XX(93)-JVS(552)*XX(94)-JVS(556)*XX(95)-JVS(563)&
              &*XX(96)-JVS(569)*XX(97)-JVS(574)*XX(98)-JVS(579)*XX(99)-JVS(584)*XX(100)-JVS(588)*XX(101)-JVS(592)*XX(102)&
              &-JVS(602)*XX(103)-JVS(606)*XX(104)-JVS(611)*XX(105)-JVS(617)*XX(106)-JVS(620)*XX(107)-JVS(635)*XX(109)&
              &-JVS(644)*XX(111)-JVS(648)*XX(112)-JVS(654)*XX(113)-JVS(658)*XX(114)-JVS(663)*XX(115)-JVS(672)*XX(116)&
              &-JVS(677)*XX(117)-JVS(683)*XX(118)-JVS(689)*XX(119)-JVS(696)*XX(120)-JVS(700)*XX(121)-JVS(710)*XX(123)&
              &-JVS(715)*XX(124)-JVS(727)*XX(126)-JVS(732)*XX(127)-JVS(737)*XX(128)-JVS(741)*XX(129)-JVS(748)*XX(130)&
              &-JVS(755)*XX(131)-JVS(766)*XX(133)-JVS(770)*XX(134)-JVS(774)*XX(135)-JVS(779)*XX(136)-JVS(784)*XX(137)&
              &-JVS(798)*XX(139)-JVS(810)*XX(141)-JVS(814)*XX(142)-JVS(825)*XX(143)-JVS(838)*XX(145)-JVS(856)*XX(146)&
              &-JVS(866)*XX(147)-JVS(876)*XX(148)-JVS(887)*XX(149)-JVS(892)*XX(150)-JVS(899)*XX(151)-JVS(905)*XX(152)&
              &-JVS(949)*XX(157)-JVS(973)*XX(158)-JVS(983)*XX(159)-JVS(1001)*XX(161)-JVS(1013)*XX(162)-JVS(1033)*XX(164)&
              &-JVS(1053)*XX(165)-JVS(1067)*XX(167)-JVS(1077)*XX(168)-JVS(1084)*XX(169)-JVS(1107)*XX(170)-JVS(1120)*XX(171)&
              &-JVS(1139)*XX(173)-JVS(1144)*XX(174)-JVS(1155)*XX(175)-JVS(1181)*XX(176)-JVS(1193)*XX(177)-JVS(1217)*XX(178)&
              &-JVS(1232)*XX(179)-JVS(1241)*XX(180)-JVS(1252)*XX(181)-JVS(1264)*XX(182)-JVS(1276)*XX(183)-JVS(1292)*XX(184)&
              &-JVS(1304)*XX(185)-JVS(1319)*XX(186)-JVS(1330)*XX(187)-JVS(1340)*XX(188)-JVS(1351)*XX(189)-JVS(1414)*XX(190)&
              &-JVS(1422)*XX(191)-JVS(1448)*XX(192)-JVS(1462)*XX(193)-JVS(1504)*XX(194)-JVS(1517)*XX(195)-JVS(1538)*XX(196)&
              &-JVS(1552)*XX(197)-JVS(1561)*XX(198)-JVS(1576)*XX(199)-JVS(1628)*XX(200)-JVS(1644)*XX(201)-JVS(1659)*XX(202)&
              &-JVS(1672)*XX(203)-JVS(1694)*XX(204)-JVS(1708)*XX(205)-JVS(1732)*XX(206)-JVS(1755)*XX(207)-JVS(1810)*XX(208)&
              &-JVS(1827)*XX(209)-JVS(1853)*XX(210)-JVS(1868)*XX(211)-JVS(1924)*XX(212)-JVS(1965)*XX(213)-JVS(2053)*XX(214)&
              &-JVS(2075)*XX(215)-JVS(2113)*XX(216)-JVS(2133)*XX(217)-JVS(2197)*XX(218)-JVS(2228)*XX(219)-JVS(2299)*XX(220)&
              &-JVS(2368)*XX(221)-JVS(2421)*XX(222)-JVS(2503)*XX(223)-JVS(2536)*XX(224)-JVS(2597)*XX(225)-JVS(2641)*XX(226)&
              &-JVS(2729)*XX(227)-JVS(2783)*XX(228)-JVS(2867)*XX(229)-JVS(2975)*XX(230)-JVS(3030)*XX(231)-JVS(3147)*XX(232)&
              &-JVS(3192)*XX(233))/(JVS(3354))
  XX(235) = (X(235)-JVS(266)*XX(31)-JVS(356)*XX(36)-JVS(733)*XX(127)-JVS(760)*XX(132)-JVS(831)*XX(144)-JVS(913)*XX(153)&
              &-JVS(927)*XX(155)-JVS(935)*XX(156)-JVS(992)*XX(160)-JVS(1021)*XX(163)-JVS(1108)*XX(170)-JVS(1128)*XX(172)&
              &-JVS(1182)*XX(176)-JVS(1320)*XX(186)-JVS(1415)*XX(190)-JVS(1449)*XX(192)-JVS(1505)*XX(194)-JVS(1539)*XX(196)&
              &-JVS(1553)*XX(197)-JVS(1577)*XX(199)-JVS(1629)*XX(200)-JVS(1811)*XX(208)-JVS(1828)*XX(209)-JVS(1854)*XX(210)&
              &-JVS(1925)*XX(212)-JVS(1966)*XX(213)-JVS(2054)*XX(214)-JVS(2076)*XX(215)-JVS(2114)*XX(216)-JVS(2134)*XX(217)&
              &-JVS(2198)*XX(218)-JVS(2229)*XX(219)-JVS(2300)*XX(220)-JVS(2369)*XX(221)-JVS(2422)*XX(222)-JVS(2504)*XX(223)&
              &-JVS(2537)*XX(224)-JVS(2598)*XX(225)-JVS(2642)*XX(226)-JVS(2730)*XX(227)-JVS(2784)*XX(228)-JVS(2868)*XX(229)&
              &-JVS(2976)*XX(230)-JVS(3031)*XX(231)-JVS(3148)*XX(232)-JVS(3193)*XX(233)-JVS(3355)*XX(234))/(JVS(3441))
  XX(235) = XX(235)
  XX(234) = XX(234)-JVS(3440)*XX(235)
  XX(233) = XX(233)-JVS(3353)*XX(234)-JVS(3439)*XX(235)
  XX(232) = XX(232)-JVS(3190)*XX(233)-JVS(3352)*XX(234)-JVS(3438)*XX(235)
  XX(231) = XX(231)-JVS(3144)*XX(232)-JVS(3189)*XX(233)-JVS(3351)*XX(234)-JVS(3437)*XX(235)
  XX(230) = XX(230)-JVS(3026)*XX(231)-JVS(3143)*XX(232)-JVS(3188)*XX(233)-JVS(3350)*XX(234)-JVS(3436)*XX(235)
  XX(229) = XX(229)-JVS(2970)*XX(230)-JVS(3025)*XX(231)-JVS(3142)*XX(232)-JVS(3187)*XX(233)-JVS(3349)*XX(234)-JVS(3435)&
              &*XX(235)
  XX(228) = XX(228)-JVS(2861)*XX(229)-JVS(2969)*XX(230)-JVS(3024)*XX(231)-JVS(3141)*XX(232)-JVS(3186)*XX(233)-JVS(3348)&
              &*XX(234)-JVS(3434)*XX(235)
  XX(227) = XX(227)-JVS(2776)*XX(228)-JVS(2860)*XX(229)-JVS(2968)*XX(230)-JVS(3023)*XX(231)-JVS(3140)*XX(232)-JVS(3185)&
              &*XX(233)-JVS(3347)*XX(234)-JVS(3433)*XX(235)
  XX(226) = XX(226)-JVS(2721)*XX(227)-JVS(2775)*XX(228)-JVS(2859)*XX(229)-JVS(2967)*XX(230)-JVS(3022)*XX(231)-JVS(3139)&
              &*XX(232)-JVS(3184)*XX(233)-JVS(3346)*XX(234)-JVS(3432)*XX(235)
  XX(225) = XX(225)-JVS(2632)*XX(226)-JVS(2720)*XX(227)-JVS(2774)*XX(228)-JVS(2858)*XX(229)-JVS(2966)*XX(230)-JVS(3021)&
              &*XX(231)-JVS(3138)*XX(232)-JVS(3183)*XX(233)-JVS(3345)*XX(234)-JVS(3431)*XX(235)
  XX(224) = XX(224)-JVS(2587)*XX(225)-JVS(2631)*XX(226)-JVS(2719)*XX(227)-JVS(2773)*XX(228)-JVS(2857)*XX(229)-JVS(2965)&
              &*XX(230)-JVS(3020)*XX(231)-JVS(3137)*XX(232)-JVS(3182)*XX(233)-JVS(3344)*XX(234)-JVS(3430)*XX(235)
  XX(223) = XX(223)-JVS(2525)*XX(224)-JVS(2586)*XX(225)-JVS(2630)*XX(226)-JVS(2718)*XX(227)-JVS(2772)*XX(228)-JVS(2856)&
              &*XX(229)-JVS(2964)*XX(230)-JVS(3019)*XX(231)-JVS(3136)*XX(232)-JVS(3181)*XX(233)-JVS(3343)*XX(234)-JVS(3429)&
              &*XX(235)
  XX(222) = XX(222)-JVS(2491)*XX(223)-JVS(2524)*XX(224)-JVS(2585)*XX(225)-JVS(2629)*XX(226)-JVS(2717)*XX(227)-JVS(2771)&
              &*XX(228)-JVS(2855)*XX(229)-JVS(2963)*XX(230)-JVS(3018)*XX(231)-JVS(3135)*XX(232)-JVS(3180)*XX(233)-JVS(3342)&
              &*XX(234)-JVS(3428)*XX(235)
  XX(221) = XX(221)-JVS(2408)*XX(222)-JVS(2490)*XX(223)-JVS(2523)*XX(224)-JVS(2584)*XX(225)-JVS(2628)*XX(226)-JVS(2716)&
              &*XX(227)-JVS(2770)*XX(228)-JVS(2854)*XX(229)-JVS(2962)*XX(230)-JVS(3017)*XX(231)-JVS(3134)*XX(232)-JVS(3179)&
              &*XX(233)-JVS(3341)*XX(234)-JVS(3427)*XX(235)
  XX(220) = XX(220)-JVS(2356)*XX(221)-JVS(2407)*XX(222)-JVS(2489)*XX(223)-JVS(2522)*XX(224)-JVS(2583)*XX(225)-JVS(2627)&
              &*XX(226)-JVS(2715)*XX(227)-JVS(2769)*XX(228)-JVS(2853)*XX(229)-JVS(2961)*XX(230)-JVS(3016)*XX(231)-JVS(3133)&
              &*XX(232)-JVS(3178)*XX(233)-JVS(3340)*XX(234)-JVS(3426)*XX(235)
  XX(219) = XX(219)-JVS(2286)*XX(220)-JVS(2355)*XX(221)-JVS(2406)*XX(222)-JVS(2488)*XX(223)-JVS(2521)*XX(224)-JVS(2582)&
              &*XX(225)-JVS(2626)*XX(226)-JVS(2714)*XX(227)-JVS(2768)*XX(228)-JVS(2852)*XX(229)-JVS(2960)*XX(230)-JVS(3015)&
              &*XX(231)-JVS(3132)*XX(232)-JVS(3177)*XX(233)-JVS(3339)*XX(234)-JVS(3425)*XX(235)
  XX(218) = XX(218)-JVS(2216)*XX(219)-JVS(2285)*XX(220)-JVS(2354)*XX(221)-JVS(2405)*XX(222)-JVS(2487)*XX(223)-JVS(2520)&
              &*XX(224)-JVS(2581)*XX(225)-JVS(2625)*XX(226)-JVS(2713)*XX(227)-JVS(2767)*XX(228)-JVS(2851)*XX(229)-JVS(2959)&
              &*XX(230)-JVS(3014)*XX(231)-JVS(3131)*XX(232)-JVS(3176)*XX(233)-JVS(3338)*XX(234)-JVS(3424)*XX(235)
  XX(217) = XX(217)-JVS(2185)*XX(218)-JVS(2215)*XX(219)-JVS(2284)*XX(220)-JVS(2353)*XX(221)-JVS(2404)*XX(222)-JVS(2486)&
              &*XX(223)-JVS(2519)*XX(224)-JVS(2580)*XX(225)-JVS(2624)*XX(226)-JVS(2712)*XX(227)-JVS(2766)*XX(228)-JVS(2850)&
              &*XX(229)-JVS(2958)*XX(230)-JVS(3013)*XX(231)-JVS(3130)*XX(232)-JVS(3175)*XX(233)-JVS(3337)*XX(234)-JVS(3423)&
              &*XX(235)
  XX(216) = XX(216)-JVS(2184)*XX(218)-JVS(2283)*XX(220)-JVS(2352)*XX(221)-JVS(2403)*XX(222)-JVS(2518)*XX(224)-JVS(2579)&
              &*XX(225)-JVS(2623)*XX(226)-JVS(2711)*XX(227)-JVS(2765)*XX(228)-JVS(2849)*XX(229)-JVS(2957)*XX(230)-JVS(3012)&
              &*XX(231)-JVS(3129)*XX(232)-JVS(3336)*XX(234)-JVS(3422)*XX(235)
  XX(215) = XX(215)-JVS(2099)*XX(216)-JVS(2183)*XX(218)-JVS(2214)*XX(219)-JVS(2282)*XX(220)-JVS(2351)*XX(221)-JVS(2402)&
              &*XX(222)-JVS(2485)*XX(223)-JVS(2517)*XX(224)-JVS(2578)*XX(225)-JVS(2710)*XX(227)-JVS(2764)*XX(228)-JVS(2848)&
              &*XX(229)-JVS(2956)*XX(230)-JVS(3011)*XX(231)-JVS(3128)*XX(232)-JVS(3174)*XX(233)-JVS(3335)*XX(234)-JVS(3421)&
              &*XX(235)
  XX(214) = XX(214)-JVS(2281)*XX(220)-JVS(2401)*XX(222)-JVS(2516)*XX(224)-JVS(2577)*XX(225)-JVS(2709)*XX(227)-JVS(2763)&
              &*XX(228)-JVS(2847)*XX(229)-JVS(2955)*XX(230)-JVS(3010)*XX(231)-JVS(3127)*XX(232)-JVS(3334)*XX(234)-JVS(3420)&
              &*XX(235)
  XX(213) = XX(213)-JVS(2034)*XX(214)-JVS(2098)*XX(216)-JVS(2182)*XX(218)-JVS(2280)*XX(220)-JVS(2350)*XX(221)-JVS(2400)&
              &*XX(222)-JVS(2484)*XX(223)-JVS(2515)*XX(224)-JVS(2576)*XX(225)-JVS(2708)*XX(227)-JVS(2846)*XX(229)-JVS(2954)&
              &*XX(230)-JVS(3009)*XX(231)-JVS(3126)*XX(232)-JVS(3173)*XX(233)-JVS(3333)*XX(234)-JVS(3419)*XX(235)
  XX(212) = XX(212)-JVS(2033)*XX(214)-JVS(2097)*XX(216)-JVS(2181)*XX(218)-JVS(2279)*XX(220)-JVS(2349)*XX(221)-JVS(2483)&
              &*XX(223)-JVS(2575)*XX(225)-JVS(2707)*XX(227)-JVS(2845)*XX(229)-JVS(2953)*XX(230)-JVS(3008)*XX(231)-JVS(3125)&
              &*XX(232)-JVS(3172)*XX(233)-JVS(3332)*XX(234)-JVS(3418)*XX(235)
  XX(211) = XX(211)-JVS(1908)*XX(212)-JVS(2032)*XX(214)-JVS(2096)*XX(216)-JVS(2180)*XX(218)-JVS(2213)*XX(219)-JVS(2278)&
              &*XX(220)-JVS(2348)*XX(221)-JVS(2399)*XX(222)-JVS(2482)*XX(223)-JVS(2514)*XX(224)-JVS(2574)*XX(225)-JVS(2622)&
              &*XX(226)-JVS(2706)*XX(227)-JVS(2762)*XX(228)-JVS(2844)*XX(229)-JVS(2952)*XX(230)-JVS(3007)*XX(231)-JVS(3124)&
              &*XX(232)-JVS(3331)*XX(234)-JVS(3417)*XX(235)
  XX(210) = XX(210)-JVS(2398)*XX(222)-JVS(2481)*XX(223)-JVS(2513)*XX(224)-JVS(2573)*XX(225)-JVS(2621)*XX(226)-JVS(2705)&
              &*XX(227)-JVS(2761)*XX(228)-JVS(2843)*XX(229)-JVS(2951)*XX(230)-JVS(3006)*XX(231)-JVS(3123)*XX(232)-JVS(3171)&
              &*XX(233)-JVS(3330)*XX(234)-JVS(3416)*XX(235)
  XX(209) = XX(209)-JVS(1907)*XX(212)-JVS(1951)*XX(213)-JVS(2031)*XX(214)-JVS(2179)*XX(218)-JVS(2277)*XX(220)-JVS(2347)&
              &*XX(221)-JVS(2480)*XX(223)-JVS(2572)*XX(225)-JVS(2704)*XX(227)-JVS(2842)*XX(229)-JVS(2950)*XX(230)-JVS(3122)&
              &*XX(232)-JVS(3329)*XX(234)-JVS(3415)*XX(235)
  XX(208) = XX(208)-JVS(2030)*XX(214)-JVS(2178)*XX(218)-JVS(2276)*XX(220)-JVS(2346)*XX(221)-JVS(2571)*XX(225)-JVS(2703)&
              &*XX(227)-JVS(2841)*XX(229)-JVS(2949)*XX(230)-JVS(3121)*XX(232)-JVS(3328)*XX(234)-JVS(3414)*XX(235)
  XX(207) = XX(207)-JVS(1793)*XX(208)-JVS(1906)*XX(212)-JVS(1950)*XX(213)-JVS(2029)*XX(214)-JVS(2095)*XX(216)-JVS(2177)&
              &*XX(218)-JVS(2275)*XX(220)-JVS(2345)*XX(221)-JVS(2397)*XX(222)-JVS(2479)*XX(223)-JVS(2512)*XX(224)-JVS(2570)&
              &*XX(225)-JVS(2702)*XX(227)-JVS(2840)*XX(229)-JVS(2948)*XX(230)-JVS(3120)*XX(232)-JVS(3170)*XX(233)-JVS(3327)&
              &*XX(234)-JVS(3413)*XX(235)
  XX(206) = XX(206)-JVS(1744)*XX(207)-JVS(1792)*XX(208)-JVS(1905)*XX(212)-JVS(1949)*XX(213)-JVS(2028)*XX(214)-JVS(2094)&
              &*XX(216)-JVS(2176)*XX(218)-JVS(2274)*XX(220)-JVS(2344)*XX(221)-JVS(2396)*XX(222)-JVS(2478)*XX(223)-JVS(2511)&
              &*XX(224)-JVS(2569)*XX(225)-JVS(2701)*XX(227)-JVS(2839)*XX(229)-JVS(2947)*XX(230)-JVS(3119)*XX(232)-JVS(3169)&
              &*XX(233)-JVS(3326)*XX(234)-JVS(3412)*XX(235)
  XX(205) = XX(205)-JVS(1722)*XX(206)-JVS(1743)*XX(207)-JVS(1791)*XX(208)-JVS(1904)*XX(212)-JVS(1948)*XX(213)-JVS(2027)&
              &*XX(214)-JVS(2063)*XX(215)-JVS(2093)*XX(216)-JVS(2121)*XX(217)-JVS(2175)*XX(218)-JVS(2212)*XX(219)-JVS(2273)&
              &*XX(220)-JVS(2343)*XX(221)-JVS(2477)*XX(223)-JVS(2568)*XX(225)-JVS(2700)*XX(227)-JVS(2760)*XX(228)-JVS(2838)&
              &*XX(229)-JVS(2946)*XX(230)-JVS(3005)*XX(231)-JVS(3118)*XX(232)-JVS(3168)*XX(233)-JVS(3325)*XX(234)-JVS(3411)&
              &*XX(235)
  XX(204) = XX(204)-JVS(2026)*XX(214)-JVS(2092)*XX(216)-JVS(2174)*XX(218)-JVS(2342)*XX(221)-JVS(2476)*XX(223)-JVS(2567)&
              &*XX(225)-JVS(2699)*XX(227)-JVS(2945)*XX(230)-JVS(3117)*XX(232)-JVS(3167)*XX(233)-JVS(3324)*XX(234)-JVS(3410)&
              &*XX(235)
  XX(203) = XX(203)-JVS(1721)*XX(206)-JVS(1742)*XX(207)-JVS(1790)*XX(208)-JVS(1903)*XX(212)-JVS(1947)*XX(213)-JVS(2025)&
              &*XX(214)-JVS(2062)*XX(215)-JVS(2091)*XX(216)-JVS(2120)*XX(217)-JVS(2173)*XX(218)-JVS(2211)*XX(219)-JVS(2272)&
              &*XX(220)-JVS(2341)*XX(221)-JVS(2475)*XX(223)-JVS(2566)*XX(225)-JVS(2698)*XX(227)-JVS(2759)*XX(228)-JVS(2837)&
              &*XX(229)-JVS(2944)*XX(230)-JVS(3004)*XX(231)-JVS(3116)*XX(232)-JVS(3323)*XX(234)-JVS(3409)*XX(235)
  XX(202) = XX(202)-JVS(1720)*XX(206)-JVS(1789)*XX(208)-JVS(1902)*XX(212)-JVS(1946)*XX(213)-JVS(2024)*XX(214)-JVS(2172)&
              &*XX(218)-JVS(2210)*XX(219)-JVS(2271)*XX(220)-JVS(2340)*XX(221)-JVS(2474)*XX(223)-JVS(2565)*XX(225)-JVS(2697)&
              &*XX(227)-JVS(2758)*XX(228)-JVS(2836)*XX(229)-JVS(2943)*XX(230)-JVS(3003)*XX(231)-JVS(3115)*XX(232)-JVS(3322)&
              &*XX(234)-JVS(3408)*XX(235)
  XX(201) = XX(201)-JVS(1788)*XX(208)-JVS(2023)*XX(214)-JVS(2171)*XX(218)-JVS(2270)*XX(220)-JVS(2339)*XX(221)-JVS(2395)&
              &*XX(222)-JVS(2473)*XX(223)-JVS(2510)*XX(224)-JVS(2564)*XX(225)-JVS(2696)*XX(227)-JVS(2835)*XX(229)-JVS(2942)&
              &*XX(230)-JVS(3114)*XX(232)-JVS(3321)*XX(234)-JVS(3407)*XX(235)
  XX(200) = XX(200)-JVS(2170)*XX(218)-JVS(2269)*XX(220)-JVS(2834)*XX(229)-JVS(2941)*XX(230)-JVS(3113)*XX(232)-JVS(3320)&
              &*XX(234)-JVS(3406)*XX(235)
  XX(199) = XX(199)-JVS(1839)*XX(210)-JVS(2394)*XX(222)-JVS(2509)*XX(224)-JVS(2563)*XX(225)-JVS(2620)*XX(226)-JVS(2695)&
              &*XX(227)-JVS(2757)*XX(228)-JVS(2833)*XX(229)-JVS(2940)*XX(230)-JVS(3002)*XX(231)-JVS(3166)*XX(233)-JVS(3319)&
              &*XX(234)-JVS(3405)*XX(235)
  XX(198) = XX(198)-JVS(1605)*XX(200)-JVS(1677)*XX(204)-JVS(1699)*XX(205)-JVS(1741)*XX(207)-JVS(1787)*XX(208)-JVS(1901)&
              &*XX(212)-JVS(1945)*XX(213)-JVS(2022)*XX(214)-JVS(2090)*XX(216)-JVS(2169)*XX(218)-JVS(2268)*XX(220)-JVS(2338)&
              &*XX(221)-JVS(2472)*XX(223)-JVS(2562)*XX(225)-JVS(2694)*XX(227)-JVS(2832)*XX(229)-JVS(2939)*XX(230)-JVS(3001)&
              &*XX(231)-JVS(3112)*XX(232)-JVS(3318)*XX(234)-JVS(3404)*XX(235)
  XX(197) = XX(197)-JVS(2021)*XX(214)-JVS(2209)*XX(219)-JVS(2267)*XX(220)-JVS(2471)*XX(223)-JVS(2561)*XX(225)-JVS(2693)&
              &*XX(227)-JVS(2756)*XX(228)-JVS(2831)*XX(229)-JVS(2938)*XX(230)-JVS(3111)*XX(232)-JVS(3317)*XX(234)-JVS(3403)&
              &*XX(235)
  XX(196) = XX(196)-JVS(2393)*XX(222)-JVS(2508)*XX(224)-JVS(2560)*XX(225)-JVS(2619)*XX(226)-JVS(2692)*XX(227)-JVS(2755)&
              &*XX(228)-JVS(3165)*XX(233)-JVS(3316)*XX(234)-JVS(3402)*XX(235)
  XX(195) = XX(195)-JVS(1604)*XX(200)-JVS(1900)*XX(212)-JVS(1944)*XX(213)-JVS(2020)*XX(214)-JVS(2168)*XX(218)-JVS(2266)&
              &*XX(220)-JVS(2337)*XX(221)-JVS(2470)*XX(223)-JVS(2559)*XX(225)-JVS(2691)*XX(227)-JVS(2830)*XX(229)-JVS(2937)&
              &*XX(230)-JVS(3110)*XX(232)-JVS(3315)*XX(234)-JVS(3401)*XX(235)
  XX(194) = XX(194)-JVS(2336)*XX(221)-JVS(2558)*XX(225)-JVS(2690)*XX(227)-JVS(3314)*XX(234)-JVS(3400)*XX(235)
  XX(193) = XX(193)-JVS(1478)*XX(194)-JVS(1786)*XX(208)-JVS(1899)*XX(212)-JVS(1943)*XX(213)-JVS(2019)*XX(214)-JVS(2167)&
              &*XX(218)-JVS(2265)*XX(220)-JVS(2335)*XX(221)-JVS(2469)*XX(223)-JVS(2829)*XX(229)-JVS(2936)*XX(230)-JVS(3000)&
              &*XX(231)-JVS(3109)*XX(232)-JVS(3313)*XX(234)-JVS(3399)*XX(235)
  XX(192) = XX(192)-JVS(2018)*XX(214)-JVS(2264)*XX(220)-JVS(2557)*XX(225)-JVS(2689)*XX(227)-JVS(2828)*XX(229)-JVS(2935)&
              &*XX(230)-JVS(3108)*XX(232)-JVS(3312)*XX(234)-JVS(3398)*XX(235)
  XX(191) = XX(191)-JVS(1433)*XX(192)-JVS(1477)*XX(194)-JVS(1603)*XX(200)-JVS(1649)*XX(202)-JVS(1719)*XX(206)-JVS(1740)&
              &*XX(207)-JVS(1785)*XX(208)-JVS(1898)*XX(212)-JVS(2017)*XX(214)-JVS(2089)*XX(216)-JVS(2166)*XX(218)-JVS(2263)&
              &*XX(220)-JVS(2334)*XX(221)-JVS(2468)*XX(223)-JVS(2556)*XX(225)-JVS(2688)*XX(227)-JVS(2827)*XX(229)-JVS(2934)&
              &*XX(230)-JVS(2999)*XX(231)-JVS(3107)*XX(232)-JVS(3311)*XX(234)-JVS(3397)*XX(235)
  XX(190) = XX(190)-JVS(2826)*XX(229)-JVS(2933)*XX(230)-JVS(3310)*XX(234)-JVS(3396)*XX(235)
  XX(189) = XX(189)-JVS(1382)*XX(190)-JVS(1432)*XX(192)-JVS(1476)*XX(194)-JVS(1602)*XX(200)-JVS(1718)*XX(206)-JVS(1784)&
              &*XX(208)-JVS(1897)*XX(212)-JVS(1942)*XX(213)-JVS(2016)*XX(214)-JVS(2165)*XX(218)-JVS(2262)*XX(220)-JVS(2333)&
              &*XX(221)-JVS(2467)*XX(223)-JVS(2825)*XX(229)-JVS(2932)*XX(230)-JVS(2998)*XX(231)-JVS(3106)*XX(232)-JVS(3309)&
              &*XX(234)
  XX(188) = XX(188)-JVS(1381)*XX(190)-JVS(1632)*XX(201)-JVS(1717)*XX(206)-JVS(1783)*XX(208)-JVS(1896)*XX(212)-JVS(1941)&
              &*XX(213)-JVS(2015)*XX(214)-JVS(2164)*XX(218)-JVS(2332)*XX(221)-JVS(2466)*XX(223)-JVS(2555)*XX(225)-JVS(2687)&
              &*XX(227)-JVS(2824)*XX(229)-JVS(2931)*XX(230)-JVS(2997)*XX(231)-JVS(3105)*XX(232)-JVS(3308)*XX(234)-JVS(3395)&
              &*XX(235)
  XX(187) = XX(187)-JVS(1380)*XX(190)-JVS(1431)*XX(192)-JVS(1475)*XX(194)-JVS(1601)*XX(200)-JVS(1716)*XX(206)-JVS(1739)&
              &*XX(207)-JVS(1782)*XX(208)-JVS(1895)*XX(212)-JVS(2014)*XX(214)-JVS(2088)*XX(216)-JVS(2163)*XX(218)-JVS(2261)&
              &*XX(220)-JVS(2331)*XX(221)-JVS(2465)*XX(223)-JVS(2554)*XX(225)-JVS(2686)*XX(227)-JVS(2823)*XX(229)-JVS(2930)&
              &*XX(230)-JVS(3104)*XX(232)-JVS(3307)*XX(234)-JVS(3394)*XX(235)
  XX(186) = XX(186)-JVS(1379)*XX(190)-JVS(1564)*XX(199)-JVS(1838)*XX(210)-JVS(2392)*XX(222)-JVS(2507)*XX(224)-JVS(2553)&
              &*XX(225)-JVS(2685)*XX(227)-JVS(2754)*XX(228)-JVS(2996)*XX(231)-JVS(3306)*XX(234)-JVS(3393)*XX(235)
  XX(185) = XX(185)-JVS(1474)*XX(194)-JVS(1600)*XX(200)-JVS(1738)*XX(207)-JVS(1781)*XX(208)-JVS(1894)*XX(212)-JVS(1940)&
              &*XX(213)-JVS(2013)*XX(214)-JVS(2087)*XX(216)-JVS(2162)*XX(218)-JVS(2330)*XX(221)-JVS(2464)*XX(223)-JVS(2929)&
              &*XX(230)-JVS(3103)*XX(232)-JVS(3305)*XX(234)-JVS(3392)*XX(235)
  XX(184) = XX(184)-JVS(1378)*XX(190)-JVS(1523)*XX(196)-JVS(1837)*XX(210)-JVS(2391)*XX(222)-JVS(2463)*XX(223)-JVS(2684)&
              &*XX(227)-JVS(2753)*XX(228)-JVS(2822)*XX(229)-JVS(2928)*XX(230)-JVS(2995)*XX(231)-JVS(3102)*XX(232)-JVS(3164)&
              &*XX(233)-JVS(3304)*XX(234)-JVS(3391)*XX(235)
  XX(183) = XX(183)-JVS(1377)*XX(190)-JVS(1780)*XX(208)-JVS(1893)*XX(212)-JVS(1939)*XX(213)-JVS(2012)*XX(214)-JVS(2161)&
              &*XX(218)-JVS(2329)*XX(221)-JVS(2462)*XX(223)-JVS(2821)*XX(229)-JVS(2927)*XX(230)-JVS(2994)*XX(231)-JVS(3101)&
              &*XX(232)-JVS(3303)*XX(234)
  XX(182) = XX(182)-JVS(1268)*XX(183)-JVS(1376)*XX(190)-JVS(1779)*XX(208)-JVS(1892)*XX(212)-JVS(1938)*XX(213)-JVS(2011)&
              &*XX(214)-JVS(2160)*XX(218)-JVS(2328)*XX(221)-JVS(2461)*XX(223)-JVS(2820)*XX(229)-JVS(2926)*XX(230)-JVS(2993)&
              &*XX(231)-JVS(3100)*XX(232)-JVS(3302)*XX(234)
  XX(181) = XX(181)-JVS(1375)*XX(190)-JVS(1473)*XX(194)-JVS(1599)*XX(200)-JVS(1778)*XX(208)-JVS(2010)*XX(214)-JVS(2260)&
              &*XX(220)-JVS(2460)*XX(223)-JVS(2552)*XX(225)-JVS(2683)*XX(227)-JVS(2819)*XX(229)-JVS(2925)*XX(230)-JVS(3099)&
              &*XX(232)-JVS(3301)*XX(234)-JVS(3390)*XX(235)
  XX(180) = XX(180)-JVS(1374)*XX(190)-JVS(1715)*XX(206)-JVS(1777)*XX(208)-JVS(1857)*XX(211)-JVS(1891)*XX(212)-JVS(1937)&
              &*XX(213)-JVS(2009)*XX(214)-JVS(2061)*XX(215)-JVS(2159)*XX(218)-JVS(2327)*XX(221)-JVS(2459)*XX(223)-JVS(2818)&
              &*XX(229)-JVS(2924)*XX(230)-JVS(2992)*XX(231)-JVS(3098)*XX(232)-JVS(3300)*XX(234)
  XX(179) = XX(179)-JVS(1676)*XX(204)-JVS(2008)*XX(214)-JVS(2086)*XX(216)-JVS(2158)*XX(218)-JVS(2326)*XX(221)-JVS(2458)&
              &*XX(223)-JVS(2923)*XX(230)-JVS(2991)*XX(231)-JVS(3097)*XX(232)-JVS(3299)*XX(234)
  XX(178) = XX(178)-JVS(1283)*XX(184)-JVS(1373)*XX(190)-JVS(1836)*XX(210)-JVS(2390)*XX(222)-JVS(2457)*XX(223)-JVS(2682)&
              &*XX(227)-JVS(2817)*XX(229)-JVS(2922)*XX(230)-JVS(2990)*XX(231)-JVS(3096)*XX(232)-JVS(3298)*XX(234)-JVS(3389)&
              &*XX(235)
  XX(177) = XX(177)-JVS(1472)*XX(194)-JVS(1598)*XX(200)-JVS(1776)*XX(208)-JVS(2007)*XX(214)-JVS(2157)*XX(218)-JVS(2325)&
              &*XX(221)-JVS(2456)*XX(223)-JVS(2921)*XX(230)-JVS(3095)*XX(232)-JVS(3297)*XX(234)-JVS(3388)*XX(235)
  XX(176) = XX(176)-JVS(2551)*XX(225)-JVS(2681)*XX(227)-JVS(2752)*XX(228)-JVS(3094)*XX(232)-JVS(3296)*XX(234)-JVS(3387)&
              &*XX(235)
  XX(175) = XX(175)-JVS(1372)*XX(190)-JVS(1471)*XX(194)-JVS(1775)*XX(208)-JVS(1890)*XX(212)-JVS(1936)*XX(213)-JVS(2006)&
              &*XX(214)-JVS(2156)*XX(218)-JVS(2324)*XX(221)-JVS(2455)*XX(223)-JVS(2920)*XX(230)-JVS(3093)*XX(232)-JVS(3295)&
              &*XX(234)
  XX(174) = XX(174)-JVS(1165)*XX(176)-JVS(1507)*XX(195)-JVS(1540)*XX(197)-JVS(1663)*XX(203)-JVS(1698)*XX(205)-JVS(1774)&
              &*XX(208)-JVS(1814)*XX(209)-JVS(1856)*XX(211)-JVS(2005)*XX(214)-JVS(2060)*XX(215)-JVS(2119)*XX(217)-JVS(2155)&
              &*XX(218)-JVS(2208)*XX(219)-JVS(2259)*XX(220)-JVS(2323)*XX(221)-JVS(2454)*XX(223)-JVS(2550)*XX(225)-JVS(2680)&
              &*XX(227)-JVS(2816)*XX(229)-JVS(2919)*XX(230)-JVS(2989)*XX(231)-JVS(3092)*XX(232)-JVS(3294)*XX(234)-JVS(3386)&
              &*XX(235)
  XX(173) = XX(173)-JVS(1470)*XX(194)-JVS(1714)*XX(206)-JVS(1737)*XX(207)-JVS(1889)*XX(212)-JVS(2004)*XX(214)-JVS(2085)&
              &*XX(216)-JVS(2154)*XX(218)-JVS(2322)*XX(221)-JVS(2453)*XX(223)-JVS(2918)*XX(230)-JVS(3091)*XX(232)-JVS(3293)&
              &*XX(234)
  XX(172) = XX(172)-JVS(1164)*XX(176)-JVS(1773)*XX(208)-JVS(1813)*XX(209)-JVS(2003)*XX(214)-JVS(2059)*XX(215)-JVS(2207)&
              &*XX(219)-JVS(2258)*XX(220)-JVS(2452)*XX(223)-JVS(2815)*XX(229)-JVS(2917)*XX(230)-JVS(3090)*XX(232)-JVS(3292)&
              &*XX(234)-JVS(3385)*XX(235)
  XX(171) = XX(171)-JVS(1469)*XX(194)-JVS(1631)*XX(201)-JVS(1888)*XX(212)-JVS(2002)*XX(214)-JVS(2153)*XX(218)-JVS(2321)&
              &*XX(221)-JVS(2451)*XX(223)-JVS(2916)*XX(230)-JVS(3089)*XX(232)-JVS(3291)*XX(234)
  XX(170) = XX(170)-JVS(2549)*XX(225)-JVS(2679)*XX(227)-JVS(3088)*XX(232)-JVS(3290)*XX(234)-JVS(3384)*XX(235)
  XX(169) = XX(169)-JVS(1090)*XX(170)-JVS(1130)*XX(173)-JVS(1243)*XX(181)-JVS(1323)*XX(187)-JVS(1371)*XX(190)-JVS(1430)&
              &*XX(192)-JVS(1597)*XX(200)-JVS(1772)*XX(208)-JVS(1887)*XX(212)-JVS(2001)*XX(214)-JVS(2152)*XX(218)-JVS(2257)&
              &*XX(220)-JVS(2320)*XX(221)-JVS(2450)*XX(223)-JVS(2814)*XX(229)-JVS(2915)*XX(230)-JVS(3087)*XX(232)-JVS(3289)&
              &*XX(234)
  XX(168) = XX(168)-JVS(1468)*XX(194)-JVS(1771)*XX(208)-JVS(1886)*XX(212)-JVS(2000)*XX(214)-JVS(2084)*XX(216)-JVS(2151)&
              &*XX(218)-JVS(2319)*XX(221)-JVS(2449)*XX(223)-JVS(2914)*XX(230)-JVS(3086)*XX(232)-JVS(3288)*XX(234)
  XX(167) = XX(167)-JVS(1220)*XX(179)-JVS(1596)*XX(200)-JVS(1770)*XX(208)-JVS(1999)*XX(214)-JVS(2083)*XX(216)-JVS(2150)&
              &*XX(218)-JVS(2256)*XX(220)-JVS(2318)*XX(221)-JVS(2448)*XX(223)-JVS(2813)*XX(229)-JVS(2913)*XX(230)-JVS(2988)&
              &*XX(231)-JVS(3085)*XX(232)-JVS(3287)*XX(234)
  XX(166) = XX(166)-JVS(1146)*XX(175)-JVS(1452)*XX(193)-JVS(1467)*XX(194)-JVS(1595)*XX(200)-JVS(1736)*XX(207)-JVS(1885)&
              &*XX(212)-JVS(1998)*XX(214)-JVS(2149)*XX(218)-JVS(2255)*XX(220)-JVS(2317)*XX(221)-JVS(2447)*XX(223)-JVS(2912)&
              &*XX(230)-JVS(3084)*XX(232)-JVS(3286)*XX(234)
  XX(165) = XX(165)-JVS(1594)*XX(200)-JVS(1997)*XX(214)-JVS(2254)*XX(220)-JVS(2316)*XX(221)-JVS(2911)*XX(230)-JVS(3285)&
              &*XX(234)
  XX(164) = XX(164)-JVS(1466)*XX(194)-JVS(1884)*XX(212)-JVS(1996)*XX(214)-JVS(2148)*XX(218)-JVS(2315)*XX(221)-JVS(2446)&
              &*XX(223)-JVS(2910)*XX(230)-JVS(3083)*XX(232)-JVS(3284)*XX(234)
  XX(163) = XX(163)-JVS(1163)*XX(176)-JVS(1593)*XX(200)-JVS(2147)*XX(218)-JVS(2206)*XX(219)-JVS(2253)*XX(220)-JVS(2314)&
              &*XX(221)-JVS(2445)*XX(223)-JVS(2812)*XX(229)-JVS(2909)*XX(230)-JVS(3283)*XX(234)-JVS(3383)*XX(235)
  XX(162) = XX(162)-JVS(1370)*XX(190)-JVS(1769)*XX(208)-JVS(1883)*XX(212)-JVS(2811)*XX(229)-JVS(2908)*XX(230)-JVS(2987)&
              &*XX(231)-JVS(3282)*XX(234)
  XX(161) = XX(161)-JVS(1038)*XX(165)-JVS(1465)*XX(194)-JVS(1882)*XX(212)-JVS(1995)*XX(214)-JVS(2082)*XX(216)-JVS(2146)&
              &*XX(218)-JVS(2313)*XX(221)-JVS(2444)*XX(223)-JVS(2907)*XX(230)-JVS(3082)*XX(232)-JVS(3281)*XX(234)
  XX(160) = XX(160)-JVS(1162)*XX(176)-JVS(1592)*XX(200)-JVS(2205)*XX(219)-JVS(2252)*XX(220)-JVS(2443)*XX(223)-JVS(2810)&
              &*XX(229)-JVS(2906)*XX(230)-JVS(3280)*XX(234)-JVS(3382)*XX(235)
  XX(159) = XX(159)-JVS(1089)*XX(170)-JVS(1369)*XX(190)-JVS(1429)*XX(192)-JVS(1591)*XX(200)-JVS(1994)*XX(214)-JVS(2145)&
              &*XX(218)-JVS(2809)*XX(229)-JVS(2905)*XX(230)-JVS(3279)*XX(234)
  XX(158) = XX(158)-JVS(1368)*XX(190)-JVS(1993)*XX(214)-JVS(2251)*XX(220)-JVS(2808)*XX(229)-JVS(3081)*XX(232)-JVS(3278)&
              &*XX(234)
  XX(157) = XX(157)-JVS(960)*XX(158)-JVS(1088)*XX(170)-JVS(1428)*XX(192)-JVS(1590)*XX(200)-JVS(1768)*XX(208)-JVS(1992)&
              &*XX(214)-JVS(2144)*XX(218)-JVS(2250)*XX(220)-JVS(2442)*XX(223)-JVS(2904)*XX(230)-JVS(3080)*XX(232)-JVS(3277)&
              &*XX(234)
  XX(156) = XX(156)-JVS(1161)*XX(176)-JVS(1464)*XX(194)-JVS(2081)*XX(216)-JVS(2204)*XX(219)-JVS(2249)*XX(220)-JVS(2441)&
              &*XX(223)-JVS(2807)*XX(229)-JVS(2903)*XX(230)-JVS(3276)*XX(234)-JVS(3381)*XX(235)
  XX(155) = XX(155)-JVS(1160)*XX(176)-JVS(1427)*XX(192)-JVS(1767)*XX(208)-JVS(2203)*XX(219)-JVS(2248)*XX(220)-JVS(2440)&
              &*XX(223)-JVS(2806)*XX(229)-JVS(2902)*XX(230)-JVS(3275)*XX(234)-JVS(3380)*XX(235)
  XX(154) = XX(154)-JVS(959)*XX(158)-JVS(1037)*XX(165)-JVS(1697)*XX(205)-JVS(1735)*XX(207)-JVS(1881)*XX(212)-JVS(1935)&
              &*XX(213)-JVS(1991)*XX(214)-JVS(2312)*XX(221)-JVS(2439)*XX(223)-JVS(2805)*XX(229)-JVS(2901)*XX(230)-JVS(3079)&
              &*XX(232)-JVS(3274)*XX(234)
  XX(153) = XX(153)-JVS(1159)*XX(176)-JVS(2118)*XX(217)-JVS(2202)*XX(219)-JVS(2247)*XX(220)-JVS(2438)*XX(223)-JVS(2804)&
              &*XX(229)-JVS(2900)*XX(230)-JVS(3273)*XX(234)-JVS(3379)*XX(235)
  XX(152) = XX(152)-JVS(958)*XX(158)-JVS(1036)*XX(165)-JVS(1696)*XX(205)-JVS(1734)*XX(207)-JVS(1880)*XX(212)-JVS(1934)&
              &*XX(213)-JVS(1990)*XX(214)-JVS(2311)*XX(221)-JVS(2437)*XX(223)-JVS(2899)*XX(230)-JVS(3078)*XX(232)-JVS(3272)&
              &*XX(234)
  XX(151) = XX(151)-JVS(1989)*XX(214)-JVS(2310)*XX(221)-JVS(2548)*XX(225)-JVS(2618)*XX(226)-JVS(2678)*XX(227)-JVS(2751)&
              &*XX(228)-JVS(2986)*XX(231)-JVS(3077)*XX(232)-JVS(3271)*XX(234)-JVS(3378)*XX(235)
  XX(150) = XX(150)-JVS(942)*XX(157)-JVS(974)*XX(159)-JVS(1035)*XX(165)-JVS(1087)*XX(170)-JVS(1242)*XX(181)-JVS(1322)&
              &*XX(187)-JVS(1367)*XX(190)-JVS(1648)*XX(202)-JVS(1988)*XX(214)-JVS(2246)*XX(220)-JVS(2898)*XX(230)-JVS(2985)&
              &*XX(231)-JVS(3076)*XX(232)-JVS(3270)*XX(234)
  XX(149) = XX(149)-JVS(1522)*XX(196)-JVS(2617)*XX(226)-JVS(2677)*XX(227)-JVS(2750)*XX(228)-JVS(3163)*XX(233)-JVS(3269)&
              &*XX(234)
  XX(148) = XX(148)-JVS(1366)*XX(190)-JVS(1766)*XX(208)-JVS(1933)*XX(213)-JVS(2803)*XX(229)-JVS(2897)*XX(230)-JVS(3268)&
              &*XX(234)
  XX(147) = XX(147)-JVS(1207)*XX(178)-JVS(1282)*XX(184)-JVS(1365)*XX(190)-JVS(2389)*XX(222)-JVS(2676)*XX(227)-JVS(2802)&
              &*XX(229)-JVS(2896)*XX(230)-JVS(3267)*XX(234)-JVS(3377)*XX(235)
  XX(146) = XX(146)-JVS(1879)*XX(212)-JVS(3075)*XX(232)-JVS(3266)*XX(234)
  XX(145) = XX(145)-JVS(1086)*XX(170)-JVS(1463)*XX(194)-JVS(1589)*XX(200)-JVS(1765)*XX(208)-JVS(1987)*XX(214)-JVS(2436)&
              &*XX(223)-JVS(2801)*XX(229)-JVS(2895)*XX(230)-JVS(3074)*XX(232)-JVS(3265)*XX(234)
  XX(144) = XX(144)-JVS(1308)*XX(186)-JVS(1364)*XX(190)-JVS(1835)*XX(210)-JVS(2388)*XX(222)-JVS(2547)*XX(225)-JVS(2675)&
              &*XX(227)-JVS(2800)*XX(229)-JVS(2894)*XX(230)-JVS(3264)*XX(234)-JVS(3376)*XX(235)
  XX(143) = XX(143)-JVS(2749)*XX(228)-JVS(2984)*XX(231)-JVS(3073)*XX(232)-JVS(3263)*XX(234)-JVS(3375)*XX(235)
  XX(142) = XX(142)-JVS(1085)*XX(170)-JVS(1158)*XX(176)-JVS(1233)*XX(180)-JVS(1255)*XX(182)-JVS(1267)*XX(183)-JVS(1295)&
              &*XX(185)-JVS(1675)*XX(204)-JVS(1855)*XX(211)-JVS(1986)*XX(214)-JVS(2058)*XX(215)-JVS(2245)*XX(220)-JVS(2799)&
              &*XX(229)-JVS(2983)*XX(231)-JVS(3072)*XX(232)-JVS(3262)*XX(234)
  XX(141) = XX(141)-JVS(1764)*XX(208)-JVS(1985)*XX(214)-JVS(2143)*XX(218)-JVS(2244)*XX(220)-JVS(2309)*XX(221)-JVS(2798)&
              &*XX(229)-JVS(2893)*XX(230)-JVS(3071)*XX(232)-JVS(3261)*XX(234)
  XX(140) = XX(140)-JVS(957)*XX(158)-JVS(1363)*XX(190)-JVS(1426)*XX(192)-JVS(1588)*XX(200)-JVS(1713)*XX(206)-JVS(1763)&
              &*XX(208)-JVS(1878)*XX(212)-JVS(2435)*XX(223)-JVS(2892)*XX(230)-JVS(3070)*XX(232)-JVS(3260)*XX(234)
  XX(139) = XX(139)-JVS(1362)*XX(190)-JVS(1712)*XX(206)-JVS(1877)*XX(212)-JVS(2434)*XX(223)-JVS(2891)*XX(230)-JVS(3069)&
              &*XX(232)-JVS(3259)*XX(234)
  XX(138) = XX(138)-JVS(859)*XX(147)-JVS(1206)*XX(178)-JVS(1281)*XX(184)-JVS(1361)*XX(190)-JVS(2387)*XX(222)-JVS(2674)&
              &*XX(227)-JVS(2797)*XX(229)-JVS(2890)*XX(230)
  XX(137) = XX(137)-JVS(1360)*XX(190)-JVS(1674)*XX(204)-JVS(2386)*XX(222)-JVS(2506)*XX(224)-JVS(2546)*XX(225)-JVS(2673)&
              &*XX(227)-JVS(2796)*XX(229)-JVS(3258)*XX(234)-JVS(3374)*XX(235)
  XX(136) = XX(136)-JVS(1451)*XX(193)-JVS(1762)*XX(208)-JVS(1984)*XX(214)-JVS(2142)*XX(218)-JVS(2243)*XX(220)-JVS(2795)&
              &*XX(229)-JVS(2889)*XX(230)-JVS(2982)*XX(231)-JVS(3257)*XX(234)
  XX(135) = XX(135)-JVS(1157)*XX(176)-JVS(1254)*XX(182)-JVS(1266)*XX(183)-JVS(1294)*XX(185)-JVS(1332)*XX(188)-JVS(1876)&
              &*XX(212)-JVS(1932)*XX(213)-JVS(2242)*XX(220)-JVS(2794)*XX(229)-JVS(2981)*XX(231)-JVS(3068)*XX(232)-JVS(3256)&
              &*XX(234)
  XX(134) = XX(134)-JVS(1156)*XX(176)-JVS(1253)*XX(182)-JVS(1265)*XX(183)-JVS(1293)*XX(185)-JVS(1331)*XX(188)-JVS(1875)&
              &*XX(212)-JVS(1931)*XX(213)-JVS(2241)*XX(220)-JVS(2793)*XX(229)-JVS(2980)*XX(231)-JVS(3067)*XX(232)-JVS(3255)&
              &*XX(234)
  XX(133) = XX(133)-JVS(1695)*XX(205)-JVS(1733)*XX(207)-JVS(1874)*XX(212)-JVS(1930)*XX(213)-JVS(2888)*XX(230)-JVS(3066)&
              &*XX(232)-JVS(3254)*XX(234)
  XX(132) = XX(132)-JVS(1359)*XX(190)-JVS(1521)*XX(196)-JVS(2545)*XX(225)-JVS(2672)*XX(227)-JVS(2792)*XX(229)-JVS(2887)&
              &*XX(230)-JVS(3253)*XX(234)-JVS(3373)*XX(235)
  XX(131) = XX(131)-JVS(1983)*XX(214)-JVS(2240)*XX(220)-JVS(2886)*XX(230)-JVS(3065)*XX(232)-JVS(3252)*XX(234)
  XX(130) = XX(130)-JVS(2080)*XX(216)-JVS(2544)*XX(225)-JVS(2671)*XX(227)-JVS(3064)*XX(232)-JVS(3251)*XX(234)
  XX(129) = XX(129)-JVS(941)*XX(157)-JVS(1343)*XX(189)-JVS(1647)*XX(202)-JVS(1662)*XX(203)-JVS(1982)*XX(214)-JVS(2057)&
              &*XX(215)-JVS(2117)*XX(217)-JVS(3063)*XX(232)-JVS(3250)*XX(234)-JVS(3372)*XX(235)
  XX(128) = XX(128)-JVS(940)*XX(157)-JVS(1342)*XX(189)-JVS(1646)*XX(202)-JVS(1661)*XX(203)-JVS(1981)*XX(214)-JVS(2056)&
              &*XX(215)-JVS(2116)*XX(217)-JVS(3062)*XX(232)-JVS(3249)*XX(234)-JVS(3371)*XX(235)
  XX(127) = XX(127)-JVS(1761)*XX(208)-JVS(1812)*XX(209)-JVS(1980)*XX(214)-JVS(2239)*XX(220)-JVS(3061)*XX(232)-JVS(3248)&
              &*XX(234)
  XX(126) = XX(126)-JVS(1145)*XX(175)-JVS(1450)*XX(193)-JVS(1979)*XX(214)-JVS(2141)*XX(218)-JVS(3247)*XX(234)
  XX(125) = XX(125)-JVS(1307)*XX(186)-JVS(1358)*XX(190)-JVS(1563)*XX(199)-JVS(2385)*XX(222)-JVS(2670)*XX(227)-JVS(2979)&
              &*XX(231)-JVS(3246)*XX(234)
  XX(124) = XX(124)-JVS(1978)*XX(214)-JVS(2308)*XX(221)-JVS(2543)*XX(225)-JVS(2669)*XX(227)-JVS(3060)*XX(232)-JVS(3245)&
              &*XX(234)-JVS(3370)*XX(235)
  XX(123) = XX(123)-JVS(1078)*XX(169)-JVS(1129)*XX(173)-JVS(1321)*XX(187)-JVS(1873)*XX(212)-JVS(2885)*XX(230)-JVS(3059)&
              &*XX(232)-JVS(3244)*XX(234)
  XX(122) = XX(122)-JVS(1306)*XX(186)-JVS(1357)*XX(190)-JVS(1562)*XX(199)-JVS(2384)*XX(222)-JVS(2668)*XX(227)-JVS(2978)&
              &*XX(231)-JVS(3243)*XX(234)
  XX(121) = XX(121)-JVS(939)*XX(157)-JVS(1645)*XX(202)-JVS(1660)*XX(203)-JVS(1977)*XX(214)-JVS(2055)*XX(215)-JVS(2115)&
              &*XX(217)-JVS(3058)*XX(232)-JVS(3242)*XX(234)-JVS(3369)*XX(235)
  XX(120) = XX(120)-JVS(1760)*XX(208)-JVS(1929)*XX(213)-JVS(2238)*XX(220)-JVS(3057)*XX(232)-JVS(3241)*XX(234)
  XX(119) = XX(119)-JVS(1356)*XX(190)-JVS(1759)*XX(208)-JVS(2791)*XX(229)-JVS(2884)*XX(230)-JVS(3240)*XX(234)
  XX(118) = XX(118)-JVS(791)*XX(139)-JVS(1928)*XX(213)-JVS(2977)*XX(231)-JVS(3056)*XX(232)-JVS(3239)*XX(234)
  XX(117) = XX(117)-JVS(1587)*XX(200)-JVS(1976)*XX(214)-JVS(2140)*XX(218)-JVS(2237)*XX(220)-JVS(3055)*XX(232)-JVS(3238)&
              &*XX(234)
  XX(116) = XX(116)-JVS(1305)*XX(186)-JVS(2383)*XX(222)-JVS(3237)*XX(234)
  XX(115) = XX(115)-JVS(1183)*XX(177)-JVS(1586)*XX(200)-JVS(1975)*XX(214)-JVS(2139)*XX(218)-JVS(3236)*XX(234)-JVS(3368)&
              &*XX(235)
  XX(114) = XX(114)-JVS(1425)*XX(192)-JVS(1506)*XX(195)-JVS(1585)*XX(200)-JVS(1927)*XX(213)-JVS(1974)*XX(214)-JVS(2138)&
              &*XX(218)-JVS(3054)*XX(232)-JVS(3235)*XX(234)
  XX(113) = XX(113)-JVS(956)*XX(158)-JVS(1584)*XX(200)-JVS(2433)*XX(223)-JVS(2883)*XX(230)-JVS(3053)*XX(232)-JVS(3234)&
              &*XX(234)
  XX(112) = XX(112)-JVS(690)*XX(120)-JVS(1341)*XX(189)-JVS(1424)*XX(192)-JVS(1583)*XX(200)-JVS(1758)*XX(208)-JVS(2236)&
              &*XX(220)-JVS(3052)*XX(232)-JVS(3233)*XX(234)
  XX(111) = XX(111)-JVS(1205)*XX(178)-JVS(1280)*XX(184)-JVS(2382)*XX(222)-JVS(2667)*XX(227)-JVS(3232)*XX(234)-JVS(3367)&
              &*XX(235)
  XX(110) = XX(110)-JVS(955)*XX(158)-JVS(1582)*XX(200)-JVS(2235)*XX(220)-JVS(2432)*XX(223)-JVS(2882)*XX(230)-JVS(3051)&
              &*XX(232)-JVS(3231)*XX(234)
  XX(109) = XX(109)-JVS(1023)*XX(164)-JVS(1110)*XX(171)-JVS(2381)*XX(222)-JVS(2505)*XX(224)-JVS(2542)*XX(225)-JVS(2666)&
              &*XX(227)-JVS(3230)*XX(234)
  XX(108) = XX(108)-JVS(2380)*XX(222)-JVS(2665)*XX(227)
  XX(107) = XX(107)-JVS(649)*XX(113)-JVS(954)*XX(158)-JVS(1423)*XX(192)-JVS(1581)*XX(200)-JVS(1757)*XX(208)-JVS(1973)&
              &*XX(214)-JVS(2137)*XX(218)-JVS(2234)*XX(220)-JVS(3050)*XX(232)-JVS(3229)*XX(234)
  XX(106) = XX(106)-JVS(1711)*XX(206)-JVS(1872)*XX(212)-JVS(3049)*XX(232)-JVS(3228)*XX(234)
  XX(105) = XX(105)-JVS(1710)*XX(206)-JVS(1871)*XX(212)-JVS(1926)*XX(213)-JVS(3048)*XX(232)-JVS(3227)*XX(234)
  XX(104) = XX(104)-JVS(1355)*XX(190)-JVS(1709)*XX(206)-JVS(2541)*XX(225)-JVS(2664)*XX(227)-JVS(2790)*XX(229)-JVS(3226)&
              &*XX(234)
  XX(103) = XX(103)-JVS(2201)*XX(219)-JVS(3225)*XX(234)
  XX(102) = XX(102)-JVS(993)*XX(161)-JVS(1034)*XX(165)-JVS(1870)*XX(212)-JVS(2881)*XX(230)-JVS(3047)*XX(232)-JVS(3224)&
              &*XX(234)
  XX(101) = XX(101)-JVS(1068)*XX(168)-JVS(1756)*XX(208)-JVS(1972)*XX(214)-JVS(2079)*XX(216)-JVS(3046)*XX(232)-JVS(3223)&
              &*XX(234)
  XX(100) = XX(100)-JVS(1219)*XX(179)-JVS(2078)*XX(216)-JVS(3045)*XX(232)-JVS(3222)*XX(234)
  XX(99) = XX(99)-JVS(2136)*XX(218)-JVS(2307)*XX(221)-JVS(2789)*XX(229)-JVS(2880)*XX(230)
  XX(98) = XX(98)-JVS(1520)*XX(196)-JVS(2748)*XX(228)-JVS(3162)*XX(233)-JVS(3221)*XX(234)
  XX(97) = XX(97)-JVS(2431)*XX(223)-JVS(2879)*XX(230)-JVS(3220)*XX(234)-JVS(3366)*XX(235)
  XX(96) = XX(96)-JVS(877)*XX(149)-JVS(2663)*XX(227)-JVS(3161)*XX(233)
  XX(95) = XX(95)-JVS(2788)*XX(229)-JVS(2878)*XX(230)-JVS(3044)*XX(232)-JVS(3219)*XX(234)-JVS(3365)*XX(235)
  XX(94) = XX(94)-JVS(1834)*XX(210)-JVS(2306)*XX(221)-JVS(2379)*XX(222)-JVS(2616)*XX(226)-JVS(3043)*XX(232)-JVS(3218)&
             &*XX(234)-JVS(3364)*XX(235)
  XX(93) = XX(93)-JVS(2233)*XX(220)-JVS(2305)*XX(221)-JVS(2540)*XX(225)-JVS(2662)*XX(227)-JVS(3042)*XX(232)-JVS(3217)&
             &*XX(234)-JVS(3363)*XX(235)
  XX(92) = XX(92)-JVS(1354)*XX(190)-JVS(1971)*XX(214)-JVS(2200)*XX(219)-JVS(2304)*XX(221)-JVS(2787)*XX(229)-JVS(3216)&
             &*XX(234)
  XX(91) = XX(91)-JVS(953)*XX(158)-JVS(1580)*XX(200)-JVS(1970)*XX(214)-JVS(2430)*XX(223)-JVS(2786)*XX(229)-JVS(3041)&
             &*XX(232)
  XX(90) = XX(90)-JVS(1109)*XX(171)-JVS(1630)*XX(201)-JVS(3040)*XX(232)-JVS(3215)*XX(234)
  XX(89) = XX(89)-JVS(1022)*XX(164)-JVS(1869)*XX(212)-JVS(3039)*XX(232)-JVS(3214)*XX(234)
  XX(88) = XX(88)-JVS(1204)*XX(178)-JVS(1279)*XX(184)-JVS(2429)*XX(223)-JVS(2877)*XX(230)
  XX(87) = XX(87)-JVS(2615)*XX(226)-JVS(2661)*XX(227)-JVS(2747)*XX(228)-JVS(3160)*XX(233)-JVS(3213)*XX(234)-JVS(3362)&
             &*XX(235)
  XX(86) = XX(86)-JVS(564)*XX(97)-JVS(858)*XX(147)-JVS(1203)*XX(178)-JVS(2378)*XX(222)-JVS(2660)*XX(227)-JVS(2876)&
             &*XX(230)
  XX(85) = XX(85)-JVS(2614)*XX(226)-JVS(2659)*XX(227)-JVS(2746)*XX(228)-JVS(3159)*XX(233)-JVS(3212)*XX(234)-JVS(3361)&
             &*XX(235)
  XX(84) = XX(84)-JVS(2613)*XX(226)-JVS(2658)*XX(227)-JVS(2745)*XX(228)-JVS(3158)*XX(233)-JVS(3211)*XX(234)-JVS(3360)&
             &*XX(235)
  XX(83) = XX(83)-JVS(1519)*XX(196)-JVS(2657)*XX(227)-JVS(2875)*XX(230)-JVS(3210)*XX(234)
  XX(82) = XX(82)-JVS(2612)*XX(226)-JVS(2656)*XX(227)-JVS(2744)*XX(228)-JVS(3157)*XX(233)-JVS(3209)*XX(234)-JVS(3359)&
             &*XX(235)
  XX(81) = XX(81)-JVS(1673)*XX(204)-JVS(2077)*XX(216)-JVS(3038)*XX(232)-JVS(3208)*XX(234)
  XX(80) = XX(80)-JVS(1833)*XX(210)-JVS(2377)*XX(222)-JVS(2611)*XX(226)-JVS(2743)*XX(228)-JVS(3207)*XX(234)
  XX(79) = XX(79)-JVS(557)*XX(96)-JVS(1518)*XX(196)-JVS(2655)*XX(227)-JVS(3156)*XX(233)-JVS(3206)*XX(234)
  XX(78) = XX(78)-JVS(1969)*XX(214)-JVS(2303)*XX(221)-JVS(2785)*XX(229)-JVS(2874)*XX(230)-JVS(3037)*XX(232)
  XX(77) = XX(77)-JVS(2232)*XX(220)-JVS(2539)*XX(225)-JVS(2654)*XX(227)-JVS(3036)*XX(232)-JVS(3205)*XX(234)
  XX(76) = XX(76)-JVS(804)*XX(141)-JVS(2873)*XX(230)
  XX(75) = XX(75)-JVS(2231)*XX(220)-JVS(2538)*XX(225)-JVS(2653)*XX(227)-JVS(3035)*XX(232)-JVS(3204)*XX(234)
  XX(74) = XX(74)-JVS(1202)*XX(178)-JVS(2652)*XX(227)
  XX(73) = XX(73)-JVS(1832)*XX(210)-JVS(2376)*XX(222)-JVS(2610)*XX(226)-JVS(2742)*XX(228)-JVS(3203)*XX(234)
  XX(72) = XX(72)-JVS(2135)*XX(218)-JVS(2302)*XX(221)-JVS(3202)*XX(234)
  XX(71) = XX(71)-JVS(1201)*XX(178)-JVS(3201)*XX(234)-JVS(3358)*XX(235)
  XX(70) = XX(70)-JVS(2428)*XX(223)-JVS(3034)*XX(232)
  XX(69) = XX(69)-JVS(2199)*XX(219)-JVS(2230)*XX(220)-JVS(2741)*XX(228)-JVS(3200)*XX(234)
  XX(68) = XX(68)-JVS(2427)*XX(223)-JVS(2609)*XX(226)-JVS(2740)*XX(228)-JVS(2872)*XX(230)
  XX(67) = XX(67)-JVS(1353)*XX(190)
  XX(66) = XX(66)-JVS(938)*XX(157)-JVS(3199)*XX(234)
  XX(65) = XX(65)-JVS(937)*XX(157)-JVS(3198)*XX(234)
  XX(64) = XX(64)-JVS(2426)*XX(223)-JVS(3033)*XX(232)
  XX(63) = XX(63)-JVS(2425)*XX(223)-JVS(3032)*XX(232)
  XX(62) = XX(62)-JVS(2424)*XX(223)-JVS(2608)*XX(226)
  XX(61) = XX(61)-JVS(857)*XX(147)-JVS(1200)*XX(178)-JVS(2423)*XX(223)
  XX(60) = XX(60)-JVS(936)*XX(157)-JVS(3197)*XX(234)
  XX(59) = XX(59)-JVS(1199)*XX(178)-JVS(2375)*XX(222)
  XX(58) = XX(58)-JVS(1831)*XX(210)-JVS(2374)*XX(222)-JVS(2607)*XX(226)-JVS(2651)*XX(227)-JVS(2739)*XX(228)-JVS(3155)&
             &*XX(233)
  XX(57) = XX(57)-JVS(2606)*XX(226)-JVS(2650)*XX(227)-JVS(2738)*XX(228)-JVS(3154)*XX(233)
  XX(56) = XX(56)-JVS(2605)*XX(226)-JVS(2649)*XX(227)-JVS(2737)*XX(228)-JVS(3153)*XX(233)
  XX(55) = XX(55)-JVS(2604)*XX(226)-JVS(2648)*XX(227)-JVS(2736)*XX(228)-JVS(3152)*XX(233)
  XX(54) = XX(54)-JVS(2603)*XX(226)-JVS(2647)*XX(227)-JVS(2735)*XX(228)-JVS(3151)*XX(233)
  XX(53) = XX(53)-JVS(2602)*XX(226)-JVS(2646)*XX(227)-JVS(2734)*XX(228)-JVS(3150)*XX(233)
  XX(52) = XX(52)-JVS(2601)*XX(226)-JVS(2645)*XX(227)-JVS(2733)*XX(228)-JVS(3149)*XX(233)
  XX(51) = XX(51)-JVS(2373)*XX(222)-JVS(2871)*XX(230)
  XX(50) = XX(50)-JVS(424)*XX(63)-JVS(952)*XX(158)-JVS(1579)*XX(200)-JVS(1968)*XX(214)
  XX(49) = XX(49)-JVS(1218)*XX(179)-JVS(2870)*XX(230)
  XX(48) = XX(48)-JVS(832)*XX(145)-JVS(2869)*XX(230)
  XX(47) = XX(47)-JVS(528)*XX(88)-JVS(1278)*XX(184)
  XX(46) = XX(46)-JVS(1830)*XX(210)-JVS(2372)*XX(222)-JVS(2600)*XX(226)-JVS(2732)*XX(228)
  XX(45) = XX(45)-JVS(1829)*XX(210)-JVS(2371)*XX(222)-JVS(2599)*XX(226)-JVS(2731)*XX(228)
  XX(44) = XX(44)-JVS(1198)*XX(178)-JVS(2301)*XX(221)-JVS(3196)*XX(234)-JVS(3357)*XX(235)
  XX(43) = XX(43)-JVS(2644)*XX(227)-JVS(3195)*XX(234)-JVS(3356)*XX(235)
  XX(42) = XX(42)-JVS(429)*XX(64)-JVS(951)*XX(158)-JVS(1967)*XX(214)
  XX(41) = XX(41)-JVS(1352)*XX(190)
  XX(40) = XX(40)-JVS(527)*XX(88)-JVS(1197)*XX(178)-JVS(1277)*XX(184)
  XX(39) = XX(39)-JVS(950)*XX(158)-JVS(1578)*XX(200)-JVS(3194)*XX(234)
  XX(38) = XX(38)-JVS(444)*XX(67)
  XX(37) = XX(37)-JVS(526)*XX(88)
  XX(36) = XX(36)
  XX(35) = XX(35)
  XX(34) = XX(34)
  XX(33) = XX(33)
  XX(32) = XX(32)
  XX(31) = XX(31)
  XX(30) = XX(30)
  XX(29) = XX(29)
  XX(28) = XX(28)
  XX(27) = XX(27)
  XX(26) = XX(26)
  XX(25) = XX(25)
  XX(24) = XX(24)
  XX(23) = XX(23)
  XX(22) = XX(22)
  XX(21) = XX(21)
  XX(20) = XX(20)
  XX(19) = XX(19)
  XX(18) = XX(18)
  XX(17) = XX(17)
  XX(16) = XX(16)
  XX(15) = XX(15)
  XX(14) = XX(14)
  XX(13) = XX(13)
  XX(12) = XX(12)
  XX(11) = XX(11)
  XX(10) = XX(10)
  XX(9) = XX(9)
  XX(8) = XX(8)
  XX(7) = XX(7)
  XX(6) = XX(6)
  XX(5) = XX(5)
  XX(4) = XX(4)
  XX(3) = XX(3)-JVS(1196)*XX(178)-JVS(2370)*XX(222)
  XX(2) = XX(2)-JVS(1195)*XX(178)-JVS(2643)*XX(227)
  XX(1) = XX(1)-JVS(1194)*XX(178)
      
END SUBROUTINE KppSolveTR

! End of KppSolveTR function
! ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~


! ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
! 
! BLAS_UTIL - BLAS-LIKE utility functions
!   Arguments :
! 
! ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~

!--------------------------------------------------------------
!
! BLAS/LAPACK-like subroutines used by the integration algorithms
! It is recommended to replace them by calls to the optimized
!      BLAS/LAPACK library for your machine
!
!  (C) Adrian Sandu, Aug. 2004
!      Virginia Polytechnic Institute and State University
!--------------------------------------------------------------


!--------------------------------------------------------------
      SUBROUTINE WCOPY(N,X,incX,Y,incY)
!--------------------------------------------------------------
!     copies a vector, x, to a vector, y:  y <- x
!     only for incX=incY=1
!     after BLAS
!     replace this by the function from the optimized BLAS implementation:
!         CALL  SCOPY(N,X,1,Y,1)   or   CALL  DCOPY(N,X,1,Y,1)
!--------------------------------------------------------------
!     USE gckpp_Precision
      
      INTEGER  :: i,incX,incY,M,MP1,N
      REAL(kind=dp) :: X(N),Y(N)

      IF (N.LE.0) RETURN

      M = MOD(N,8)
      IF( M .NE. 0 ) THEN
        DO i = 1,M
          Y(i) = X(i)
        END DO
        IF( N .LT. 8 ) RETURN
      END IF    
      MP1 = M+1
      DO i = MP1,N,8
        Y(i) = X(i)
        Y(i + 1) = X(i + 1)
        Y(i + 2) = X(i + 2)
        Y(i + 3) = X(i + 3)
        Y(i + 4) = X(i + 4)
        Y(i + 5) = X(i + 5)
        Y(i + 6) = X(i + 6)
        Y(i + 7) = X(i + 7)
      END DO

      END SUBROUTINE WCOPY


!--------------------------------------------------------------
      SUBROUTINE WAXPY(N,Alpha,X,incX,Y,incY)
!--------------------------------------------------------------
!     constant times a vector plus a vector: y <- y + Alpha*x
!     only for incX=incY=1
!     after BLAS
!     replace this by the function from the optimized BLAS implementation:
!         CALL SAXPY(N,Alpha,X,1,Y,1) or  CALL DAXPY(N,Alpha,X,1,Y,1)
!--------------------------------------------------------------

      INTEGER  :: i,incX,incY,M,MP1,N
      REAL(kind=dp) :: X(N),Y(N),Alpha
      REAL(kind=dp), PARAMETER :: ZERO = 0.0_dp

      IF (Alpha .EQ. ZERO) RETURN
      IF (N .LE. 0) RETURN

      M = MOD(N,4)
      IF( M .NE. 0 ) THEN
        DO i = 1,M
          Y(i) = Y(i) + Alpha*X(i)
        END DO
        IF( N .LT. 4 ) RETURN
      END IF
      MP1 = M + 1
      DO i = MP1,N,4
        Y(i) = Y(i) + Alpha*X(i)
        Y(i + 1) = Y(i + 1) + Alpha*X(i + 1)
        Y(i + 2) = Y(i + 2) + Alpha*X(i + 2)
        Y(i + 3) = Y(i + 3) + Alpha*X(i + 3)
      END DO
      
      END SUBROUTINE WAXPY



!--------------------------------------------------------------
      SUBROUTINE WSCAL(N,Alpha,X,incX)
!--------------------------------------------------------------
!     constant times a vector: x(1:N) <- Alpha*x(1:N) 
!     only for incX=incY=1
!     after BLAS
!     replace this by the function from the optimized BLAS implementation:
!         CALL SSCAL(N,Alpha,X,1) or  CALL DSCAL(N,Alpha,X,1)
!--------------------------------------------------------------

      INTEGER  :: i,incX,M,MP1,N
      REAL(kind=dp)  :: X(N),Alpha
      REAL(kind=dp), PARAMETER  :: ZERO=0.0_dp, ONE=1.0_dp

      IF (Alpha .EQ. ONE) RETURN
      IF (N .LE. 0) RETURN

      M = MOD(N,5)
      IF( M .NE. 0 ) THEN
        IF (Alpha .EQ. (-ONE)) THEN
          DO i = 1,M
            X(i) = -X(i)
          END DO
        ELSEIF (Alpha .EQ. ZERO) THEN
          DO i = 1,M
            X(i) = ZERO
          END DO
        ELSE
          DO i = 1,M
            X(i) = Alpha*X(i)
          END DO
        END IF
        IF( N .LT. 5 ) RETURN
      END IF
      MP1 = M + 1
      IF (Alpha .EQ. (-ONE)) THEN
        DO i = MP1,N,5
          X(i)     = -X(i)
          X(i + 1) = -X(i + 1)
          X(i + 2) = -X(i + 2)
          X(i + 3) = -X(i + 3)
          X(i + 4) = -X(i + 4)
        END DO
      ELSEIF (Alpha .EQ. ZERO) THEN
        DO i = MP1,N,5
          X(i)     = ZERO
          X(i + 1) = ZERO
          X(i + 2) = ZERO
          X(i + 3) = ZERO
          X(i + 4) = ZERO
        END DO
      ELSE
        DO i = MP1,N,5
          X(i)     = Alpha*X(i)
          X(i + 1) = Alpha*X(i + 1)
          X(i + 2) = Alpha*X(i + 2)
          X(i + 3) = Alpha*X(i + 3)
          X(i + 4) = Alpha*X(i + 4)
        END DO
      END IF

      END SUBROUTINE WSCAL

!--------------------------------------------------------------
      REAL(kind=dp) FUNCTION WLAMCH( C )
!--------------------------------------------------------------
!     returns epsilon machine
!     after LAPACK
!     replace this by the function from the optimized LAPACK implementation:
!          CALL SLAMCH('E') or CALL DLAMCH('E')
!--------------------------------------------------------------
!      USE gckpp_Precision

      CHARACTER ::  C
      INTEGER    :: i
      REAL(kind=dp), SAVE  ::  Eps
      REAL(kind=dp)  ::  Suma
      REAL(kind=dp), PARAMETER  ::  ONE=1.0_dp, HALF=0.5_dp
      LOGICAL, SAVE   ::  First=.TRUE.

!$OMP THREADPRIVATE( Eps, First )      

      IF (First) THEN
        First = .FALSE.
        Eps = HALF**(16)
        DO i = 17, 80
          Eps = Eps*HALF
          CALL WLAMCH_ADD(ONE,Eps,Suma)
          IF (Suma.LE.ONE) GOTO 10
        END DO
        PRINT*,'ERROR IN WLAMCH. EPS < ',Eps
        RETURN
10      Eps = Eps*2
        i = i-1      
      END IF

      WLAMCH = Eps

      END FUNCTION WLAMCH
     
      SUBROUTINE WLAMCH_ADD( A, B, Suma )
!      USE gckpp_Precision
      
      REAL(kind=dp) A, B, Suma
      Suma = A + B

      END SUBROUTINE WLAMCH_ADD
!--------------------------------------------------------------


!--------------------------------------------------------------
      SUBROUTINE SET2ZERO(N,Y)
!--------------------------------------------------------------
!     copies zeros into the vector y:  y <- 0
!     after BLAS
!--------------------------------------------------------------
      
      INTEGER ::  i,M,MP1,N
      REAL(kind=dp) ::  Y(N)
      REAL(kind=dp), PARAMETER :: ZERO = 0.0d0

      IF (N.LE.0) RETURN

      M = MOD(N,8)
      IF( M .NE. 0 ) THEN
        DO i = 1,M
          Y(i) = ZERO
        END DO
        IF( N .LT. 8 ) RETURN
      END IF    
      MP1 = M+1
      DO i = MP1,N,8
        Y(i)     = ZERO
        Y(i + 1) = ZERO
        Y(i + 2) = ZERO
        Y(i + 3) = ZERO
        Y(i + 4) = ZERO
        Y(i + 5) = ZERO
        Y(i + 6) = ZERO
        Y(i + 7) = ZERO
      END DO

      END SUBROUTINE SET2ZERO


!--------------------------------------------------------------
      REAL(kind=dp) FUNCTION WDOT (N, DX, incX, DY, incY) 
!--------------------------------------------------------------
!     dot produce: wdot = x(1:N)*y(1:N) 
!     only for incX=incY=1
!     after BLAS
!     replace this by the function from the optimized BLAS implementation:
!         CALL SDOT(N,X,1,Y,1) or  CALL DDOT(N,X,1,Y,1)
!--------------------------------------------------------------
!      USE messy_mecca_kpp_Precision
!--------------------------------------------------------------
      IMPLICIT NONE
      INTEGER :: N, incX, incY
      REAL(kind=dp) :: DX(N), DY(N) 

      INTEGER :: i, IX, IY, M, MP1, NS
                                 
      WDOT = 0.0D0 
      IF (N .LE. 0) RETURN 
      IF (incX .EQ. incY) IF (incX-1) 5,20,60 
!                                                                       
!     Code for unequal or nonpositive increments.                       
!                                                                       
    5 IX = 1 
      IY = 1 
      IF (incX .LT. 0) IX = (-N+1)*incX + 1 
      IF (incY .LT. 0) IY = (-N+1)*incY + 1 
      DO i = 1,N 
        WDOT = WDOT + DX(IX)*DY(IY) 
        IX = IX + incX 
        IY = IY + incY 
      END DO 
      RETURN 
!                                                                       
!     Code for both increments equal to 1.                              
!                                                                       
!     Clean-up loop so remaining vector length is a multiple of 5.      
!                                                                       
   20 M = MOD(N,5) 
      IF (M .EQ. 0) GO TO 40 
      DO i = 1,M 
         WDOT = WDOT + DX(i)*DY(i) 
      END DO 
      IF (N .LT. 5) RETURN 
   40 MP1 = M + 1 
      DO i = MP1,N,5 
          WDOT = WDOT + DX(i)*DY(i) + DX(i+1)*DY(i+1) + DX(i+2)*DY(i+2) +  &
                   DX(i+3)*DY(i+3) + DX(i+4)*DY(i+4)                   
      END DO 
      RETURN 
!                                                                       
!     Code for equal, positive, non-unit increments.                    
!                                                                       
   60 NS = N*incX 
      DO i = 1,NS,incX 
        WDOT = WDOT + DX(i)*DY(i) 
      END DO 

      END FUNCTION WDOT                                          


!--------------------------------------------------------------
      SUBROUTINE WADD(N,X,Y,Z)
!--------------------------------------------------------------
!     adds two vectors: z <- x + y
!     BLAS - like
!--------------------------------------------------------------
!     USE gckpp_Precision
      
      INTEGER :: i, M, MP1, N
      REAL(kind=dp) :: X(N),Y(N),Z(N)

      IF (N.LE.0) RETURN

      M = MOD(N,5)
      IF( M /= 0 ) THEN
         DO i = 1,M
            Z(i) = X(i) + Y(i)
         END DO
         IF( N < 5 ) RETURN
      END IF    
      MP1 = M+1
      DO i = MP1,N,5
         Z(i)     = X(i)     + Y(i)
         Z(i + 1) = X(i + 1) + Y(i + 1)
         Z(i + 2) = X(i + 2) + Y(i + 2)
         Z(i + 3) = X(i + 3) + Y(i + 3)
         Z(i + 4) = X(i + 4) + Y(i + 4)
      END DO

      END SUBROUTINE WADD
      
      
      
!--------------------------------------------------------------
      SUBROUTINE WGEFA(N,A,Ipvt,info)
!--------------------------------------------------------------
!     WGEFA FACTORS THE MATRIX A (N,N) BY
!           GAUSS ELIMINATION WITH PARTIAL PIVOTING
!     LINPACK - LIKE 
!--------------------------------------------------------------
!
      INTEGER       :: N,Ipvt(N),info
      REAL(kind=dp) :: A(N,N)
      REAL(kind=dp) :: t, dmax, da
      INTEGER       :: j,k,l
      REAL(kind=dp), PARAMETER :: ZERO = 0.0, ONE = 1.0

      info = 0

size: IF (n > 1) THEN
      
col:  DO k = 1, n-1

!        find l = pivot index
!        l = idamax(n-k+1,A(k,k),1) + k - 1
         l = k; dmax = abs(A(k,k))
         DO j = k+1,n
            da = ABS(A(j,k))
            IF (da > dmax) THEN
              l = j; dmax = da
            END IF
         END DO
         Ipvt(k) = l

!        zero pivot implies this column already triangularized
         IF (ABS(A(l,k)) < TINY(ZERO)) THEN
            info = k
            return
         ELSE   
            IF (l /= k) THEN
               t = A(l,k); A(l,k) = A(k,k); A(k,k) = t
            END IF
            t = -ONE/A(k,k)
            CALL WSCAL(n-k,t,A(k+1,k),1)
            DO j = k+1, n
               t = A(l,j)
               IF (l /= k) THEN
                  A(l,j) = A(k,j); A(k,j) = t
               END IF
               CALL WAXPY(n-k,t,A(k+1,k),1,A(k+1,j),1)
            END DO         
         END IF
         
       END DO col
       
      END IF size
      
      Ipvt(N) = N
      IF (ABS(A(N,N)) == ZERO) info = N
      
      END SUBROUTINE WGEFA


!--------------------------------------------------------------
      SUBROUTINE WGESL(Trans,N,A,Ipvt,b)
!--------------------------------------------------------------
!     WGESL solves the system
!     a * x = b  or  trans(a) * x = b
!     using the factors computed by WGEFA.
!
!     Trans      = 'N'   to solve  A*x = b ,
!                = 'T'   to solve  transpose(A)*x = b
!     LINPACK - LIKE 
!--------------------------------------------------------------

      INTEGER       :: N,Ipvt(N)
      CHARACTER     :: trans
      REAL(kind=dp) :: A(N,N),b(N)
      REAL(kind=dp) :: t
      INTEGER       :: k,kb,l

      
      SELECT CASE (Trans)

      CASE ('n','N')  !  Solve  A * x = b

!        first solve  L*y = b
         IF (n >= 2) THEN
          DO k = 1, n-1
            l = Ipvt(k)
            t = b(l)
            IF (l /= k) THEN
               b(l) = b(k)
               b(k) = t
            END IF
            CALL WAXPY(n-k,t,a(k+1,k),1,b(k+1),1)
          END DO
         END IF
!        now solve  U*x = y
         DO kb = 1, n
            k = n + 1 - kb
            b(k) = b(k)/a(k,k)
            t = -b(k)
            CALL WAXPY(k-1,t,a(1,k),1,b(1),1)
         END DO
      
      CASE ('t','T')  !  Solve transpose(A) * x = b

!        first solve  trans(U)*y = b
         DO k = 1, n
            t = WDOT(k-1,a(1,k),1,b(1),1)
            b(k) = (b(k) - t)/a(k,k)
         END DO
!        now solve trans(L)*x = y
         IF (n >= 2) THEN
         DO kb = 1, n-1
            k = n - kb
            b(k) = b(k) + WDOT(n-k,a(k+1,k),1,b(k+1),1)
            l = Ipvt(k)
            IF (l /= k) THEN
               t = b(l); b(l) = b(k); b(k) = t
            END IF
         END DO
         END IF
   
      END SELECT

      END SUBROUTINE WGESL
! End of BLAS_UTIL function
! ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~



END MODULE gckpp_LinearAlgebra

